/************************************************************************//**
 *
 * @file	t16b_reg.h
 *
 * @brief	Definition of the 16-bit PWM Timer(T16B) Register.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 01 Sep. 2016    1.00
 *				- First revision.
 *
 ******************************************************************************/

#ifndef T16B_REG_H__
#define T16B_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

/// T16B Ch.N Clock Control Register
typedef union T16BNCLK_REG_TAG {
    unsigned short  reg;
    struct T16BNCLK_REG_BIT_TAG {
        /**
         * These bits select the clock source of T16B Ch.n.
         * .CLKSRC[1:0]
         *  These bits select the clock source of T16B Ch.n.
         * .CLKDIV[3:0]
         *  These bits select the division ratio of the T16B Ch.n operating clock (counter clock).
         * +-------------+--------------------------------------------------------------+
         * |             |                         CLKSRC[2:0]                          |
         * |             +--------+------+--------+-----+------+------+--------+--------+
         * |             |  0x0   |  0x1 |  0x2   | 0x3 | 0x4  | 0x5  |  0x6   |  0x7   |
         * | CLKDIV[3:0] +--------+------+--------+-----+------+------+--------+--------+
         * |             |        |      |        |     |      |      | EXCL00 | EXCL11 |
         * |             |  IOSC  | OSC1 |  OSC3  |EXOSC|EXCL00|EXCL01|inverted|inverted|
         * |             |        |      |        |     |      |      |  input |  input |
         * +-------------+--------+------+--------+-----+------+------+--------+--------+
         * |      0xf    |1/32,768|1/1   |1/32,768|1/1  |1/1   |1/1   |1/1     |1/1     |
         * +-------------+--------+      +--------+     +      +      +        +        +
         * |      0xe    |1/16,384|      |1/16,384|     |      |      |        |        |
         * +-------------+--------+      +--------+     +      +      +        +        +
         * |      0xd    |1/8,192 |      |1/8,192 |     |      |      |        |        |
         * +-------------+--------+      +--------+     +      +      +        +        +
         * |      0xc    |1/4,096 |      |1/4,096 |     |      |      |        |        |
         * +-------------+--------+      +--------+     +      +      +        +        +
         * |      0xb    |1/2,048 |      |1/2,048 |     |      |      |        |        |
         * +-------------+--------+      +--------+     +      +      +        +        +
         * |      0xa    |1/1,024 |      |1/1,024 |     |      |      |        |        |
         * +-------------+--------+      +--------+     +      +      +        +        +
         * |      0x9    |1/512   |      |1/512   |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x8    |1/256   |1/256 |1/256   |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x7    |1/128   |1/128 |1/128   |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x6    |1/64    |1/64  |1/64    |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x5    |1/32    |1/32  |1/32    |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x4    |1/16    |1/16  |1/16    |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x3    |1/8     |1/8   |1/8     |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x2    |1/4     |1/4   |1/4     |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x1    |1/2     |1/2   |1/2     |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x0    |1/1     |1/1   |1/1     |     |      |      |        |        |
         * +-------------+--------+------+--------+-----+------+------+--------+--------+
         */
        unsigned short      CLKSRC      : 3;
        unsigned short      reserved_1  : 1;    ///< Reserved.
        /**
         * These bits select the division ratio of the T16B Ch.n operating clock (counter clock).
         * .CLKSRC[1:0]
         *  These bits select the clock source of T16B Ch.n.
         * .CLKDIV[3:0]
         *  These bits select the division ratio of the T16B Ch.n operating clock (counter clock).
         * +-------------+--------------------------------------------------------------+
         * |             |                         CLKSRC[2:0]                          |
         * |             +--------+------+--------+-----+------+------+--------+--------+
         * |             |  0x0   |  0x1 |  0x2   | 0x3 | 0x4  | 0x5  |  0x6   |  0x7   |
         * | CLKDIV[3:0] +--------+------+--------+-----+------+------+--------+--------+
         * |             |        |      |        |     |      |      | EXCL00 | EXCL11 |
         * |             |  IOSC  | OSC1 |  OSC3  |EXOSC|EXCL00|EXCL01|inverted|inverted|
         * |             |        |      |        |     |      |      |  input |  input |
         * +-------------+--------+------+--------+-----+------+------+--------+--------+
         * |      0xf    |1/32,768|1/1   |1/32,768|1/1  |1/1   |1/1   |1/1     |1/1     |
         * +-------------+--------+      +--------+     +      +      +        +        +
         * |      0xe    |1/16,384|      |1/16,384|     |      |      |        |        |
         * +-------------+--------+      +--------+     +      +      +        +        +
         * |      0xd    |1/8,192 |      |1/8,192 |     |      |      |        |        |
         * +-------------+--------+      +--------+     +      +      +        +        +
         * |      0xc    |1/4,096 |      |1/4,096 |     |      |      |        |        |
         * +-------------+--------+      +--------+     +      +      +        +        +
         * |      0xb    |1/2,048 |      |1/2,048 |     |      |      |        |        |
         * +-------------+--------+      +--------+     +      +      +        +        +
         * |      0xa    |1/1,024 |      |1/1,024 |     |      |      |        |        |
         * +-------------+--------+      +--------+     +      +      +        +        +
         * |      0x9    |1/512   |      |1/512   |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x8    |1/256   |1/256 |1/256   |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x7    |1/128   |1/128 |1/128   |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x6    |1/64    |1/64  |1/64    |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x5    |1/32    |1/32  |1/32    |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x4    |1/16    |1/16  |1/16    |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x3    |1/8     |1/8   |1/8     |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x2    |1/4     |1/4   |1/4     |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x1    |1/2     |1/2   |1/2     |     |      |      |        |        |
         * +-------------+--------+------+--------+     +      +      +        +        +
         * |      0x0    |1/1     |1/1   |1/1     |     |      |      |        |        |
         * +-------------+--------+------+--------+-----+------+------+--------+--------+
         */
        unsigned short      CLKDIV      : 4;
        /**
         * This bit sets whether the T16B Ch.N operating clock is supplied in DEBUG mode or not.
         * .DBRUN
         *  This bit sets whether the T16B Ch.N operating clock is supplied in DEBUG mode or not.
         *    1 (R/W): Clock supplied in DEBUG mode
         *    0 (R/W): No clock supplied in DEBUG mode
         */
        unsigned short      DBRUN       : 1;
        unsigned short      reserved_2  : 7;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} T16BNCLK_REG;

/// T16B Ch.N Counter Control Register.
typedef union T16BNCTL_REG_TAG {
    unsigned short  reg;
    struct T16BNCTL_REG_BIT_TAG {
        /**
         * This bit enables the T16B Ch.N operations.
         * .MODEN
         *  This bit enables the T16B Ch.n operations.
         *    1 (R/W): Enable (Start supplying operating clock)
         *    0 (R/W): Disable (Stop supplying operating clock)
         */
        unsigned short      MODEN       : 1;
        /**
         * This bit resets the counter.
         * .PRESET
         *  This bit resets the counter.
         *    1 (W): Reset
         *    0 (W): Ineffective
         *    1 (R): Resetting in progress
         *    0 (R): Resetting finished or normal operation
         */
        unsigned short      PRESET      : 1;
        /**
         * This bit starts/stops counting.
         * .RUN
         *  This bit starts/stops counting.
         *    1 (W): Start counting
         *    0 (W): Stop counting
         *    1 (R): Counting
         *    0 (R): Idle
         */
        unsigned short      RUN         : 1;
        /**
         * This bit selects the counter repeat/one-shot mode.
         * .ONEST
         *  This bit selects the counter repeat/one-shot mode.
         * .CNTMD[1:0]
         *  These bits select the counter up/down mode.
         * +------------+-----------------------------------------------------+
         * |            |                      Count mode                     |
         * | CNTMD[1:0] +---------------------------+-------------------------+
         * |            |        ONEST = 1          |        ONEST = 0        |
         * +------------+---------------------------+-------------------------+
         * |    0x3     |                       Reserved                      |
         * +------------+---------------------------+-------------------------+
         * |    0x2     |One-shot up/down count mode|Repeat up/down count mode|
         * +------------+---------------------------+-------------------------+
         * |    0x1     | One-shot down count mode  | Repeat down count mode  |
         * +------------+---------------------------+-------------------------+
         * |    0x0     |  One-shot up count mode   |  Repeat up count mode   |
         * +------------+---------------------------+-------------------------+
         */
        unsigned short      ONEST       : 1;
        /**
         * These bits select the counter up/down mode.
         * .ONEST
         *  This bit selects the counter repeat/one-shot mode.
         * .CNTMD[1:0]
         *  These bits select the counter up/down mode.
         * +------------+-----------------------------------------------------+
         * |            |                      Count mode                     |
         * | CNTMD[1:0] +---------------------------+-------------------------+
         * |            |        ONEST = 1          |        ONEST = 0        |
         * +------------+---------------------------+-------------------------+
         * |    0x3     |                       Reserved                      |
         * +------------+---------------------------+-------------------------+
         * |    0x2     |One-shot up/down count mode|Repeat up/down count mode|
         * +------------+---------------------------+-------------------------+
         * |    0x1     | One-shot down count mode  | Repeat down count mode  |
         * +------------+---------------------------+-------------------------+
         * |    0x0     |  One-shot up count mode   |  Repeat up count mode   |
         * +------------+---------------------------+-------------------------+
         */
        unsigned short      CNTMD       : 2;
        unsigned short      reserved_1  : 2;    ///< Reserved.
        /**
         * This bit indicates whether data can be written to the T16BnMC register or not.
         * .MAXBSY
         *  This bit indicates whether data can be written to the T16BnMC register or not.
         *    1 (R): Busy status (cannot be written)
         *    0 (R): Idle (can be written)
         */
        unsigned short      MAXBSY      : 1;
        unsigned short      reserved_2  : 7;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} T16BNCTL_REG;

/// T16B Ch.N Max Counter Data Register
typedef union T16BNMC_REG_TAG {
    unsigned short  reg;
    struct T16BNMC_REG_BIT_TAG {
        /**
         * .MC[15:0]
         *  These bits are used to set the MAX value to preset to the counter.
         */
        unsigned short      MC          :16;
    } bit;
    unsigned char   byte_reg[2];
} T16BNMC_REG;

/// T16B Ch.N Timer Counter Data Register.
typedef union T16BNTC_REG_TAG {
    unsigned short  reg;
    struct T16BNTC_REG_BIT_TAG {
        /**
         * .TC[15:0]
         *  The current counter value can be read out through these bits.
         */
        unsigned short      TC          :16;
    } bit;
    unsigned char   byte_reg[2];
} T16BNTC_REG;

/// T16B Ch.N Counter Status Register
typedef union T16BNCS_REG_TAG {
    unsigned short  reg;
    struct T16BNCS_REG_BIT_TAG {
        /**
         * This bit indicates the counter operating status.
         * .BSY
         *  This bit indicates the counter operating status.
         *    1 (R): Running
         *    0 (R): Idle
         */
        unsigned short      BSY         : 1;
        /**
         * This bit indicates the currently set count direction.
         * .UP_DOWN
         *  This bit indicates the currently set count direction.
         *    1 (R): Count up
         *    0 (R): Count down
         */
        unsigned short      UP_DOWN     : 1;
        /**
         * These bits indicate the signal level currently input to the CAPx0 pin.
         * .CAPI0
         *  These bits indicate the signal level currently input to the CAPnm pin.
         *    1 (R): Input signal = High level
         *    0 (R): Input signal = Low level
         * .CAPI0 bit: CAPn0 pin
         */
        unsigned short      CAPI0       : 1;
        /**
         * These bits indicate the signal level currently input to the CAPx1 pin.
         * .CAPI1
         *  These bits indicate the signal level currently input to the CAPnm pin.
         *    1 (R): Input signal = High level
         *    0 (R): Input signal = Low level
         * .CAPI1 bit: CAPn1 pin
         */
        unsigned short      CAPI1       : 1;
        /**
         * These bits indicate the signal level currently input to the CAPx2 pin.
         * .CAPI2
         *  These bits indicate the signal level currently input to the CAPnm pin.
         *    1 (R): Input signal = High level
         *    0 (R): Input signal = Low level
         * .CAPI2 bit: CAPn2 pin
         */
        unsigned short      CAPI2       : 1;
        /**
         * These bits indicate the signal level currently input to the CAPx3 pin.
         * .CAPI3
         *  These bits indicate the signal level currently input to the CAPnm pin.
         *    1 (R): Input signal = High level
         *    0 (R): Input signal = Low level
         * .CAPI3 bit: CAPn3 pin
         */
        unsigned short      CAPI3       : 1;
        /**
         * These bits indicate the signal level currently input to the CAPx4 pin.
         * .CAPI4
         *  These bits indicate the signal level currently input to the CAPnm pin.
         *    1 (R): Input signal = High level
         *    0 (R): Input signal = Low level
         * .CAPI4 bit: CAPn4 pin
         */
        unsigned short      CAPI4       : 1;
        /**
         * These bits indicate the signal level currently input to the CAPx5 pin.
         * .CAPI5
         *  These bits indicate the signal level currently input to the CAPnm pin.
         *    1 (R): Input signal = High level
         *    0 (R): Input signal = Low level
         * .CAPI5 bit: CAPn5 pin
         */
        unsigned short      CAPI5       : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} T16BNCS_REG;

/// T16B Ch.N Interrupt Flag Register.
typedef union T16BNINTF_REG_TAG {
    unsigned short  reg;
    struct T16BNINTF_REG_BIT_TAG {
        /**
         * Counter zero interrupt
         * .CNTZEROIF
         *  These bits indicate the T16B Ch.n interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         * .CNTZEROIF bit: Counter zero interrupt
         */
        unsigned short      CNTZEROIF   : 1;
        /**
         * Counter MAX interrupt
         * .CNTMAXIF
         *  These bits indicate the T16B Ch.n interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         * .CNTMAXIF bit: Counter MAX interrupt
         */
        unsigned short      CNTMAXIF    : 1;
        /**
         * Compare/capture 0 interrupt
         * .CMPCAP0IF
         *  These bits indicate the T16B Ch.n interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         * .CMPCAP0IF bit: Compare/capture 0 interrupt
         */
        unsigned short      CMPCAP0IF   : 1;
        /**
         * Capture 0 overwrite interrupt
         * .CAPOW0IF
         *  These bits indicate the T16B Ch.n interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         * .CAPOW0IF bit: Capture 0 overwrite interrupt
         */
        unsigned short      CAPOW0IF    : 1;
        /**
         * Compare/capture 1 interrupt
         * .CMPCAP1IF.
         *  These bits indicate the T16B Ch.n interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         * .CMPCAP1IF bit: Compare/capture 1 interrupt
         */
        unsigned short      CMPCAP1IF   : 1;
        /**
         * Capture 1 overwrite interrupt
         * .CAPOW1IF
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         * .CAPOW1IF bit: Capture 1 overwrite interrupt
         */
        unsigned short      CAPOW1IF    : 1;
        /**
         * Compare/capture 2 interrupt
         * .CMPCAP2IF
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         * .CMPCAP2IF bit: Compare/capture 2 interrupt
         */
        unsigned short      CMPCAP2IF   : 1;
        /**
         * Capture 2 overwrite interrupt
         * .CAPOW2IF
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         * .CAPOW2IF bit: Capture 2 overwrite interrupt
         */
        unsigned short      CAPOW2IF    : 1;
        /**
         * Compare/capture 3 interrupt
         * .CMPCAP3IF
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         * .CMPCAP3IF bit: Compare/capture 3 interrupt
         */
        unsigned short      CMPCAP3IF   : 1;
        /**
         * Capture 3 overwrite interrupt
         * .CAPOW3IF
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         * .CAPOW3IF bit: Capture 3 overwrite interrupt
         */
        unsigned short      CAPOW3IF    : 1;
        /**
         * Compare/capture 4 interrupt
         * .CMPCAP4IF
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         * .CMPCAP4IF bit: Compare/capture 4 interrupt
         */
        unsigned short      CMPCAP4IF   : 1;
        /**
         * Capture 4 overwrite interrupt
         * .CAPOW4IF
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         * .CAPOW4IF bit: Capture 4 overwrite interrupt
         */
        unsigned short      CAPOW4IF    : 1;
        /**
         * Compare/capture 5 interrupt
         * .CMPCAP5IF
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         * .CMPCAP5IF bit: Compare/capture 5 interrupt
         */
        unsigned short      CMPCAP5IF   : 1;
        /**
         * Capture 5 overwrite interrupt
         * .CAPOW5IF
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         * .CAPOW5IF bit: Capture 5 overwrite interrupt
         */
        unsigned short      CAPOW5IF    : 1;
        unsigned short      reserved_1  : 2;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} T16BNINTF_REG;

/// T16B Ch.N Interrupt Enable Register.
typedef union T16BNINTE_REG_TAG {
    unsigned short  reg;
    struct T16BNINTE_REG_BIT_TAG {
        /**
         * Counter zero interrupt
         * .CNTZEROIE
         *  These bits enable T16B Ch.n interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         * .CNTZEROIE bit: Counter zero interrupt
         */
        unsigned short      CNTZEROIE   : 1;
        /**
         * Counter MAX interrupt
         * .CNTMAXIE
         *  These bits enable T16B Ch.n interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         * .CNTMAXIE bit: Counter MAX interrupt
         */
        unsigned short      CNTMAXIE    : 1;
        /**
         * Compare/capture 0 interrupt
         * .CMPCAP0IE
         *  These bits enable T16B Ch.n interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         * .CMPCAP0IE bit: Compare/capture 0 interrupt
         */
        unsigned short      CMPCAP0IE   : 1;
        /**
         * Capture 0 overwrite interrupt
         * .CAPOW0IE
         *  These bits enable T16B Ch.n interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         * .CAPOW0IE bit: Capture 0 overwrite interrupt
         */
        unsigned short      CAPOW0IE    : 1;
        /**
         * Compare/capture 1 interrupt
         * .CMPCAP1IE
         *  These bits enable T16B Ch.n interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         * .CMPCAP1IE bit: Compare/capture 1 interrupt
         */
        unsigned short      CMPCAP1IE   : 1;
        /**
         * Capture 1 overwrite interrupt
         * .CAPOW1IE
         *  These bits enable T16B Ch.n interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         * .CAPOW1IE bit: Capture 1 overwrite interrupt
         */
        unsigned short      CAPOW1IE    : 1;
        /**
         * Compare/capture 2 interrupt
         * .CMPCAP2IE
         *  These bits enable T16B Ch.n interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         * .CMPCAP2IE bit: Compare/capture 2 interrupt
         */
        unsigned short      CMPCAP2IE   : 1;
        /**
         * Capture 2 overwrite interrupt
         * .CAPOW2IE
         *  These bits enable T16B Ch.n interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         * .CAPOW2IE bit: Capture 2 overwrite interrupt
         */
        unsigned short      CAPOW2IE    : 1;
        /**
         * Compare/capture 3 interrupt
         * .CMPCAP3IE
         *  These bits enable T16B Ch.n interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         * .CMPCAP3IE bit: Compare/capture 3 interrupt
         */
        unsigned short      CMPCAP3IE   : 1;
        /**
         * Capture 3 overwrite interrupt
         * .CAPOW3IE
         *  These bits enable T16B Ch.n interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         * .CAPOW3IE bit: Capture 3 overwrite interrupt
         */
        unsigned short      CAPOW3IE    : 1;
        /**
         * Compare/capture 4 interrupt
         * .CMPCAP4IE
         *  These bits enable T16B Ch.n interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         * .CMPCAP4IE bit: Compare/capture 4 interrupt
         */
        unsigned short      CMPCAP4IE   : 1;
        /**
         * Capture 4 overwrite interrupt
         * .CAPOW4IE
         *  These bits enable T16B Ch.n interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         * .CAPOW4IE bit: Capture 4 overwrite interrupt
         */
        unsigned short      CAPOW4IE    : 1;
        /**
         * Compare/capture 5 interrupt
         * .CMPCAP5IE
         *  These bits enable T16B Ch.n interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         * .CMPCAP5IE bit: Compare/capture 5 interrupt
         */
        unsigned short      CMPCAP5IE   : 1;
        /**
         * Capture 5 overwrite interrupt
         * .CAPOW5IE
         *  These bits enable T16B Ch.n interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         * .CAPOW5IE bit: Capture 5 overwrite interrupt
         */
        unsigned short      CAPOW5IE    : 1;
        unsigned short      reserved_1  : 2;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} T16BNINTE_REG;

/// T16B Ch.N Comparator/Capture 0 Control Register.
typedef union T16BNCCCTLM_REG_TAG {
    unsigned short  reg;
    struct T16BNCCCTLM_REG_BIT_TAG {
        /**
         * This bit selects the operating mode of the comparator/capture circuit m.
         * .CCMD
         *  This bit selects the operating mode of the comparator/capture circuit m.
         *    1 (R/W): Capture mode (T16BnCCRm register = capture register)
         *    0 (R/W): Comparator mode (T16BnCCRm register = compare data register)
         */
        unsigned short      CCMD        : 1;
        /**
         * This bit selects the TOUT00 signal polarity.
         * .TOUTINV
         *  This bit selects the TOUTnm signal polarity.
         *    1 (R/W): Inverted (active low)
         *    0 (R/W): Normal (active high)
         */
        unsigned short      TOUTINV     : 1;
        /**
         * These bits configure how the TOUT00 signal waveform is changed.
         * .TOUTMD[2:0]
         *  These bits configure how the TOUTnm signal waveform is changed by the comparator MATCH and
         *  counter MAX/ZERO signals.
         * +-------------+---------------------------------------------------------------------------------------------------+
         * |             |                                TOUT generation mode and operations                                |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * | TOUTMD[2:0] |            |                  | Output  |                                                         |
         * |             |  TOUTMT    |    Count mode    | signal  |                  Change in the signal                   |
         * +-------------+------------+------------------+---------+---------------------------------------------------------+
         * |    0x7      |Reset/set mode                                                                                     |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     0      |Up count mode     |TOUTnm   |The signal becomes inactive by the MATCH signal and it   |
         * |             |            |Up/down count mode|         |becomes active by the MAX signal.                        |
         * |             |            +------------------+---------+---------------------------------------------------------+
         * |             |            |Down count mode   |TOUTnm   |The signal becomes inactive by the MATCH signal and it   |
         * |             |            |                  |         |becomes active by the ZERO signal.                       |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     1      |All count modes   |TOUTnm   |The signal becomes inactive by the MATCHm signal and it  |
         * |             |            |                  |         |becomes active by the MATCH1 signal.                     |
         * |             |            |                  +---------+---------------------------------------------------------+
         * |             |            |                  |TOUTnm+1 |The signal becomes inactive by the MATCHm+1 signal and   |
         * |             |            |                  |         |it becomes active by the MATCH0 signal.                  |
         * +-------------+------------+------------------+---------+---------------------------------------------------------+
         * |    0x6      |Toggle/set mode                                                                                    |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     0      |Up count mode     |TOUTnm   |The signal is inverted by the MATCH signal and it becomes|
         * |             |            |Up/down count mode|         |active by the MAX signal.                                |
         * |             |            +------------------+---------+---------------------------------------------------------+
         * |             |            |Down count mode   |TOUTnm   |The signal is inverted by the MATCH signal and it becomes|
         * |             |            |                  |         |active by the ZERO signal.                               |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     1      |All count modes   |TOUTnm   |The signal is inverted by the MATCHm signal and it       |
         * |             |            |                  |         |becomes active by the MATCHm+1 signal.                   |
         * |             |            |                  +---------+---------------------------------------------------------+
         * |             |            |                  |TOUTnm+1 |The signal is inverted by the MATCHm+1 signal and it     |
         * |             |            |                  |         |becomes active by the MATCHm signal.                     |
         * +-------------+------------+------------------+---------+---------------------------------------------------------+
         * |    0x5      |Reset mode                                                                                         |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     0      |All count modes   |TOUTnm   |The signal becomes inactive by the MATCH signal.         |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     1      |All count modes   |TOUTnm   |The signal becomes inactive by the MATCHm or MATCHm+1    |
         * |             |            |                  |         |signal.                                                  |
         * |             |            |                  +---------+---------------------------------------------------------+
         * |             |            |                  |TOUTnm+1 |The signal becomes inactive by the MATCHm+1 or           |
         * |             |            |                  |         |MATCHm signal.                                           |
         * +-------------+------------+------------------+---------+---------------------------------------------------------+
         * |    0x4      |Toggle mode                                                                                        |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     0      |All count modes   |TOUTnm   |The signal is inverted by the MATCH signal.              |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     1      |All count modes   |TOUTnm   |The signal is inverted by the MATCHm or MATCHm+1 signal. |
         * |             |            |                  +---------+---------------------------------------------------------+
         * |             |            |                  |TOUTnm+1 |The signal is inverted by the MATCHm+1 or MATCHm signal. |
         * +-------------+------------+------------------+---------+---------------------------------------------------------+
         * |    0x3      |Set/reset mode                                                                                     |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     0      |Up count mode     |TOUTnm   |The signal becomes active by the MATCH signal and it     |
         * |             |            |Up/down count mode|         |becomes inactive by the MAX signal.                      |
         * |             +            +------------------+---------+---------------------------------------------------------+
         * |             |            |Down count mode   |TOUTnm   |The signal becomes active by the MATCH signal and it     |
         * |             |            |                  |         |becomes inactive by the ZERO signal.                     |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     1      |All count modes   |TOUTnm   |The signal becomes active by the MATCHm signal and it    |
         * |             |            |                  |         |becomes inactive by the MATCHm+1 signal.                 |
         * |             |            |                  +---------+---------------------------------------------------------+
         * |             |            |                  |TOUTnm+1 |The signal becomes active by the MATCHm+1 signal and it  |
         * |             |            |                  |         |becomes inactive by the MATCHm signal.                   |
         * +-------------+------------+------------------+---------+---------------------------------------------------------+
         * |    0x2      |Toggle/reset mode                                                                                  |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     0      |Up count mode     |TOUTnm   |The signal is inverted by the MATCH signal and it        |
         * |             |            |Up/down count mode|         |becomes inactive by the MAX signal.                      |
         * |             +            +------------------+---------+---------------------------------------------------------+
         * |             |            |Down count mode   |TOUTnm   |The signal is inverted by the MATCH signal and it        |
         * |             |            |                  |         |becomes inactive by the ZERO signal.                     |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     1      |All count modes   |TOUTnm   |The signal is inverted by the MATCHm signal and it       |
         * |             |            |                  |         |becomes inactive by the MATCHm+1 signal.                 |
         * |             |            |                  +---------+---------------------------------------------------------+
         * |             |            |                  |TOUTnm+1 |The signal is inverted by the MATCHm+1 signal and it     |
         * |             |            |                  |         |becomes inactive by the MATCHm signal.                   |
         * +-------------+------------+------------------+---------+---------------------------------------------------------+
         * |    0x1      |Set mode                                                                                           |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     0      |All count modes   |TOUTnm   |The signal becomes active by the MATCH signal.           |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     1      |All count modes   |TOUTnm   |The signal becomes active by the MATCHm or MATCHm+1      |
         * |             |            |                  |         |signal.                                                  |
         * |             |            |                  +---------+---------------------------------------------------------+
         * |             |            |                  |TOUTnm+1 |The signal becomes active by the MATCHm+1 or MATCHm      |
         * |             |            |                  |         |signal.                                           |
         * +-------------+------------+------------------+---------+---------------------------------------------------------+
         * |    0x0      |Software control mode                                                                              |
         * |             +------------+------------------+---------+---------------------------------------------------------+
         * |             |     *      |All count modes   |TOUTnm   |The signal becomes active by setting the T16BnCCCTLm.    |
         * |             |            |                  |         |TOUTO bit to 1 and it becomes inactive by setting to 0.  |
         * +-------------+------------+------------------+---------+---------------------------------------------------------+
         */
        unsigned short      TOUTMD      : 3;
        /**
         * This bit sets the TOUT00 signal output level
         * .TOUTO
         *  This bit sets the TOUTnm signal output level when software control mode
         *  (T16BnCCCTLm.TOUTMD[2:0] = 0x0) is selected for the TOUTnm output.
         *    1 (R/W): High level output
         *    0 (R/W): Low level output
         */
        unsigned short      TOUTO       : 1;
        /**
         * This bit selects whether the comparator equal signal.
         * .TOUTMT
         *  This bit selects whether the comparator MATCH signal of another system is used for generating the TOUTnm signal or not.
         *    1 (R/W): Generate TOUT using two comparator MATCH signals of the comparator circuit pair (0 and 1, 2 and 3, 4 and 5)
         *    0 (R/W): Generate TOUT using one comparator MATCH signal of comparator m and the counter MAX or ZERO signals
         */
        unsigned short      TOUTMT      : 1;
        unsigned short      reserved_1  : 1;    ///< Reserved.
        /**
         * These bits select the trigger edge(s) of the trigger signal.
         * .CAPTRG[2:0]
         *  These bits select the trigger edge(s) of the trigger signal at which the counter value is captured
         *  in the T16BnCCRm register in capture mode.
         * .CAPIS[1:0]
         *  These bits select the trigger signal for capturing.
         * +----------------------+------------------------------------------------------------------------------------------------------------------+
         * |                      |                                                Trigger condition                                                 |
         * |                      +------------------------------------------------------------------------------------------------------------------+
         * |  CAPTRG[1:0]         |                                       CAPIS[1:0] (Trigger signal)                                                |
         * |(Trigger edge)        +----------------------------------------------+---------------------------------+---------------------------------+
         * |                      |        0x0 (External trigger signal)         | 0x2 (Software trigger signal=L) | 0x3 (Software trigger signal=H) |
         * +----------------------+----------------------------------------------+---------------------------------+---------------------------------+
         * |  0x3(Rising&Falling) |Rising or falling edge of the CAPnm pin input |Altering the T16BnCCCTLm.CAPIS[1:0]bits from 0x2 to 0x3, or        |
         * |                      |signal                                        |from 0x3 to 0x2                                                    |
         * +----------------------+----------------------------------------------+-------------------------------------------------------------------+
         * |  0x2(Falling)        |Falling edge of the CAPnm pin input signal    |Altering the T16BnCCCTLm.CAPIS[1:0]bits from 0x3 to 0x2            |
         * +----------------------+----------------------------------------------+-------------------------------------------------------------------+
         * |  0x1(Rising)         |Rising edge of the CAPnm pin input signal     |Altering the T16BnCCCTLm.CAPIS[1:0]bits from 0x2 to 0x3            |
         * +----------------------+----------------------------------------------+-------------------------------------------------------------------+
         * |  0x0                 |                                     Not triggered (disable capture function)                                     |
         * +----------------------+------------------------------------------------------------------------------------------------------------------+
         */
        unsigned short      CAPTRG      : 2;
        /**
         * These bits select the trigger signal for capturing.
         * .CAPTRG[2:0]
         *  These bits select the trigger edge(s) of the trigger signal at which the counter value is captured
         *  in the T16BnCCRm register in capture mode.
         * .CAPIS[1:0]
         *  These bits select the trigger signal for capturing.
         * +----------------------+------------------------------------------------------------------------------------------------------------------+
         * |                      |                                                Trigger condition                                                 |
         * |                      +------------------------------------------------------------------------------------------------------------------+
         * |  CAPTRG[1:0]         |                                       CAPIS[1:0] (Trigger signal)                                                |
         * |(Trigger edge)        +----------------------------------------------+---------------------------------+---------------------------------+
         * |                      |        0x0 (External trigger signal)         | 0x2 (Software trigger signal=L) | 0x3 (Software trigger signal=H) |
         * +----------------------+----------------------------------------------+---------------------------------+---------------------------------+
         * |  0x3(Rising&Falling) |Rising or falling edge of the CAPnm pin input |Altering the T16BnCCCTLm.CAPIS[1:0]bits from 0x2 to 0x3, or        |
         * |                      |signal                                        |from 0x3 to 0x2                                                    |
         * +----------------------+----------------------------------------------+-------------------------------------------------------------------+
         * |  0x2(Falling)        |Falling edge of the CAPnm pin input signal    |Altering the T16BnCCCTLm.CAPIS[1:0]bits from 0x3 to 0x2            |
         * +----------------------+----------------------------------------------+-------------------------------------------------------------------+
         * |  0x1(Rising)         |Rising edge of the CAPnm pin input signal     |Altering the T16BnCCCTLm.CAPIS[1:0]bits from 0x2 to 0x3            |
         * +----------------------+----------------------------------------------+-------------------------------------------------------------------+
         * |  0x0                 |                                     Not triggered (disable capture function)                                     |
         * +----------------------+------------------------------------------------------------------------------------------------------------------+
         */
        unsigned short      CAPIS       : 2;
        /**
         * These bits select the timing to load the comparison value written.
         * .CBUFMD[2:0]
         *  These bits select the timing to load the comparison value written in the T16BnCCRm register to the compare buffer.
         * +-------------+------------+------------------------------------------------------------------------+
         * | CBUFMD[2:0] | Count mode |                      Comparison Value load timing                      |
         * +-------------+------------+------------------------------------------------------------------------+
         * |    0x7-0x5  |                                      Reserved                                       |
         * +-------------+------------+------------------------------------------------------------------------+
         * |     0x4     |Up mode     |When the counter becomes equal to the comparison value set previously   |
         * |             |            |Also the counter is reset to 0x0000 simultaneously.                     |
         * |             +------------+------------------------------------------------------------------------+
         * |             |Down mode   |When the counter becomes equal to the comparison value set previously   |
         * |             |            |Also the counter is reset to the MAX value simultaneously.              |
         * |             +------------+------------------------------------------------------------------------+
         * |             |Up/down mode|When the counter becomes equal to the comparison value set previously   |
         * |             |            |Also the counter is reset to 0x0000 simultaneously.                     |
         * +-------------+------------+------------------------------------------------------------------------+
         * |     0x3     |Up mode     |When the counter reverts to 0x0000                                      |
         * |             +------------+------------------------------------------------------------------------+
         * |             |Down mode   |When the counter reverts to the MAX value                               |
         * |             +------------+------------------------------------------------------------------------+
         * |             |Up/down mode|When the counter becomes equal to the comparison value set previously or|
         * |             |            |when the counter reverts to 0x0000                                      |
         * +-------------+------------+------------------------------------------------------------------------+
         * |     0x2     |Up mode     |When the counter becomes equal to the comparison value set previously   |
         * |             +------------+                                                                        |
         * |             |Down mode   |                                                                        |
         * |             +------------+                                                                        |
         * |             |Up/down mode|                                                                        |
         * +-------------+------------+------------------------------------------------------------------------+
         * |     0x1     |Up mode     |When the counter reaches the MAX value                                  |
         * |             +------------+------------------------------------------------------------------------+
         * |             |Down mode   |When the counter reaches 0x0000                                         |
         * |             +------------+------------------------------------------------------------------------+
         * |             |Up/down mode|When the counter reaches 0x0000 or the MAX value                        |
         * +-------------+------------+------------------------------------------------------------------------+
         * |     0x0     |Up mode     |At the CLK_16Bn rising edge after writing to the T16BnCCRm register     |
         * |             +------------+                                                                        |
         * |             |Down mode   |                                                                        |
         * |             +------------+                                                                        |
         * |             |Up/down mode|                                                                        |
         * +-------------+------------+------------------------------------------------------------------------+
         */
        unsigned short      CBUFMD      : 3;
        /**
         * This bit selects either synchronous capture mode or asynchronous capture mode.
         * .SCS
         *  This bit selects either synchronous capture mode or asynchronous capture mode.
         *    1 (R/W): Synchronous capture mode
         *    0 (R/W): Asynchronous capture mode
         */
        unsigned short      SCS         : 1;
    } bit;
    unsigned char   byte_reg[2];
} T16BNCCCTLM_REG;

/// T16B Ch.N Compare/Capture M Data Register.
typedef union T16BNCCRM_REG_TAG {
    unsigned short  reg;
    struct T16BNCCRM_REG_BIT_TAG {
        /**
         * T16B Ch.n Compare/Capture m Data Register
         * .CC[15:0]
         *  In comparator mode, this register is configured as the compare data register and used to set the comparison value to be compared with the counter value.
         */
        unsigned short      CC          :16;
    } bit;
    unsigned char   byte_reg[2];
} T16BNCCRM_REG;

#ifdef __cplusplus
}
#endif

#endif // T16B_REG_H__
