/************************************************************************//**
 *
 * @file    boot.c
 *
 * @brief   This is vector and interrupt program with C.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ******************************************************************************/
#include <c17_mcu_select.h>
#include "crt0.h"
#include "c17_misc.h"

/* --- function declaration --- */

void _init_device( void);

/* --- stack pointer --- */
C17_INITIAL_STACK_POINTER(0x7C0);

/* --- Non-Maskable Interrupts --- */
C17_INTERRUPT_HANDLER(_vector01_handler, intAddrErr);	// Address misaligned

/****************************************************************************
 * _init_device function.
 *
 * @brief	Initialize device module.
 ***************************************************************************/
void _init_device(void)
{
	/// Initialize module.
	c17setFlashcAccessCycle(0x1);	/// Set RDWAIT = 2cycle (12.6MHz max)

	return;
}


/****************************************************************************
 * intAddrErr function.
 *
 * @brief	Interrupt handler for "Address misaligned".
 ***************************************************************************/
void intAddrErr(void)
{
	/// Undecid processing.
	asm("halt");
}


