/************************************************************************//**
 *
 * @file    c17_init_config.h
 * @brief   This is initialize macro header.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ***************************************************************************/
#ifndef C17_INIT_CONFIG_H_
#define C17_INIT_CONFIG_H_


#define C17_PE_LCD8A
#define C17_PE_PORT
#define C17_PE_REMC
#define C17_PE_RTCA
#define C17_PE_SVD
#define C17_PE_T16
#define C17_PE_T16B
#define C17_PE_UART
#define C17_PE_WDT

/// --- BEGIN CLG Setting ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_CLG	(3)			/// Set CLG interrupt level  0 to 7


/// --- END CLG Setting ---



/// --- BEGIN LCD8A Setting ---

/**
 * Internal definition macro
 * Do not change.
 */
#define LCD_enable				(1)			/// --- Do not change. ---
#define LCD_disable				(0)			/// --- Do not change. ---
#define LCD_IOSC				(0)			/// --- Do not change. ---
#define LCD_OSC1				(1)			/// --- Do not change. ---
#define LCD_OSC3				(2)			/// --- Do not change. ---
#define LCD_EXT					(3)			/// --- Do not change. ---
#define LCD_CLKDIV_1			(0)			/// --- Do not change. ---
#define LCD_CLKDIV_IOSC_4		(0)			/// --- Do not change. ---
#define LCD_CLKDIV_IOSC_8		(1)			/// --- Do not change. ---
#define LCD_CLKDIV_IOSC_16		(2)			/// --- Do not change. ---
#define LCD_CLKDIV_IOSC_32		(3)			/// --- Do not change. ---
#define LCD_CLKDIV_IOSC_64		(4)			/// --- Do not change. ---
#define LCD_CLKDIV_IOSC_128		(5)			/// --- Do not change. ---
#define LCD_CLKDIV_OSC3_16		(0)			/// --- Do not change. ---
#define LCD_CLKDIV_OSC3_32		(1)			/// --- Do not change. ---
#define LCD_CLKDIV_OSC3_64		(2)			/// --- Do not change. ---
#define LCD_CLKDIV_OSC3_128		(3)			/// --- Do not change. ---
#define LCD_CLKDIV_OSC3_256		(4)			/// --- Do not change. ---
#define LCD_CLKDIV_OSC3_512		(5)			/// --- Do not change. ---
#define LCD_INIT(a, b, c)	(((LCD_##a) << 5) + ((LCD_##b) << 3) + (LCD_##c))	/// --- Do not change. ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_LCD8A	(3)			/// Set LCD8A interrupt level  0 to 7

/**
 * LCD8A Setting
 * Please change the argument, if necessary.
 *  - 1st:Module activate(enable,disable)
 *  - 2nd:Clock source(IOSC,OSC1,OSC3,EXT)
 *  - 3rd:Clock division
 *          IOSC,OSC3(CLKDIV_xx:16,32,64,128,256,512)
 *          OSC1,EXT(CLKDIV_1)
 *
 * example.
 * #define LCD8A_INIT LCD_INIT(enable, IOSC, CLKDIV_16)
 */

#define LCD8A_INIT LCD_INIT(enable, OSC1, CLKDIV_1)

/// --- END LCD8A Setting ---


/// --- BEGIN PORT Setting ---

/**
 * Internal definition macro
 * Do not change.
 */

#define PORT_enable				(1)			/// --- Do not change. ---
#define PORT_disable			(0)			/// --- Do not change. ---
#define PORT_input				(0)			/// --- Do not change. ---
#define PORT_output				(1)			/// --- Do not change. ---
#define PORT_chatta_enable		(1)			/// --- Do not change. ---
#define PORT_chatta_disable		(0)			/// --- Do not change. ---
#define PORT_none				(0)			/// --- Do not change. ---
#define PORT_pullup				(1)			/// --- Do not change. ---
#define PORT_pulldown			(2)			/// --- Do not change. ---
#define PORT_INIT(a, b, c, d)	(((PORT_##a) << 7) + ((PORT_##b) << 6) + ((PORT_##c) << 5) + (PORT_##d))	/// --- Do not change. ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_PORT	(3)			/// Set PORT interrupt level  0 to 7

/// --- END PORT Setting ---



/// --- BEGIN REMC Setting ---

/**
 * Internal definition macro
 * Do not change.
 */

#define REMC_IOSC				(0)			/// --- Do not change. ---
#define REMC_OSC1				(1)			/// --- Do not change. ---
#define REMC_OSC3				(2)			/// --- Do not change. ---
#define REMC_EXT				(3)			/// --- Do not change. ---
#define REMC_repeat				(0)			/// --- Do not change. ---
#define REMC_oneshot			(1)			/// --- Do not change. ---
#define REMC_CLKDIV_1			(0)			/// --- Do not change. ---
#define REMC_CLKDIV_2			(1)			/// --- Do not change. ---
#define REMC_CLKDIV_4			(2)			/// --- Do not change. ---
#define REMC_CLKDIV_8			(3)			/// --- Do not change. ---
#define REMC_CLKDIV_16			(4)			/// --- Do not change. ---
#define REMC_CLKDIV_32			(5)			/// --- Do not change. ---
#define REMC_CLKDIV_64			(6)			/// --- Do not change. ---
#define REMC_CLKDIV_128			(7)			/// --- Do not change. ---
#define REMC_CLKDIV_256			(8)			/// --- Do not change. ---
#define REMC_CLKDIV_512			(9)			/// --- Do not change. ---
#define REMC_CLKDIV_1024		(10)		/// --- Do not change. ---
#define REMC_CLKDIV_2048		(11)		/// --- Do not change. ---
#define REMC_CLKDIV_4096		(12)		/// --- Do not change. ---
#define REMC_CLKDIV_8192		(13)		/// --- Do not change. ---
#define REMC_CLKDIV_16384		(14)		/// --- Do not change. ---
#define REMC_CLKDIV_32768		(15)		/// --- Do not change. ---
#define REMC_INIT(a, b, c)	(((REMC_##a) << 6) + ((REMC_##c) << 5)  + (REMC_##b))	/// --- Do not change. ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_REMC	(3)				/// Set REMC interrupt level  0 to 7
/**
 * @todo Change frequency specified in REMC_INIT
 */
#define REMC_CLOCK				(3UL)		/// REMC operating clock frequency[MHz]
														/// REMC_CLOCK = Clock source frequency / Clock division = 12MHz /4 = 3
														/// Clock source and the clock division is set in the REMC_INIT macro.


/**
 * REMC Setting
 * Please change the argument, if necessary.
 *  - 1st:Clock source(IOSC,OSC1,OSC3,EXT)
 *  - 2nd:Clock division
 *          IOSC,OSC3(CLKDIV_xx:1,2,4,8,16,32,64,128,256,512,1024,2048,4096,8192,16384,32768)
 *          OSC1(CLKDIV_xx:1,2,4,8,16,32,64,128,256)
 *          EXT(CLKDIV_1)
 *  - 3rd:Mode(repeat,oneshot)
 *
 * example.
 * #define REMC_SET_INIT REMC_INIT(OSC3, CLKDIV_4, repeat)
 */

#define REMC_SET_INIT REMC_INIT(OSC3, CLKDIV_4, repeat)

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */
/// Transmission bit order
#define REMC_BITORDER_MSBFIRST	0
#define REMC_BITORDER_LSBFIRST	1
#define REMC_BITORDER REMC_BITORDER_LSBFIRST


/// --- END REMC Setting ---

/// --- BEGIN RTCA Setting ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_RTCA	(4)				/// Set RTCA interrupt level  0 to 7


#define THEORETICAL_ENABLE		(1)				/// Theoretical Regulation enable = 1,disable = 0.
#define THEORETICAL_CYCLE_TIME	(4096)			/// Theoretical regulation execution cycle time n [sec]
#define THEORETICAL_TRIM		(0x43)			/// Correction rate : 0x43=(-58.2 ppm). 0x00 to 0x7f

/// --- END RTCA Setting ---


/// --- BEGIN SVD3 Setting ---


/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_SVD	(3)			/// Set SVD interrupt level  0 to 7


/// --- END SVD3 Setting ---


/// --- BEGIN T16 Setting ---

/**
 * Internal definition macro
 * Do not change.
 */

#define T16_enable				(1)			/// --- Do not change. ---
#define T16_disable				(0)			/// --- Do not change. ---
#define T16_IOSC				(0)			/// --- Do not change. ---
#define T16_OSC1				(1)			/// --- Do not change. ---
#define T16_OSC3				(2)			/// --- Do not change. ---
#define T16_EXT					(3)			/// --- Do not change. ---
#define T16_repeat				(0)			/// --- Do not change. ---
#define T16_oneshot				(1)			/// --- Do not change. ---
#define T16_CLKDIV_1			(0)			/// --- Do not change. ---
#define T16_CLKDIV_2			(1)			/// --- Do not change. ---
#define T16_CLKDIV_4			(2)			/// --- Do not change. ---
#define T16_CLKDIV_8			(3)			/// --- Do not change. ---
#define T16_CLKDIV_16			(4)			/// --- Do not change. ---
#define T16_CLKDIV_32			(5)			/// --- Do not change. ---
#define T16_CLKDIV_64			(6)			/// --- Do not change. ---
#define T16_CLKDIV_128			(7)			/// --- Do not change. ---
#define T16_CLKDIV_256			(8)			/// --- Do not change. ---
#define T16_CLKDIV_512			(9)			/// --- Do not change. ---
#define T16_CLKDIV_1024			(10)		/// --- Do not change. ---
#define T16_CLKDIV_2048			(11)		/// --- Do not change. ---
#define T16_CLKDIV_4096			(12)		/// --- Do not change. ---
#define T16_CLKDIV_8192			(13)		/// --- Do not change. ---
#define T16_CLKDIV_16384		(14)		/// --- Do not change. ---
#define T16_CLKDIV_32768		(15)		/// --- Do not change. ---
#define T16_INIT(a, b, c, d)	(((T16_##a) << 7) + ((T16_##b) << 5) + ((T16_##d) << 4) + (T16_##c))	/// --- Do not change. ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */

#define INTERRUPT_LEVEL_T16_0	(3)			/// Set T16 CH.0 interrupt level  0 to 7
#define INTERRUPT_LEVEL_T16_1	(3)			/// Set T16 CH.1 interrupt level  0 to 7
#define INTERRUPT_LEVEL_T16_2	(3)			/// Set T16 CH.2 interrupt level  0 to 7
#define INTERRUPT_LEVEL_T16_3	(3)			/// Set T16 CH.3 interrupt level  0 to 7

#define T16CH0_DISABLE_ENTERRUPT_HANDLER	(1)
#define T16CH1_DISABLE_ENTERRUPT_HANDLER	(1)
#define T16CH2_DISABLE_ENTERRUPT_HANDLER	(1)

#define T16CH0_COUNT		(32)
#define T16CH1_COUNT		(32)
#define T16CH2_COUNT		(32)

/**
 * T16 Setting
 * Please change the argument, if necessary.
 *  - 1st:Module activate(enable,disable)
 *  - 2nd:Clock source(IOSC,OSC1,OSC3,EXT)
 *  - 3rd:Clock division
 *          IOSC,OSC3(CLKDIV_xx:1,2,4,8,16,32,64,128,256,512,1024,2048,4096,8192,16384,32768)
 *          OSC1(CLKDIV_xx:1,2,4,8,16,32,64,128,256)
 *          EXT(CLKDIV_1)
 *  - 4th:Mode(repeat,oneshot)
 *
 * example.
 * #define T16CH0_INIT T16_INIT(enable, IOSC, CLKDIV_32, oneshot)
 */

#define T16CH0_INIT T16_INIT(enable,  OSC1, CLKDIV_1,  repeat)
#define T16CH1_INIT T16_INIT(enable,  OSC1, CLKDIV_1,  repeat)
#define T16CH2_INIT T16_INIT(enable,  OSC1, CLKDIV_1, repeat)
#define T16CH3_INIT T16_INIT(disable, IOSC, CLKDIV_1,  repeat)

/// --- END T16 Setting ---


/// --- BEGIN T16B Setting ---

/**
 * Internal definition macro
 * Do not change.
 */

#define T16B_enable				(1)			/// --- Do not change. ---
#define T16B_disable			(0)			/// --- Do not change. ---
#define T16B_IOSC				(0)			/// --- Do not change. ---
#define T16B_OSC1				(1)			/// --- Do not change. ---
#define T16B_OSC3				(2)			/// --- Do not change. ---
#define T16B_EXT				(3)			/// --- Do not change. ---
#define T16B_EXCL0				(4)			/// --- Do not change. ---
#define T16B_EXCL1				(5)			/// --- Do not change. ---
#define T16B_EXCL0INV			(6)			/// --- Do not change. ---
#define T16B_EXCL1INV			(7)			/// --- Do not change. ---
#define T16B_up					(0)			/// --- Do not change. ---
#define T16B_down				(1)			/// --- Do not change. ---
#define T16B_updown				(2)			/// --- Do not change. ---
#define T16B_repeat				(0)			/// --- Do not change. ---
#define T16B_oneshot			(1)			/// --- Do not change. ---
#define T16B_CLKDIV_1			(0)			/// --- Do not change. ---
#define T16B_CLKDIV_2			(1)			/// --- Do not change. ---
#define T16B_CLKDIV_4			(2)			/// --- Do not change. ---
#define T16B_CLKDIV_8			(3)			/// --- Do not change. ---
#define T16B_CLKDIV_16			(4)			/// --- Do not change. ---
#define T16B_CLKDIV_32			(5)			/// --- Do not change. ---
#define T16B_CLKDIV_64			(6)			/// --- Do not change. ---
#define T16B_CLKDIV_128			(7)			/// --- Do not change. ---
#define T16B_CLKDIV_256			(8)			/// --- Do not change. ---
#define T16B_CLKDIV_512			(9)			/// --- Do not change. ---
#define T16B_CLKDIV_1024		(10)		/// --- Do not change. ---
#define T16B_CLKDIV_2048		(11)		/// --- Do not change. ---
#define T16B_CLKDIV_4096		(12)		/// --- Do not change. ---
#define T16B_CLKDIV_8192		(13)		/// --- Do not change. ---
#define T16B_CLKDIV_16384		(14)		/// --- Do not change. ---
#define T16B_CLKDIV_32768		(15)		/// --- Do not change. ---
#define T16B_INIT(a, b, c, d, e)(((T16B_##a) << 10) + ((T16B_##b) << 7) + ((T16B_##d) << 5) + ((T16B_##e) << 4) + (T16B_##c))	/// --- Do not change. ---


/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */
#define INTERRUPT_LEVEL_T16B_0	(2)			/// Set T16B CH.0 interrupt level  0 to 7



/**
 * T16B Setting
 * Please change the argument, if necessary.
 *  - 1st:Module activate(enable,disable)
 *  - 2nd:Clock source(IOSC,OSC1,OSC3,EXT,EXCL0,EXCL1,EXCL0INV,EXCL1INV)
 *  - 3rd:Clock division
 *          IOSC,OSC3(CLKDIV_xx:1,2,4,8,16,32,64,128,256,512,1024,2048,4096,8192,16384,32768)
 *          OSC1(CLKDIV_xx:1,2,4,8,16,32,64,128,256)
 *          EXT,EXCL0,EXCL1,EXCL0INV,EXCL1INV(CLKDIV_1)
 *  - 4th:Count mode(up,down,updown)
 *  - 5th:Mode(repeat,oneshot)
 *
 * example.
 * #define T16BCH0_INIT T16B_INIT(enable, IOSC, CLKDIV_32, up, repeat)
 */

#define T16BCH0_INIT T16B_INIT(enable, OSC1, CLKDIV_1, up, repeat)

/// --- END T16B Setting ---

/// --- BEGIN UART3 Setting ---

/**
 * Internal definition macro
 * Do not change.
 */
#define UART_IOSC				(0)			/// --- Do not change. ---
#define UART_OSC1				(1)			/// --- Do not change. ---
#define UART_OSC3				(2)			/// --- Do not change. ---
#define UART_EXT				(3)			/// --- Do not change. ---
#define UART_CLKDIV_1			(0)			/// --- Do not change. ---
#define UART_CLKDIV_2			(1)			/// --- Do not change. ---
#define UART_CLKDIV_4			(2)			/// --- Do not change. ---
#define UART_CLKDIV_8			(3)			/// --- Do not change. ---
#define UART_parity_none		(0)			/// --- Do not change. ---
#define UART_parity_odd			(1)			/// --- Do not change. ---
#define UART_parity_even		(2)			/// --- Do not change. ---
#define UART_stop_2				(1)			/// --- Do not change. ---
#define UART_stop_1				(0)			/// --- Do not change. ---
#define UART_data_8				(1)			/// --- Do not change. ---
#define UART_data_7				(0)			/// --- Do not change. ---
#define UART_INIT(a, b, c, d, e)	(((UART_##a) << 6) + ((UART_##b) << 4) + ((UART_##c) << 2) + ((UART_##d) << 1) + (UART_##e))	/// --- Do not change. ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */
#define UART_CLOCK				(12000000)		/// Uart Clock source frequency(OSC3=12000000Hz)
												/// CLK_UART3 = UART_CLOCK / [Clock division]
												/// Clock source and the clock division is set in the UARTCHx_INIT macro.
#define UART_BSP				(9600)			/// Set UART BPS example (9600,19200,.,115200,.)


#define INTERRUPT_LEVEL_UART	(3)				/// Set UART interrupt level  0 to 7

#define IOSC_CALIBRATION_ENABLE	(0)				/**
												 * calibration enable = 1,calibration disable = 0
												 * If the UART clock source of the IOSC,
												 * to adjust the baud rate using the other clock(OSC3 or OSC1).
												 */
#if defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34)
#define IOSC_CALIBRATION_CLOCK	(32768)		/// clock source frequency(ex. OSC1 = 32768Hz)
#endif

#if defined(C17_MCUSEL_M31)
#define IOSC_CALIBRATION_CLOCK	(4000000)		/// clock source frequency(ex. OSC3 = 4000000Hz)
#endif


/**
 * UART Setting
 * Please change the argument, if necessary.
 *  - 1st:Clock source(IOSC,OSC1,OSC3,EXT)
 *  - 2nd:Clock division
 *          IOSC,OSC3(CLKDIV_xx:1,2,4,8)
 *          OSC1,EXT(CLKDIV_1)
 *  - 3rd:Parity mode(parity_none,parity_odd,parity_even)
 *  - 4th:Stop bit length(stop_2,stop_1)
 *  - 5th:Data bit length(data_7,data_8)
 *
 * example.
 * #define UARTCH0_INIT UART_INIT(IOSC,CLKDIV_1,parity_none,stop_1,data_8)
 */

#define UARTCH0_INIT UART_INIT(OSC3, CLKDIV_8, parity_none, stop_1, data_8)


/// --- END UART3 Setting ---


#endif /* C17_INIT_CONFIG_H_ */

