/************************************************************************//**
 *
 * @file    c17_lcd8a_1.h
 *
 * @brief   This is LCD8A driver header file.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ***************************************************************************/
#ifndef C17_LCD8A_H__
#define C17_LCD8A_H__

#include <c17_mcu_select.h>

/* --- definition --- */
enum
{
	C17_LCD_CLKSRC_IOSC,				///< Clock Source = IOSC
	C17_LCD_CLKSRC_OSC1,				///< Clock Source = OSC1
	C17_LCD_CLKSRC_OSC3,				///< Clock Source = OSC3
	C17_LCD_CLKSRC_EXT					///< Clock Source = External OSC
};

enum
{
	C17_LCD_CLKDIV_16,					///< Clock Division = 1/16
	C17_LCD_CLKDIV_32,					///< Clock Division = 1/32
	C17_LCD_CLKDIV_64,					///< Clock Division = 1/64
	C17_LCD_CLKDIV_128,					///< Clock Division = 1/128
	C17_LCD_CLKDIV_256,					///< Clock Division = 1/256
	C17_LCD_CLKDIV_512,					///< Clock Division = 1/512
	C17_LCD_CLKDIV_1					///< Clock Division = 1/1
};

enum
{
	C17_LCD_CLKDIV_OSC3_16,				///< Clock Division = 1/16
	C17_LCD_CLKDIV_OSC3_32,				///< Clock Division = 1/32
	C17_LCD_CLKDIV_OSC3_64,				///< Clock Division = 1/64
	C17_LCD_CLKDIV_OSC3_128,			///< Clock Division = 1/128
	C17_LCD_CLKDIV_OSC3_256,			///< Clock Division = 1/256
	C17_LCD_CLKDIV_OSC3_512				///< Clock Division = 1/512
};

enum
{
	C17_LCD_CLKDIV_IOSC_4,				///< Clock Division = 1/4
	C17_LCD_CLKDIV_IOSC_8,				///< Clock Division = 1/8
	C17_LCD_CLKDIV_IOSC_16,				///< Clock Division = 1/16
	C17_LCD_CLKDIV_IOSC_32,				///< Clock Division = 1/32
	C17_LCD_CLKDIV_IOSC_64,				///< Clock Division = 1/64
	C17_LCD_CLKDIV_IOSC_128				///< Clock Division = 1/128
};

enum
{
	C17_LCD_STATE_OFF,					///< Mode : Display off.
	C17_LCD_STATE_NORMAL,				///< Mode : Normal display.
	C17_LCD_STATE_ALL_ON,				///< Mode : All on.
	C17_LCD_STATE_ALL_OFF				///< Mode : All off.
};

enum
{
	C17_LCD_DISPLAY_AREA0,				///< Area : Display Area 0.
	C17_LCD_DISPLAY_AREA1				///< Area : Display Area 1.
};

enum
{
	C17_LCD_DISPLAY_INVERTED,			///< Inverted display
	C17_LCD_DISPLAY_NORMAL				///< Normal display
};

// Display Memory Address.
#define	LCD8A_SEGRAM_TOP_ADDR		( 0x7000 )			///< The display data RAM address.
#define	LCD8A_SEGRAM_TOP_ADDR_AREA0	(0x7000) 			///< The display data RAM address(Area0).
#define	LCD8A_SEGRAM_TOP_ADDR_AREA1	(0x7040) 			///< The display data RAM address(Area1).
#if defined(C17_MCUSEL_M01)
#define	LCD8A_SEGRAM_SIZE		( 0x20 )						///< The display data RAM size.
#endif
#if defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34)
#define	LCD8A_SEGRAM_SIZE		( 0x32 )						///< The display data RAM size.
#endif

#define	LCD8A_SEG_00_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x00)	///< SEG  0 address.
#define	LCD8A_SEG_01_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x01)	///< SEG  1 address.
#define	LCD8A_SEG_02_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x02)	///< SEG  2 address.
#define	LCD8A_SEG_03_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x03)	///< SEG  3 address.
#define	LCD8A_SEG_04_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x04)	///< SEG  4 address.
#define	LCD8A_SEG_05_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x05)	///< SEG  5 address.
#define	LCD8A_SEG_06_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x06)	///< SEG  6 address.
#define	LCD8A_SEG_07_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x07)	///< SEG  7 address.
#define	LCD8A_SEG_08_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x08)	///< SEG  8 address.
#define	LCD8A_SEG_09_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x09)	///< SEG  9 address.
#define	LCD8A_SEG_10_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x0A)	///< SEG 10 address.
#define	LCD8A_SEG_11_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x0B)	///< SEG 11 address.
#define	LCD8A_SEG_12_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x0C)	///< SEG 12 address.
#define	LCD8A_SEG_13_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x0D)	///< SEG 13 address.
#define	LCD8A_SEG_14_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x0E)	///< SEG 14 address.
#define	LCD8A_SEG_15_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x0F)	///< SEG 15 address.
#define	LCD8A_SEG_16_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x10)	///< SEG 16 address.
#define	LCD8A_SEG_17_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x11)	///< SEG 17 address.
#define	LCD8A_SEG_18_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x12)	///< SEG 18 address.
#define	LCD8A_SEG_19_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x13)	///< SEG 19 address.
#define	LCD8A_SEG_20_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x14)	///< SEG 20 address.
#define	LCD8A_SEG_21_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x15)	///< SEG 21 address.
#define	LCD8A_SEG_22_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x16)	///< SEG 22 address.
#define	LCD8A_SEG_23_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x17)	///< SEG 23 address.
#define	LCD8A_SEG_24_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x18)	///< SEG 24 address.
#define	LCD8A_SEG_25_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x19)	///< SEG 25 address.
#define	LCD8A_SEG_26_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x1A)	///< SEG 26 address.
#define	LCD8A_SEG_27_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x1B)	///< SEG 27 address.
#define	LCD8A_SEG_28_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x1C)	///< SEG 28 address.
#define	LCD8A_SEG_29_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x1D)	///< SEG 29 address.
#define	LCD8A_SEG_30_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x1E)	///< SEG 30 address.
#define	LCD8A_SEG_31_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x1F)	///< SEG 31 address.
#if defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34)
#define	LCD8A_SEG_32_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x20)	///< SEG 32 address.
#define	LCD8A_SEG_33_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x21)	///< SEG 33 address.
#define	LCD8A_SEG_34_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x22)	///< SEG 34 address.
#define	LCD8A_SEG_35_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x23)	///< SEG 35 address.
#define	LCD8A_SEG_36_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x24)	///< SEG 36 address.
#define	LCD8A_SEG_37_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x25)	///< SEG 37 address.
#define	LCD8A_SEG_38_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x26)	///< SEG 38 address.
#define	LCD8A_SEG_39_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x27)	///< SEG 39 address.
#define	LCD8A_SEG_40_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x28)	///< SEG 40 address.
#define	LCD8A_SEG_41_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x29)	///< SEG 41 address.
#define	LCD8A_SEG_42_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x2A)	///< SEG 42 address.
#define	LCD8A_SEG_43_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x2B)	///< SEG 43 address.
#define	LCD8A_SEG_44_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x2C)	///< SEG 44 address.
#define	LCD8A_SEG_45_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x2D)	///< SEG 45 address.
#define	LCD8A_SEG_46_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x2E)	///< SEG 46 address.
#define	LCD8A_SEG_47_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x2F)	///< SEG 47 address.
#define	LCD8A_SEG_48_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x30)	///< SEG 48 address.
#define	LCD8A_SEG_49_ADDR		(LCD8A_SEGRAM_TOP_ADDR + 0x31)	///< SEG 49 address.
#endif


/* --- external declaration --- */
extern void c17intLcd8a(void)	__attribute__ ((interrupt_handler));

extern void c17initLcd8a( void );
extern void c17setLcd8a(unsigned short lcdClkSrc, unsigned short lcdClkDiv);
extern void c17enableIntLcd8a(void);
extern void c17disableIntLcd8a(void);
extern void c17onLcd8aDisplay( void );
extern void c17offLcd8aDisplay( void );
extern void c17setLcd8aDisplayState( unsigned char state );
extern unsigned char c17getLcd8aDisplayState( void );
extern void c17setLcd8aDisplayInverted(unsigned char display);
extern unsigned char c17getLcd8aDisplayInverted(void);
extern void c17setLcd8aDisplayArea(unsigned char area);
extern void c17setLcd8aCheckerboardPattern(void);
extern void c17clearLcd8a(void);
#endif // C17_LCD8A_H__

