/************************************************************************//**
 *
 * @file    c17_misc.c
 *
 * @brief   This is Misc Registers setting program.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ***************************************************************************/
#include "c17_misc.h"


/************************************************************************//**
 * @brief   Misc register write protect on.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17protectMiscOn(void)
{
	// Misc register write protect ON
	MSCPROT = 0x00;
}


/************************************************************************//**
 * @brief   Misc register write protect off.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17protectMiscOff(void)
{
	// Misc register write protect OFF
	MSCPROT = 0x96;
}


/************************************************************************//**
 * @brief   Flash access cycle setting.
 *
 * @param   cycle   Flashc read access cycle.
 *
 * @retval  none
 ***************************************************************************/
void c17setFlashcAccessCycle(unsigned short cycle)
{
	c17protectMiscOff();

	// Flashc read access cycle
	FLASHCWAIT = cycle;

	c17protectMiscOn();
}


/************************************************************************//**
 * @brief   GetFlashAccessCycle function.
 *
 * @param   cycle   Flashc read access cycle.
 *
 * @retval  FLASHCWAIT_RDWAIT
 ***************************************************************************/
unsigned short c17getFlashAccessCycle(void)
{
	return FLASHCWAIT_RDWAIT;
}


