/************************************************************************//**
 *
 * @file    c17_rtca_1.h
 *
 * @brief   This is RTCA driver header.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ***************************************************************************/
#ifndef C17_RTCA_H__
#define C17_RTCA_H__

#include <c17_mcu_select.h>

/* --- definition --- */
enum
{
	C17_RTCA_12H,						///< Hour counter - 12H mode.
	C17_RTCA_24H						///< Hour counter - 24H mode.
};

enum
{
	C17_RTCA_AM,						///< Mode - A.M.
	C17_RTCA_PM							///< Mode - P.M.
};

enum
{
	C17_RTCA_SUN,						///< Day of the week - Sunday.
	C17_RTCA_MON,						///< Day of the week - Monday.
	C17_RTCA_TUE,						///< Day of the week - Tuesday.
	C17_RTCA_WED,						///< Day of the week - Wednesday.
	C17_RTCA_THU,						///< Day of the week - Thursday.
	C17_RTCA_FRI,						///< Day of the week - Friday.
	C17_RTCA_SAT						///< Day of the week - Saturday.
};

/* --- Struct   ---*/
typedef struct st_rtca_bcd {
	unsigned short year;
	unsigned short month;
	unsigned short day;
	unsigned short hour;
	unsigned short minute;
	unsigned short second;
	unsigned short week;
	unsigned short ampm;
} ST_RTCA_BCD;

/* --- external declaration --- */
extern void c17intRtca(void)	__attribute__ ((interrupt_handler));

extern int c17initRtca(void);
extern void c17startRtca(void);
extern void c17stopRtca(void);
extern void c17intRtca(void);
extern void c17setRtcaDate(ST_RTCA_BCD* rtcBcd);
extern void c17getRtcaDate(ST_RTCA_BCD* rtcBcd);
extern void c17setRtcaAlarm(ST_RTCA_BCD* rtcBcd);
extern void c17enableIntRtca(void);
extern void c17disableIntRtca(void);
extern int c17setRtcaMode(unsigned short rtcaMode);
extern unsigned short c17getRtcaMode(void);
extern void c17startSw(void);
extern void c17stopSw(void);
extern void c17enableIntSW(void);
extern void c17disableIntSW(void);
extern unsigned short c17readSwCount(void);

#endif	//C17_RTCA_H__

