/************************************************************************//**
 *
 * @file    c17_t16_1.h
 *
 * @brief   This is 16-bit Timers driver header file.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ***************************************************************************/
#ifndef C17_T16_H__
#define C17_T16_H__

#include <c17_mcu_select.h>

/* --- definition --- */
enum
{
	C17_T16_CLKSRC_IOSC,				///< Clock Source = IOSC
	C17_T16_CLKSRC_OSC1,				///< Clock Source = OSC1
	C17_T16_CLKSRC_OSC3,				///< Clock Source = OSC3
	C17_T16_CLKSRC_EXT					///< Clock Source = External OSC
};

enum
{
	C17_T16_CLKDIV_1,					///< Clock Division = 1/1
	C17_T16_CLKDIV_2,					///< Clock Division = 1/2
	C17_T16_CLKDIV_4,					///< Clock Division = 1/4
	C17_T16_CLKDIV_8,					///< Clock Division = 1/8
	C17_T16_CLKDIV_16,					///< Clock Division = 1/16
	C17_T16_CLKDIV_32,					///< Clock Division = 1/32
	C17_T16_CLKDIV_64,					///< Clock Division = 1/64
	C17_T16_CLKDIV_128,					///< Clock Division = 1/128
	C17_T16_CLKDIV_256,					///< Clock Division = 1/256
	C17_T16_CLKDIV_512,					///< Clock Division = 1/512
	C17_T16_CLKDIV_1024,				///< Clock Division = 1/1024
	C17_T16_CLKDIV_2048,				///< Clock Division = 1/2048
	C17_T16_CLKDIV_4096,				///< Clock Division = 1/4096
	C17_T16_CLKDIV_8192,				///< Clock Division = 1/8192
	C17_T16_CLKDIV_16384,				///< Clock Division = 1/16384
	C17_T16_CLKDIV_32768				///< Clock Division = 1/32768
};

enum
{
	C17_T16_MODE_REPEAT,				///< Repeat mode.
	C17_T16_MODE_ONESHOT				///< One shot mode.
};

/* --- external declaration --- */
extern void c17intT16Ch0(void)	__attribute__ ((interrupt_handler));
extern void c17intT16Ch1(void)	__attribute__ ((interrupt_handler));
#if defined(C17_MCUSEL_M01) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M12) || defined(C17_MCUSEL_M13) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W13) || \
	defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W15) || \
	defined(C17_MCUSEL_W18)
extern void c17intT16Ch2(void)	__attribute__ ((interrupt_handler));
#endif
#if defined(C17_MCUSEL_M01) || defined(C17_MCUSEL_W23) || \
	defined(C17_MCUSEL_M12) || defined(C17_MCUSEL_M13) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W18)
extern void c17intT16Ch3(void)	__attribute__ ((interrupt_handler));
#endif
#if defined(C17_MCUSEL_M01) || \
	defined(C17_MCUSEL_W16)
extern void c17intT16Ch4(void)	__attribute__ ((interrupt_handler));
#endif

extern void c17initT16(void);
extern void c17setT16(unsigned short t16Channel, unsigned short t16ClkSrc, unsigned short t16ClkDiv, unsigned short t16Mode);
extern void c17disableT16(unsigned short t16Channel);
extern void c17startT16(unsigned short t16Channel);
extern void c17stopT16(unsigned short t16Channel);
extern void c17enableIntT16(unsigned short t16Channel);
extern void c17disableIntT16(unsigned short t16Channel);
extern void c17setCountT16(unsigned short t16Channel, unsigned short t16Reload);
extern unsigned short c17getCountT16(unsigned short t16Channel);

#endif	// C17_T16_H__

