/************************************************************************//**
 *
 * @file    main_acc.h
 *
 * @brief   This is header file of Remote controller mode program.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 16 Mar. 2018    1.00
 *              - First revision.
 *
 ***************************************************************************/
#ifndef MAIN_ACC_H_
#define MAIN_ACC_H_
#include "mid_key.h"
#include "main_config.h"
/* --- definition --- */
/// Key operation state.
enum
{
	ACC_OPERATION_STATE_NORMAL,		/// Normal operation.
	ACC_OPERATION_STATE_SET_CLOCK,		/// Clock setting.
	ACC_OPERATION_STATE_SET_TIMER,		/// Timer setting.
};

/// Cursor position at Clock setting state.
enum
{
	ACC_CURSOR_CLOCK_YEAR,			/// Year input.
	ACC_CURSOR_CLOCK_MONTH,			/// Month input.
	ACC_CURSOR_CLOCK_DAY,			/// Day input.
	ACC_CURSOR_CLOCK_12h_24h,		/// 24h or 12h choice.
	ACC_CURSOR_CLOCK_HOUR,			/// Hour input.
	ACC_CURSOR_CLOCK_MINUTE,		/// Minute input.
};
/// Cursor position at Timer setting state.
enum
{
	ACC_CURSOR_TIMER_BLINK_ALL,		/// Operation start key input
	ACC_CURSOR_TIMER_ON_ENABLE,		/// Enable or Disable of On timer choice.
	ACC_CURSOR_TIMER_ON_HOUR,		/// ON time hour input.
	ACC_CURSOR_TIMER_ON_MINUTE,		/// ON time minute input
	ACC_CURSOR_TIMER_OFF_ENABLE,	/// Enable or Disable of Off timer choice.
	ACC_CURSOR_TIMER_OFF_HOUR,		/// OFF time hour input.
	ACC_CURSOR_TIMER_OFF_MINUTE,	/// OFF time minute input.
};
/// Cursor blank
enum
{
	ACC_CURSOR_BLINK_DISABLE,
	ACC_CURSOR_BLINK_ENABLE,
};
enum
{
	ACC_BLINK_STATE_OFF,
	ACC_BLINK_STATE_ON
};
///
enum
{
	ACC_CLOCK_DISP_TIME,
	ACC_CLOCK_DISP_DATE,
	ACC_CLOCK_DISP_TIMER,
};

enum
{
	ACC_WIND_VERT_DIR_DN,
	ACC_WIND_VERT_DIR_UP,

};

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */
#define ACC_CURSOR_BLINK_TIME		500			/* Blinking time in 1ms unit */
#define ACC_DATE_TIMER_DISP_TIME	3000		/* Period of the timer or date display. */
#define ACC_SETTING_TIMEOUT			60000		

/* --- structure --- */
typedef struct acc_date_time_s
{
	unsigned short year;
	unsigned short month;
	unsigned short day;
	unsigned short week;
	unsigned short hour;
	unsigned short minute;
}ACC_DATE_TIME_S;



/* --- external declaration --- */
extern int main_runAcc(void);
extern void main_initAcc(void);
extern void main_onAcc(void);
extern void main_offAcc(void);
extern void main_execAccKeyInput(KEY_STATE_S *pKeState);
extern void main_updateClockDisp(void);
extern int main_chkAccIrSendState(void);

// global variable
extern ACC_AC_SETTINGS_S	AccAcSettings;
extern int					AccKeyOpeState;
extern int				    AccIsIrSending;
extern int					AccDateTimeDispMode;
extern volatile unsigned int c17rtcaIntCount;
extern volatile unsigned int c17svdIntLowVoltage;
extern volatile unsigned int c17swIntCount100;
#endif /* MAIN_ACC_H_ */
