/************************************************************************//**
 *
 * @file    main_config.h
 * @brief   This is configuration macro header for the main program.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 16 Mar. 2018    1.00
 *              - First revision.
 *
 ***************************************************************************/
#ifndef MAIN_CONFIG_H_
#define MAIN_CONFIG_H_
#include "c17_rtca_1.h"
#include "mid_key.h"

/* --- definition --- */
enum
{
	ACC_ACTIVE_STATE_STANDBY,		/// --- Do not change. ---
	ACC_ACTIVE_STATE_ACTIVE,		/// --- Do not change. ---
};

/// --- Application selection. ---
#define MAIN_USE_DEMO_MODE
#define MAIN_USE_TERM_MODE
#define MAIN_USE_TEST_MODE

/// --- Always clock display ---
enum
{
	ACC_ALWAYS_CLOCL_DISP_DISABLE,		/// --- Do not change. ---
	ACC_ALWAYS_CLOCL_DISP_ENABLE		/// --- Do not change. ---
};
#define ACC_ALWAYS_CLOCK_DSIP	ACC_ALWAYS_CLOCL_DISP_DISABLE



/// --- BEGIN Clock Setting ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */
#define ACC_CLOCK_START_YEAR		18	/* minimum year.(offset based on 2000)*/

/// --- END Clock Setting ---

/// --- BEGIN IR Remote control Setting ---

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */
#define IRCODE_LENGTH_MAX			48
#define REMSND_PRECEDE_TR_BLANK		10		/* OFF time after trailer at preceding code. (10ms) */
#define REMSND_CODE_TR_BLANK		75		/* OFF time after trailer at the operation code. (75ms) */
#define ACC_PRECEDE_CODE_ENABLE		1
#define ACC_REMOTE_REPEATE_COUNT	0
#define ACC_TRAMS_ICON_DISPTIME		500

/// --- END IR Remote control Setting ---

/// --- BEGIN Key Setting ---


/// Key code for Normal key operation.
#define KEY_ONOFF		KEY_SW07		/// < SW7
#define KEY_MODE		KEY_SW06		/// < SW6
#define KEY_TEMP_DN		KEY_SW08		/// < SW5
#define KEY_TEMP_UP		KEY_SW04		/// < SW4
#define KEY_WIND_VERT	KEY_SW11		/// < SW11
#define KEY_WIND_HORI	KEY_SW09		/// < SW9
#define KEY_WIND_FAN	KEY_SW10		/// < SW10
#define KEY_CLOCK		KEY_SW12		/// < SW12
#define KEY_TIME		KEY_SW13		/// < SW13
#define KEY_OPT			KEY_SW05		/// < SW5
/// Key code for CLOCK/TIME setting key operation.
#define KEY_OK			KEY_SW15		/// < SW15
#define KEY_CANCEL		KEY_SW14		/// < SW14
#define KEY_SETTING_DN	KEY_SW08
#define KEY_SETTING_UP	KEY_SW04

/// --- END KEY Setting ---

/// --- BEGIN A/C operation control Setting ---

/**
 * Internal definition macro
 * Do not change.
 */
enum
{
	ACC_TEMP_UNIT_CELSIUS,		/// --- Do not change. ---
	ACC_TEMP_UNIT_FAHRENHEIT	/// --- Do not change. ---
};

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */
#define ACC_TEMP_UNIT		ACC_TEMP_UNIT_CELSIUS	/* Temperature unit. */

//Temperature adjustment range.
#define ACC_TEMP_MAX		32	/// Maximum temperature.
#define ACC_TEMP_MIN		16	/// Minimum temperature.
#define ACC_TEMP_DEF		25	/// Default temperature.


#define ACC_MODE_ITEM_COUNT				5	/// Number of selectable operation mode.
#define ACC_WIND_FAN_ITEM_COUNT			6	/// Number of selectable fan speed index.
#define ACC_WIND_VERT_ITEM_COUNT		6	/// Number of selectable vertical flap.

/// --- END A/C operation control Setting ---


/// --- BEGIN Timer Setting ---

typedef enum
{
	/// --- Please add the new timers if necessary. ---
	MAIN_CURSOR_BLINK_TIMER,
	MAIN_CLOCK_DISP_TIMER,
	MAIN_SETTING_TIMER,
	MAIN_WAKEUP_TIMER,
	MAIN_TRAMS_ICON_TIMER,
	MAIN_SVD3_TIMER,
	/// --- Do not change below item. ---
	TMR_ENTRIES,
}TMR_TIMER_ENUM;

/// --- END Timer Setting ---

/* --- structure --- */
typedef struct acc_timer_s
{
	unsigned short enable;
	unsigned short hour;
	unsigned short minute;
}ACC_TIMER_S;

typedef struct acc_ac_settings_s
{
	unsigned short	AcOnOff;
	unsigned short	TempUnit;
	unsigned short	Temp;
	unsigned short	Mode;
	unsigned short	WindVert;
	unsigned short	WindHori;
	unsigned short	WindFan;
	ACC_TIMER_S		OnTimer;
	ACC_TIMER_S		OffTimer;
}ACC_AC_SETTINGS_S;

#endif /* MAIN_CONFIG_H_ */
