/************************************************************************//*
 *
 * @file    mid_dipsw.c
 *
 * @brief   This is dip switch input interface program.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2018. All rights reserved
 *
 * @warning -
 *
 * @par     History:
 *          - 16 Mar. 2018    1.00
 *              - First revision.
 *
 ***************************************************************************/
#include "mid_dipsw.h"
#include "c17_port_1.h"

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */
#define DIPSW_SW1_PORT	7,4
#define DIPSW_SW2_PORT	7,5
#define DIPSW_SW3_PORT	7,6
#define DIPSW_SW4_PORT	2,0

/************************************************************************//**
 * @brief   Initialize this interface.
 *
 *
 *  @retval     none
 ***************************************************************************/
void mid_initDipSw(void)
{
	mid_onDipSw();
}

/************************************************************************//**
 * @brief   Enable the dip switch input ports(input and pull-up).
 *
 *
 *  @retval     none
 ***************************************************************************/
void mid_onDipSw(void)
{
	int i;
	c17setDirectionPortGrp(DIPSW_SW1_PORT, C17_PORT_DIR_INPUT, 0, C17_PORT_PULL_UP);
	c17setDirectionPortGrp(DIPSW_SW2_PORT, C17_PORT_DIR_INPUT, 0, C17_PORT_PULL_UP);
	c17setDirectionPortGrp(DIPSW_SW3_PORT, C17_PORT_DIR_INPUT, 0, C17_PORT_PULL_UP);
	c17setDirectionPortGrp(DIPSW_SW4_PORT, C17_PORT_DIR_INPUT, 0, C17_PORT_PULL_UP);

	/// wait for rising time.
	for (i = 0; i < 300; i++)
	{
		asm("nop");
	}
}
/************************************************************************//**
 * @brief   Disable the dip switch input ports(Hi-z).
 *
 *
 *  @retval     none
 ***************************************************************************/
void mid_offDipSw(void)
{
	c17setDirectionPortGrp(DIPSW_SW1_PORT, C17_PORT_DIR_DISABLE, 0, C17_PORT_PULL_DISABLE);
	c17setDirectionPortGrp(DIPSW_SW2_PORT, C17_PORT_DIR_DISABLE, 0, C17_PORT_PULL_DISABLE);
	c17setDirectionPortGrp(DIPSW_SW3_PORT, C17_PORT_DIR_DISABLE, 0, C17_PORT_PULL_DISABLE);
	c17setDirectionPortGrp(DIPSW_SW4_PORT, C17_PORT_DIR_DISABLE, 0, C17_PORT_PULL_DISABLE);
}

/************************************************************************//**
 * @brief   Get dip switch state.
 *
 *
 * @retval     state of sw4(bit0) to sw1(bit1).
 ***************************************************************************/
unsigned char mid_getDipSwState(void)
{
	unsigned char state = 0;
	state |= c17getInputPortGrp(DIPSW_SW1_PORT) ? 0 : DIPSW_BIT_SW1;
	state |= c17getInputPortGrp(DIPSW_SW2_PORT) ? 0 : DIPSW_BIT_SW2;
	state |= c17getInputPortGrp(DIPSW_SW3_PORT) ? 0 : DIPSW_BIT_SW3;
	state |= c17getInputPortGrp(DIPSW_SW4_PORT) ? 0 : DIPSW_BIT_SW4;
	return state;
}

