/************************************************************************//**
 *
 * @file    mid_key.h
 *
 * @brief   This is key input interface header file.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2018. All rights reserved
 *
 * @warning -
 *
 * @par     History:
 *          - 16 Mar. 2018    1.00
 *              - First revision.
 *
 ***************************************************************************/
#ifndef MID_KEY_H_
#define MID_KEY_H_

/* --- definition --- */
enum
{
	KEY_EVENT_NONE,
	KEY_EVENT_PRESS,
	KEY_EVENT_RELEASE,
	KEY_EVENT_REPEAT,
	KEY_EVENT_LONG_PRESS,
	KEY_EVENT_PRESS_LIMIT,
};

/**
 * Macro changed according to user environment
 * Please change the argument or value if necessary.
 */
/// Key code
#define KEY_NONE		0x00000000
#define KEY_SW04		0x00000001	/// < R1, C1
#define KEY_SW05		0x00000002	/// < R1, C2
#define KEY_SW06		0x00000004	/// < R1, C3
#define KEY_SW07		0x00000008	/// < R1, C4
#define KEY_SW08		0x00000010	/// < R2, C1
#define KEY_SW09		0x00000020	/// < R2, C2
#define KEY_SW10		0x00000040	/// < R2, C3
#define KEY_SW11		0x00000080	/// < R2, C4
#define KEY_SW12		0x00000100	/// < R3, C1
#define KEY_SW13		0x00000200	/// < R3, C2
#define KEY_SW14		0x00000400	/// < R3, C3
#define KEY_SW15		0x00000800	/// < R3, C4


/* struct */
typedef struct key_state_s
{
	unsigned char keyevent;
	unsigned long keycode;
}KEY_STATE_S;

/* --- external declaration --- */
extern void mid_initKey(void);
extern void mid_startKeyScan(void);
extern void mid_stopKeyScan(void);
extern void mid_setKeyWakeup(unsigned long keyCode);
extern int mid_chkKeyWakeup(void);
extern void mid_pauseKeyScan(void);
extern void mid_getKeyState(KEY_STATE_S *pkeyState);
extern void mid_setKeyLongPressTime(unsigned short waitTime);
extern void mid_setKeyRepeateTime(unsigned short interval);
extern void mid_cancelKeyCurKeyEvent(void);


#endif /* MID_KEY_H_ */
