/************************************************************************//**
 *
 * @file    mid_lcdac.c
 *
 * @brief   This is LCD interface program for the A/C.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2018. All rights reserved
 *
 * @warning -
 *
 * @par     History:
 *          - 16 Mar. 2018    1.00
 *              - First revision.
 *
 ***************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "c17_rtca_1.h"
#include "main_config.h"
#include "mid_lcdac.h"
#include "util.h"


/// LCD segment definition
#define KM6713S03_SEG00		LCDAC_SEG00_OFFSET
#define KM6713S03_SEG01		LCDAC_SEG01_OFFSET
#define KM6713S03_SEG02		LCDAC_SEG02_OFFSET
#define KM6713S03_SEG03		LCDAC_SEG03_OFFSET
#define KM6713S03_SEG04		LCDAC_SEG04_OFFSET
#define KM6713S03_SEG05		LCDAC_SEG05_OFFSET
#define KM6713S03_SEG06		LCDAC_SEG06_OFFSET
#define KM6713S03_SEG07		LCDAC_SEG07_OFFSET
#define KM6713S03_SEG08		LCDAC_SEG08_OFFSET
#define KM6713S03_SEG09		LCDAC_SEG09_OFFSET
#define KM6713S03_SEG10		LCDAC_SEG10_OFFSET
#define KM6713S03_SEG11		LCDAC_SEG11_OFFSET
#define KM6713S03_SEG12		LCDAC_SEG12_OFFSET
#define KM6713S03_SEG13		LCDAC_SEG13_OFFSET
#define KM6713S03_SEG14		LCDAC_SEG14_OFFSET
#define KM6713S03_SEG15		LCDAC_SEG15_OFFSET
#define KM6713S03_SEG16		LCDAC_SEG20_OFFSET
#define KM6713S03_SEG17		LCDAC_SEG21_OFFSET
#define KM6713S03_SEG18		LCDAC_SEG22_OFFSET
#define KM6713S03_SEG19		LCDAC_SEG23_OFFSET
#define KM6713S03_SEG20		LCDAC_SEG24_OFFSET
#define KM6713S03_SEG21		LCDAC_SEG25_OFFSET
#define KM6713S03_SEG22		LCDAC_SEG26_OFFSET
#define KM6713S03_SEG23		LCDAC_SEG27_OFFSET
#define KM6713S03_SEG24		LCDAC_SEG28_OFFSET
#define KM6713S03_SEG25		LCDAC_SEG29_OFFSET
#define KM6713S03_SEG26		LCDAC_SEG30_OFFSET
#define KM6713S03_SEG27		LCDAC_SEG31_OFFSET
#define KM6713S03_SEG28		LCDAC_SEG32_OFFSET
#define KM6713S03_SEG29		LCDAC_SEG33_OFFSET
#define KM6713S03_SEG30		LCDAC_SEG34_OFFSET
#define KM6713S03_SEG31		LCDAC_SEG35_OFFSET
#define KM6713S03_SEG32		LCDAC_SEG36_OFFSET

/// Separator Icon.
const LCD_SEG_POS_S LcdSeparatorIcon = {
		LCDAC_COM3_BIT, KM6713S03_SEG20
};

/// 7seg for Temperature display.
const LCD_SEG_POS_S LcdTempUpper7seg[LCDAC_7SEG_COUNTS] = {
		{LCDAC_COM0_BIT, KM6713S03_SEG10},	//1a
		{LCDAC_COM0_BIT, KM6713S03_SEG11},	//1b
		{LCDAC_COM2_BIT, KM6713S03_SEG11},	//1c
		{LCDAC_COM3_BIT, KM6713S03_SEG10},	//1d
		{LCDAC_COM2_BIT, KM6713S03_SEG10},	//1e
		{LCDAC_COM1_BIT, KM6713S03_SEG10},	//1f
		{LCDAC_COM1_BIT, KM6713S03_SEG11},	//1g
		{LCDAC_COM_NONE, KM6713S03_SEG11},	//dummy
};

const LCD_SEG_POS_S LcdTempLower7seg[LCDAC_7SEG_COUNTS] = {
		{LCDAC_COM0_BIT, KM6713S03_SEG12},	//2a
		{LCDAC_COM0_BIT, KM6713S03_SEG13},	//2b
		{LCDAC_COM2_BIT, KM6713S03_SEG13},	//2c
		{LCDAC_COM3_BIT, KM6713S03_SEG12},	//2d
		{LCDAC_COM2_BIT, KM6713S03_SEG12},	//2e
		{LCDAC_COM1_BIT, KM6713S03_SEG12},	//2f
		{LCDAC_COM1_BIT, KM6713S03_SEG13},	//2g
		{LCDAC_COM_NONE, KM6713S03_SEG13},	//dummy
};

/// Temperature unit Icon.
const LCD_SEG_POS_S LcdTempUnitIcon[2] = {
		{LCDAC_COM3_BIT, KM6713S03_SEG01},	//S32(Celsius)
		{LCDAC_COM3_BIT, KM6713S03_SEG13},	//S28(Fahrenheit)
};

/// Clock display on the left side.
const LCD_SEG_POS_S LcdLeftDayTime7seg[5][LCDAC_7SEG_COUNTS] = {
		{ //First digit.
			{LCDAC_COM3_BIT, KM6713S03_SEG08},	//3a
			{LCDAC_COM2_BIT, KM6713S03_SEG08},	//3b
			{LCDAC_COM1_BIT, KM6713S03_SEG08},	//3c
			{LCDAC_COM0_BIT, KM6713S03_SEG08},	//3d
			{LCDAC_COM0_BIT, KM6713S03_SEG09},	//3e
			{LCDAC_COM2_BIT, KM6713S03_SEG09},	//3f
			{LCDAC_COM1_BIT, KM6713S03_SEG09},	//3g
			{LCDAC_COM_NONE, KM6713S03_SEG09},	//dummy
		},
		{ //Second digit.
			{LCDAC_COM3_BIT, KM6713S03_SEG06},	//4a
			{LCDAC_COM2_BIT, KM6713S03_SEG06},	//4b
			{LCDAC_COM1_BIT, KM6713S03_SEG06},	//4c
			{LCDAC_COM0_BIT, KM6713S03_SEG06},	//4d
			{LCDAC_COM0_BIT, KM6713S03_SEG07},	//4e
			{LCDAC_COM2_BIT, KM6713S03_SEG07},	//4f
			{LCDAC_COM1_BIT, KM6713S03_SEG07},	//4g
			{LCDAC_COM_NONE, KM6713S03_SEG07},	//dummy
		},
		{ //Third digit.
			{LCDAC_COM3_BIT, KM6713S03_SEG04},	//5a
			{LCDAC_COM2_BIT, KM6713S03_SEG04},	//5b
			{LCDAC_COM1_BIT, KM6713S03_SEG04},	//5c
			{LCDAC_COM0_BIT, KM6713S03_SEG04},	//5d
			{LCDAC_COM0_BIT, KM6713S03_SEG05},	//5e
			{LCDAC_COM2_BIT, KM6713S03_SEG05},	//5f
			{LCDAC_COM1_BIT, KM6713S03_SEG05},	//5g
			{LCDAC_COM3_BIT, KM6713S03_SEG05},	//P1(colon)
		},
		{ //4th digit.
			{LCDAC_COM3_BIT, KM6713S03_SEG02},	//6a
			{LCDAC_COM2_BIT, KM6713S03_SEG02},	//6b
			{LCDAC_COM1_BIT, KM6713S03_SEG02},	//6c
			{LCDAC_COM0_BIT, KM6713S03_SEG02},	//6d
			{LCDAC_COM0_BIT, KM6713S03_SEG03},	//6e
			{LCDAC_COM2_BIT, KM6713S03_SEG03},	//6f
			{LCDAC_COM1_BIT, KM6713S03_SEG03},	//6g
			{LCDAC_COM_NONE, KM6713S03_SEG03},	//dummy
		},
		{ //5th digit.
			{LCDAC_COM3_BIT, KM6713S03_SEG00},	//7a
			{LCDAC_COM2_BIT, KM6713S03_SEG00},	//7b
			{LCDAC_COM1_BIT, KM6713S03_SEG00},	//7c
			{LCDAC_COM0_BIT, KM6713S03_SEG00},	//7d
			{LCDAC_COM0_BIT, KM6713S03_SEG01},	//7e
			{LCDAC_COM2_BIT, KM6713S03_SEG01},	//7f
			{LCDAC_COM1_BIT, KM6713S03_SEG01},	//7g
			{LCDAC_COM_NONE, KM6713S03_SEG01},	//dummy
		},
};


const LCD_SEG_POS_S LcdLeftDayTimeAmPm[2] = {
		{LCDAC_COM3_BIT, KM6713S03_SEG07},	//Z2(AM)
		{LCDAC_COM3_BIT, KM6713S03_SEG09},	//Z3(PM)
};

/// Clock display on the right side.
const LCD_SEG_POS_S LcdRightDayTime7seg[5][LCDAC_7SEG_COUNTS] = {
		{ //First digit.
			{LCDAC_COM3_BIT, KM6713S03_SEG31},	//8a
			{LCDAC_COM2_BIT, KM6713S03_SEG31},	//8b
			{LCDAC_COM1_BIT, KM6713S03_SEG31},	//8c
			{LCDAC_COM0_BIT, KM6713S03_SEG31},	//8d
			{LCDAC_COM0_BIT, KM6713S03_SEG32},	//8e
			{LCDAC_COM2_BIT, KM6713S03_SEG32},	//8f
			{LCDAC_COM1_BIT, KM6713S03_SEG32},	//8g
			{LCDAC_COM_NONE, KM6713S03_SEG32},	//dummy
		},
		{ //Second digit.
			{LCDAC_COM3_BIT, KM6713S03_SEG29},	//9a
			{LCDAC_COM2_BIT, KM6713S03_SEG29},	//9b
			{LCDAC_COM1_BIT, KM6713S03_SEG29},	//9c
			{LCDAC_COM0_BIT, KM6713S03_SEG29},	//9d
			{LCDAC_COM0_BIT, KM6713S03_SEG30},	//9e
			{LCDAC_COM2_BIT, KM6713S03_SEG30},	//9f
			{LCDAC_COM1_BIT, KM6713S03_SEG30},	//9g
			{LCDAC_COM_NONE, KM6713S03_SEG30},	//dummy
		},
		{ //Third digit.
			{LCDAC_COM3_BIT, KM6713S03_SEG27},	//10a
			{LCDAC_COM2_BIT, KM6713S03_SEG27},	//10b
			{LCDAC_COM1_BIT, KM6713S03_SEG27},	//10c
			{LCDAC_COM0_BIT, KM6713S03_SEG27},	//10d
			{LCDAC_COM0_BIT, KM6713S03_SEG28},	//10e
			{LCDAC_COM2_BIT, KM6713S03_SEG28},	//10f
			{LCDAC_COM1_BIT, KM6713S03_SEG28},	//10g
			{LCDAC_COM3_BIT, KM6713S03_SEG28},	//p2(colon)
		},
		{ //4th digit.
			{LCDAC_COM3_BIT, KM6713S03_SEG25},	//11a
			{LCDAC_COM2_BIT, KM6713S03_SEG25},	//11b
			{LCDAC_COM1_BIT, KM6713S03_SEG25},	//11c
			{LCDAC_COM0_BIT, KM6713S03_SEG25},	//11d
			{LCDAC_COM0_BIT, KM6713S03_SEG26},	//11e
			{LCDAC_COM2_BIT, KM6713S03_SEG26},	//11f
			{LCDAC_COM1_BIT, KM6713S03_SEG26},	//11g
			{LCDAC_COM_NONE, KM6713S03_SEG26},	//dummy
		},
		{ //5th digit.
			{LCDAC_COM3_BIT, KM6713S03_SEG23},	//12a
			{LCDAC_COM2_BIT, KM6713S03_SEG23},	//12b
			{LCDAC_COM1_BIT, KM6713S03_SEG23},	//12c
			{LCDAC_COM0_BIT, KM6713S03_SEG23},	//12d
			{LCDAC_COM0_BIT, KM6713S03_SEG24},	//12e
			{LCDAC_COM2_BIT, KM6713S03_SEG24},	//12f
			{LCDAC_COM1_BIT, KM6713S03_SEG24},	//12g
			{LCDAC_COM_NONE, KM6713S03_SEG24},	//dummy
		},
};

const LCD_SEG_POS_S LcdRightDayTimeAmPm[2] = {
		{LCDAC_COM3_BIT, KM6713S03_SEG30},	//Z12(AM)
		{LCDAC_COM3_BIT, KM6713S03_SEG32},	//Z13(PM)
};

/// Week Icon.
const LCD_SEG_POS_S LcdWeekIcon[7] = {
		{LCDAC_COM2_BIT, KM6713S03_SEG22},	//Z4(Sunday)
		{LCDAC_COM1_BIT, KM6713S03_SEG22},	//Z5(Monday)
		{LCDAC_COM0_BIT, KM6713S03_SEG22},	//Z6(Tuesday)
		{LCDAC_COM3_BIT, KM6713S03_SEG21},	//Z7(Wednesday)
		{LCDAC_COM2_BIT, KM6713S03_SEG21},	//Z8(Thursday)
		{LCDAC_COM1_BIT, KM6713S03_SEG21},	//Z9(Friday)
		{LCDAC_COM0_BIT, KM6713S03_SEG21},	//Z10(Saturday)
};

/// Timer ON/OFF Icon
const LCD_SEG_POS_S LcdTimerOnIcon  = {
		LCDAC_COM3_BIT, KM6713S03_SEG03	//Z1(ON)
};
const LCD_SEG_POS_S LcdTimerOffIcon = {
		LCDAC_COM3_BIT, KM6713S03_SEG26	//Z11(OFF)
};


/// Mode Icon.
const LCD_SEG_POS_S LcdModeItemIcon[LCDAC_MODE_ITEM_COUNT] = {
		{LCDAC_COM1_BIT, KM6713S03_SEG14},	//S2(AUTO)
		{LCDAC_COM2_BIT, KM6713S03_SEG14},	//S3(cooling)
		{LCDAC_COM3_BIT, KM6713S03_SEG14},	//S4(heating)
		{LCDAC_COM3_BIT, KM6713S03_SEG15},	//S5(Blower)
		{LCDAC_COM2_BIT, KM6713S03_SEG15},	//S6(Dehumidify)
};

/// Vertical wind Icon.
const LCD_SEG_POS_S LcdWindVertItemIcon[LCDAC_WIND_VERT_ITEM_COUNT] = {
		{LCDAC_COM0_BIT, KM6713S03_SEG15},	//S14(AUTO)
		{LCDAC_COM1_BIT, KM6713S03_SEG17},	//S15(1)
		{LCDAC_COM3_BIT, KM6713S03_SEG18},	//S16(2)
		{LCDAC_COM2_BIT, KM6713S03_SEG18},	//S17(3)
		{LCDAC_COM1_BIT, KM6713S03_SEG18},	//S18(4)
		{LCDAC_COM0_BIT, KM6713S03_SEG18},	//S19(5)
};

const LCD_SEG_POS_S LcdWindVertSymbolIcon = {
		LCDAC_COM0_BIT, KM6713S03_SEG17		//S20(symbol)
};

/// Horizontal wind Icon.
const LCD_SEG_POS_S LcdWindHoriItemIcon[LCDAC_WIND_HORI_ITEM_COUNT] = {
		{LCDAC_COM1_BIT, KM6713S03_SEG15},	//S7(AUTO)
		{LCDAC_COM1_BIT, KM6713S03_SEG16},	//S9(Right 1)
		{LCDAC_COM2_BIT, KM6713S03_SEG16},	//S10(Right 2)
		{LCDAC_COM3_BIT, KM6713S03_SEG16},	//S11(Center)
		{LCDAC_COM3_BIT, KM6713S03_SEG17},	//S12(Left 1)
		{LCDAC_COM2_BIT, KM6713S03_SEG17},	//S13(Left 2)
};

const LCD_SEG_POS_S LcdWindHoriSymbolIcon = {
		LCDAC_COM0_BIT, KM6713S03_SEG16 //S8(symbol)
};


/// Fan speed Icon.
const LCD_SEG_POS_S LcdWindFanIcon[LCDAC_WIND_FAN_ITEM_COUNT] = {
		{LCDAC_COM3_BIT, KM6713S03_SEG19},	//S27(AUTO)
		{LCDAC_COM2_BIT, KM6713S03_SEG19},	//S21(1)
		{LCDAC_COM1_BIT, KM6713S03_SEG19},	//S22(2)
		{LCDAC_COM0_BIT, KM6713S03_SEG19},	//S23(3)
		{LCDAC_COM0_BIT, KM6713S03_SEG20},	//S24(4)
		{LCDAC_COM1_BIT, KM6713S03_SEG20},	//S25(5)
		{LCDAC_COM2_BIT, KM6713S03_SEG20},	//S26(6)
};
/// Battery Icon.
const LCD_SEG_POS_S LcdBatteryIcon[3] ={
		{LCDAC_COM3_BIT, KM6713S03_SEG11},	//S29
		{LCDAC_COM3_BIT, KM6713S03_SEG22},	//S31
		{LCDAC_COM3_BIT, KM6713S03_SEG24},	//S30
};
/// Transmission Icon.
const LCD_SEG_POS_S LcdTransmissionIcon = {
		LCDAC_COM0_BIT, KM6713S03_SEG14 //S1
};


/* --- structure --- */
typedef struct lcdac_7seg_char_s
{
	char c;
	unsigned char b;
 }LCDAC_7SEG_CHAR_S;

/* --- constant variable --- */
static const unsigned char LcdAc7SegNumBitMap[] = {
	0x3F, 0x06, 0x5B, 0x4F, 0x66, 0x6D,
	0x7D, 0x07, 0x7F, 0x6F
};

static const LCDAC_7SEG_CHAR_S LcdAc7SegCharMap[] = {
	{'-', 0x40}, {'S', 0x6D}, {'P', 0x73}, {'R', 0x77}, {'E', 0x79},
	{'b', 0x7C}, {'o', 0x5C}, {'r', 0x50}, {'L', 0x38}, {'d', 0x5E},
};

/* --- external declaration --- */
extern volatile unsigned int c17lcd8afrmIntCount;


/************************************************************************//**
 * @brief  Initialize this interface.
 *
 * @retval  none
 ***************************************************************************/
void mid_initLcdAc(void)
{
	/// Initialize LCD.
	c17initLcd8a();

}
/************************************************************************//**
 * @brief  Turn on this interface.
 *
 * @retval  none
 ***************************************************************************/
void mid_onLcdAc(void)
{
	c17clearLcd8a();
	c17onLcd8aDisplay();
}
/************************************************************************//**
 * @brief  Turn off this interface.
 *
 * @retval  none
 ***************************************************************************/
void mid_offLcdAc(void)
{
	//Enable the frame interrupt.
	c17lcd8afrmIntCount = 0;
	c17onLcd8aDisplay();
	c17enableIntLcd8a();

	// Clear LCD.
	c17clearLcd8a();
	while (c17lcd8afrmIntCount < 5);

	// Turn off
	c17disableIntLcd8a();
	c17offLcd8aDisplay();

}
/************************************************************************//**
 * @brief  Clear display.
 *
 * @retval  none
 ***************************************************************************/
void mid_clrLcdAc(void)
{
	c17clearLcd8a();
}
/************************************************************************//**
 * @brief  Display separator.
 *
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcSeparator(void)
{
	mid_setLcdAcSegPosition(LCDAC_DISPLAY_AREA, &LcdSeparatorIcon, LCDAC_SEGMENT_ON);
}
/************************************************************************//**
 * @brief  Display temperature.
 *
 * @param  unit
 *   @li @c ACC_TEMP_UNIT_CELSIUS
 *   @li @c ACC_TEMP_UNIT_FAHRENHEIT
 * @param  temp   Temperature.
 *
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcTemperature(unsigned short unit, unsigned short temp)
{
	char str[8];

	if (unit == ACC_TEMP_UNIT_FAHRENHEIT)
	{
		temp = util_convC2F(temp);
	}
	util_decTo2DigitStr(str, temp, ' ');
	mid_dispLcdAc7Seg(LCDAC_DISPLAY_AREA, LcdTempUpper7seg, str[0]);
	mid_dispLcdAc7Seg(LCDAC_DISPLAY_AREA, LcdTempLower7seg, str[1]);
	mid_selectLcdAcSegGrp(LCDAC_DISPLAY_AREA, LcdTempUnitIcon, unit, 2);
}
/************************************************************************//**
 * @brief  Display operation mode icon.
 *
 * @param  index   Index number of icon to active.
 *
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcMode(int index)
{
	mid_selectLcdAcSegGrp(LCDAC_DISPLAY_AREA, LcdModeItemIcon, index, LCDAC_MODE_ITEM_COUNT);
}
/************************************************************************//**
 * @brief  Display vertical flap icon.
 *
 * @param  index   Index number of icon to active.
 *
 * @retval  None.
 ***************************************************************************/
void mid_dispLcdAcWindVert(int index)
{
	if (index == 0)
	{
		mid_setLcdAcSegGrp(LCDAC_DISPLAY_AREA, LcdWindVertItemIcon, LCDAC_SEGMENT_ON, LCDAC_WIND_VERT_ITEM_COUNT);
	}
	else
	{
		mid_selectLcdAcSegGrp(LCDAC_DISPLAY_AREA, LcdWindVertItemIcon, index, LCDAC_WIND_VERT_ITEM_COUNT);
	}
	mid_setLcdAcSegPosition(LCDAC_DISPLAY_AREA, &LcdWindVertSymbolIcon, LCDAC_SEGMENT_ON);
}
/************************************************************************//**
 * @brief  Display horizontal flap icon.
 *
 * @param  index   Index number of icon to active.
 *
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcWindHori(int index)
{
	if (index == 0)
	{
		mid_setLcdAcSegGrp(LCDAC_DISPLAY_AREA, LcdWindHoriItemIcon, LCDAC_SEGMENT_ON, LCDAC_WIND_HORI_ITEM_COUNT);
	}
	else
	{
		mid_selectLcdAcSegGrp(LCDAC_DISPLAY_AREA, LcdWindHoriItemIcon, index, LCDAC_WIND_HORI_ITEM_COUNT);
	}
	mid_setLcdAcSegPosition(LCDAC_DISPLAY_AREA, &LcdWindHoriSymbolIcon, LCDAC_SEGMENT_ON);
}
/************************************************************************//**
 * @brief  Display fan speed icon.
 *
 * @param  index   Index number of icon to active.
 *
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcWindFan(int index)
{
	int i;

	mid_setLcdAcSegPosition(LCDAC_DISPLAY_AREA, &LcdWindFanIcon[0],
						(index == 0) ? LCDAC_SEGMENT_ON : LCDAC_SEGMENT_OFF);
	for (i = 1; i < LCDAC_WIND_FAN_ITEM_COUNT; i++)
	{
		mid_setLcdAcSegPosition(LCDAC_DISPLAY_AREA, &LcdWindFanIcon[i],
				((index ==0) || ( i <= (index + 1))) ? LCDAC_SEGMENT_ON :  LCDAC_SEGMENT_OFF);
	}
}
/************************************************************************//**
 * @brief  Display battery level.
 *
 * @param  level
 *  @li @c LCDAC_BATTERY_LEVEL_NO
 *  @li @c LCDAC_BATTERY_LEVEL_LOW
 *  @li @c LCDAC_BATTERY_LEVEL_MID
 *  @li @c LCDAC_BATTERY_LEVEL_FULL
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcBatteryLevel(int level)
{
	int i;
	for (i = 0; i < 3; i++)
	{
		mid_setLcdAcSegPosition(LCDAC_DISPLAY_AREA, &LcdBatteryIcon[i],
				(i <= (level - 1)) ? LCDAC_SEGMENT_ON : LCDAC_SEGMENT_OFF);
	}
}
/************************************************************************//**
 * @brief  Display transmission icon.
 *
 * @param  isShow
 *  @li @c 0             Icon is hidden.
 *  @li @c 1             Icon is shown.
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcTransmission(int isShow)
{
	mid_setLcdAcSegPosition(LCDAC_DISPLAY_AREA, &LcdTransmissionIcon, isShow);
}
/************************************************************************//**
 * @brief  Display week icon.
 *
 * @param  index   Index number of icon to active.
 *
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcWeek(int index)
{
	mid_selectLcdAcSegGrp(LCDAC_DISPLAY_AREA, LcdWeekIcon, index, 7);
}
/************************************************************************//**
 * @brief  Show all week icon.
 *
 *
 * @retval  none
 ***************************************************************************/
void mid_showLcdAcAllWeek(void)
{
	mid_setLcdAcSegGrp(LCDAC_DISPLAY_AREA, LcdWeekIcon, LCDAC_SEGMENT_ON, 7);
}
/************************************************************************//**
 * @brief  Hide all week icon.
 *
 *
 * @retval  none
 ***************************************************************************/
void mid_hideLcdAcAllWeek(void)
{
	mid_setLcdAcSegGrp(LCDAC_DISPLAY_AREA, LcdWeekIcon, LCDAC_SEGMENT_OFF, 7);
}

/************************************************************************//**
 * @brief  Display the time(h:mm format).
 *
 * @param  position
 *  @li @c LCDAC_DAYTIMEPOS_LEFT  Left side.
 *  @li @c LCDAC_DAYTIMEPOS_RIGHT Right side.
 * @param  rtcaMode
 *  @li @c C17_RTCA_12H           12h
 *  @li @c C17_RTCA_24H           24h
 * @param  amPm
 *  @li @c C17_RTCA_AM            AM
 *  @li @c C17_RTCA_PM            PM
 * @param  bcdHour                Hour(BCD).
 * @param  bcdMinute              Minute(BCD).
 *
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcTime(int position, int rtcaMode, unsigned short amPm, unsigned short bcdHour, unsigned short bcdMinute)
{
	char str[12];

	if (rtcaMode == C17_RTCA_24H)
	{
		mid_dispLcdAcAmPm(position, LCDAC_AMPM_DISP_NONE);
	}
	else
	{
		if (amPm == C17_RTCA_AM)
		{

			mid_dispLcdAcAmPm(position, LCDAC_AMPM_DISP_AM);
		}
		else
		{
			mid_dispLcdAcAmPm(position, LCDAC_AMPM_DISP_PM);
		}
	}
	util_bcdTo2DigitStr(&str[0], bcdHour, ' ');
	str[2] = ':';
	util_bcdTo2DigitStr(&str[3], bcdMinute, '0');

	mid_dispLcdAcClockArea(position, 0, str);
}
/************************************************************************//**
 * @brief  Display the time(h:mm format) specified by serial time.
 *
 * @param  position
 *  @li @c LCDAC_DAYTIMEPOS_LEFT  Left side.
 *  @li @c LCDAC_DAYTIMEPOS_RIGHT Right side.
 * @param  rtcaMode
 *  @li @c C17_RTCA_12H           12h
 *  @li @c C17_RTCA_24H           24h
 * @param  seritime               Serial time.
 *
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcSerialTime(int position, int rtcaMode, unsigned short seritime)
{
	unsigned short ap = C17_RTCA_AM;
	unsigned short h = seritime / 60;
	unsigned short m = seritime % 60;
	
	if (rtcaMode == C17_RTCA_12H)
	{
		if (h >= 12)
		{
			h -= 12;
			ap = C17_RTCA_PM;
		}
	}
	mid_dispLcdAcTime(position, rtcaMode,
			ap, util_convUShortNumToBcd(h), util_convUShortNumToBcd(m));
}
/************************************************************************//**
 * @brief  Display the date(yyyy mm-dd format).
 *
 * @param  bcdYear                Year(BCD)
 * @param  bcdMonth               Month(BCD).
 * @param  bcdDay                 Day(BCD).
 * @param  week                   Week
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcDate(unsigned short bcdYear, unsigned short bcdMonth, unsigned short bcdDay, unsigned short week)
{
	mid_dispLcdAcYear(LCDAC_DAYTIMEPOS_LEFT, bcdYear);
	mid_dispLcdAcMonthDay(LCDAC_DAYTIMEPOS_RIGHT, bcdMonth, bcdDay);
	mid_dispLcdAcWeek(week);
}
/************************************************************************//**
 * @brief  Display month and day(mm-dd format).
 *
 * @param  position
 *  @li @c LCDAC_DAYTIMEPOS_LEFT  Left side.
 *  @li @c LCDAC_DAYTIMEPOS_RIGHT Right side.
 * @param  bcdMonth               Month(BCD).
 * @param  bcdDay                 Day(BCD).
 *
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcMonthDay(int position, unsigned short bcdMonth, unsigned short bcdDay)
{
	char str[12];
	mid_dispLcdAcAmPm(position, LCDAC_AMPM_DISP_NONE);
	util_bcdTo2DigitStr(&str[0], bcdMonth, '0');
	str[2] = '-';
	util_bcdTo2DigitStr(&str[3], bcdDay, '0');
	mid_dispLcdAcClockArea(position, 0, str);
}
/************************************************************************//**
 * @brief  Display the year(yyyy format).
 *
 * @param  position
 *  @li @c LCDAC_DAYTIMEPOS_LEFT  Left side.
 *  @li @c LCDAC_DAYTIMEPOS_RIGHT Right side.
 * @param  bcdYear                Year offset(BCD) based on 2000.
 *
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcYear(int position, unsigned short bcdYear)
{
	char str[12];
	mid_dispLcdAcAmPm(position, LCDAC_AMPM_DISP_NONE);
	str[0] = '2';
	str[1] = '0';
	util_bcdTo2DigitStr(&str[2], bcdYear, '0');
	mid_dispLcdAcClockArea(position, 0, str);
}

/************************************************************************//**
 * @brief  Display the string to the clock display area.
 *
 * @param  position
 *  @li @c LCDAC_DAYTIMEPOS_LEFT  Left side.
 *  @li @c LCDAC_DAYTIMEPOS_RIGHT Right side.
 * @param  offset
 *  @li @c 0 to 4                 Offset.
 * @param  pstr                   Pointer to string buffer.
 *
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcClockArea(int position, int offset, const char *pstr)
{
	int i = offset;
	while (*pstr != '\0')
	{
		if (i >= 5)
		{
			break;
		}
		if (position == LCDAC_DAYTIMEPOS_LEFT)
		{
			mid_dispLcdAc7Seg(LCDAC_DISPLAY_AREA, LcdLeftDayTime7seg[i], *pstr);
		}
		else
		{
			mid_dispLcdAc7Seg(LCDAC_DISPLAY_AREA, LcdRightDayTime7seg[i], *pstr);
		}
		i++;
		pstr++;
	}
}

/************************************************************************//**
 * @brief  Display timer ON icon.
 *
 * @param  isShow
 *  @li @c 0             Icon is hidden.
 *  @li @c 1             Icon is shown.
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcTimerOn(int isShow)
{
	mid_setLcdAcSegPosition(LCDAC_DISPLAY_AREA, &LcdTimerOnIcon, isShow);
}
/************************************************************************//**
 * @brief  Display timer OFF icon.
 *
 * @param  isShow
 *  @li @c 0             Icon is hidden.
 *  @li @c 1             Icon is shown.
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcTimerOff(int isShow)
{
	mid_setLcdAcSegPosition(LCDAC_DISPLAY_AREA, &LcdTimerOffIcon, isShow);
}

/************************************************************************//**
 * @brief  Display AM/PM icon.
 *
 * @param  position
 *  @li @c LCDAC_DAYTIMEPOS_LEFT  Left side.
 *  @li @c LCDAC_DAYTIMEPOS_RIGHT Right side.
 * @param  amPmDisp
 *  @li @c LCDAC_AMPM_DISP_AM     Show AM.
 *  @li @c LCDAC_AMPM_DISP_PM     Show PM.
 *  @li @c LCDAC_AMPM_DISP_NONE   Hide both AM and PM.
 *  @li @c LCDAC_AMPM_DISP_ALL    Show both AM and PM
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAcAmPm(int position, int amPmDisp)
{
	const LCD_SEG_POS_S *pAmPmPos = (position == LCDAC_DAYTIMEPOS_LEFT) ?
												LcdLeftDayTimeAmPm : LcdRightDayTimeAmPm;
	if (amPmDisp == LCDAC_AMPM_DISP_AM)
	{
		mid_selectLcdAcSegGrp(LCDAC_DISPLAY_AREA, pAmPmPos, 0, 2);
	}
	else if (amPmDisp == LCDAC_AMPM_DISP_PM)
	{
		mid_selectLcdAcSegGrp(LCDAC_DISPLAY_AREA, pAmPmPos, 1, 2);
	}
	else if (amPmDisp == LCDAC_AMPM_DISP_NONE)
	{
		mid_setLcdAcSegPosition(LCDAC_DISPLAY_AREA, &pAmPmPos[0], LCDAC_SEGMENT_OFF);
		mid_setLcdAcSegPosition(LCDAC_DISPLAY_AREA, &pAmPmPos[1], LCDAC_SEGMENT_OFF);
	}
	else if (amPmDisp == LCDAC_AMPM_DISP_ALL)
	{
		mid_setLcdAcSegPosition(LCDAC_DISPLAY_AREA, &pAmPmPos[0], LCDAC_SEGMENT_ON);
		mid_setLcdAcSegPosition(LCDAC_DISPLAY_AREA, &pAmPmPos[1], LCDAC_SEGMENT_ON);
	}
}

/************************************************************************//**
 * @brief  Display 7 segment pattern.
 *
 * @param   area
 *  @li @c  C17_LCD_DISPLAY_AREA0   Display area 0.
 *  @li @c  C17_LCD_DISPLAY_AREA1   Display area 1.
 * @param   pSegPos     Pointer to array which is stored segment positions.
 * @param   c           Character to display.
 *
 * @retval  none
 ***************************************************************************/
void mid_dispLcdAc7Seg(unsigned char area, const LCD_SEG_POS_S *pSegPos, char c)
{
	int i;
	unsigned char mask = 0x01;
	unsigned char map = 0;

	if ((c >= '0') && (c <= '9'))
	{
		map = LcdAc7SegNumBitMap[c - '0'];
	}
	else if (c == ':')
	{
		map = 0x80;
	}
	else
	{
		for (i = 0; i < (sizeof(LcdAc7SegCharMap) / sizeof(LCDAC_7SEG_CHAR_S)); i++) {
			if (c == LcdAc7SegCharMap[i].c)
			{
				map = LcdAc7SegCharMap[i].b;
				break;
			}
		}
	}
	for (i = 0; i < LCDAC_7SEG_COUNTS; i++, mask <<= 1)
	{
		mid_setLcdAcSegPosition(area, &pSegPos[i],
						(map & mask) ? LCDAC_SEGMENT_ON : LCDAC_SEGMENT_OFF);
	}
}

/************************************************************************//**
 * @brief  Select segment to turn on in group.
 * @param   area
 *  @li @c  C17_LCD_DISPLAY_AREA0   Display area 0.
 *  @li @c  C17_LCD_DISPLAY_AREA1   Display area 1.
 * @param   pSegPos     Pointer to array which is stored group of segment.
 * @param   index       Index number in array to active.
 * @param   length      Length of array.
 *
 * @retval  none
 ***************************************************************************/
void mid_selectLcdAcSegGrp(unsigned char area, const LCD_SEG_POS_S *pSegPos, int index, int length)
{
	int i;
	for (i = 0; i < length; i++)
	{
		mid_setLcdAcSegPosition(area, &pSegPos[i], (i == index) ? LCDAC_SEGMENT_ON : LCDAC_SEGMENT_OFF);
	}
}
/************************************************************************//**
 * @brief  Turn on or off All segment in group.
 * @param   area
 *  @li @c  C17_LCD_DISPLAY_AREA0   Display area 0.
 *  @li @c  C17_LCD_DISPLAY_AREA1   Display area 1.
 * @param   pSegPos  Pointer to array which is stored grouped icon.
 * @param   DispOnOff
 *  @li @c  LCDAC_SEGMENT_OFF       Turn on.
 *  @li @c  LCDAC_SEGMENT_ON        Turn off.
 * @param   length   Length of array.
 *
 * @retval  none
 ***************************************************************************/
void mid_setLcdAcSegGrp(unsigned char area, const LCD_SEG_POS_S *pSegPos, int DispOnOff, int length)
{
	int i;
	for (i = 0; i < length; i++)
	{
		mid_setLcdAcSegPosition(area, &pSegPos[i], DispOnOff);
	}
}
/************************************************************************//**
 * @brief  Set data to segment position in Display Data RAM.
 *
 * @param   area
 *  @li @c  C17_LCD_DISPLAY_AREA0   Display area 0.
 *  @li @c  C17_LCD_DISPLAY_AREA1   Display area 1.
 * @param   pSegPos  Segment positions in Display Data RAM.
 * @param   DispOnOff
 *  @li @c  LCDAC_SEGMENT_OFF   Write to 0 specified segment bit.
 *  @li @c  LCDAC_SEGMENT_ON    Write to 1 specified segment bit.
 * @retval  none
 ***************************************************************************/
void mid_setLcdAcSegPosition(unsigned char area, const LCD_SEG_POS_S *pSegPos, int DispOnOff)
{
	if (pSegPos->Common != LCDAC_COM_NONE)
	{
		volatile unsigned char *pSegRam = (area == C17_LCD_DISPLAY_AREA0) ?
											(volatile unsigned char*)LCD8A_SEGRAM_TOP_ADDR_AREA0 :
											(volatile unsigned char*)LCD8A_SEGRAM_TOP_ADDR_AREA1;

		if (DispOnOff == LCDAC_SEGMENT_OFF)
		{
			pSegRam[pSegPos->Segment] &= ~pSegPos->Common;
		}
		else
		{
			pSegRam[pSegPos->Segment] |= pSegPos->Common;
		}
	}
}
