/************************************************************************//**
 *
 * @file    mid_lcdac.h
 *
 * @brief   This is header file of LCD interface for the A/C.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2018. All rights reserved
 *
 * @warning -
 *
 * @par     History:
 *          - 16 Mar. 2018    1.00
 *              - First revision.
 *
 ***************************************************************************/

#ifndef MID_LCDAC_H_
#define MID_LCDAC_H_

#include "c17_lcd8a_1.h"
#include "c17_rtca_1.h"

/* --- definition --- */
enum
{
	LCDAC_DAYTIMEPOS_LEFT,
	LCDAC_DAYTIMEPOS_RIGHT
};
enum
{
	LCDAC_AMPM_DISP_AM,
	LCDAC_AMPM_DISP_PM,
	LCDAC_AMPM_DISP_NONE,
	LCDAC_AMPM_DISP_ALL,
};

enum
{
	LCDAC_BATTERY_LEVEL_NO,
	LCDAC_BATTERY_LEVEL_LOW,
	LCDAC_BATTERY_LEVEL_MID,
	LCDAC_BATTERY_LEVEL_FULL,

};

enum
{
	LCDAC_SEGMENT_OFF,				///< Turn off the segment.
	LCDAC_SEGMENT_ON					///< Turn off the segment.
};

#define LCDAC_DISPLAY_AREA	(0)
//7seg
#define LCDAC_7SEG_COUNTS		8	//7seg + colon

#define LCDAC_MODE_ITEM_COUNT		5	/// Number of operation mode.
#define LCDAC_WIND_VERT_ITEM_COUNT	6	/// Number of vertical flap.
#define LCDAC_WIND_HORI_ITEM_COUNT	6	/// Number of horizontal flap.
#define LCDAC_WIND_FAN_ITEM_COUNT	7	/// Number of fan speed index.

//Offset of segment pin in Display Memory Address.
#define LCDAC_SEG00_OFFSET		0
#define LCDAC_SEG01_OFFSET		1
#define LCDAC_SEG02_OFFSET		2
#define LCDAC_SEG03_OFFSET		3
#define LCDAC_SEG04_OFFSET		4
#define LCDAC_SEG05_OFFSET		5
#define LCDAC_SEG06_OFFSET		6
#define LCDAC_SEG07_OFFSET		7
#define LCDAC_SEG08_OFFSET		8
#define LCDAC_SEG09_OFFSET		9
#define LCDAC_SEG10_OFFSET		10
#define LCDAC_SEG11_OFFSET		11
#define LCDAC_SEG12_OFFSET		12
#define LCDAC_SEG13_OFFSET		13
#define LCDAC_SEG14_OFFSET		14
#define LCDAC_SEG15_OFFSET		15
#define LCDAC_SEG16_OFFSET		16
#define LCDAC_SEG17_OFFSET		17
#define LCDAC_SEG18_OFFSET		18
#define LCDAC_SEG19_OFFSET		19
#define LCDAC_SEG20_OFFSET		20
#define LCDAC_SEG21_OFFSET		21
#define LCDAC_SEG22_OFFSET		22
#define LCDAC_SEG23_OFFSET		23
#define LCDAC_SEG24_OFFSET		24
#define LCDAC_SEG25_OFFSET		25
#define LCDAC_SEG26_OFFSET		26
#define LCDAC_SEG27_OFFSET		27
#define LCDAC_SEG28_OFFSET		28
#define LCDAC_SEG29_OFFSET		29
#define LCDAC_SEG30_OFFSET		30
#define LCDAC_SEG31_OFFSET		31
#define LCDAC_SEG32_OFFSET		32
#define LCDAC_SEG33_OFFSET		33
#define LCDAC_SEG34_OFFSET		34
#define LCDAC_SEG35_OFFSET		35
#define LCDAC_SEG36_OFFSET		36
#define LCDAC_SEG37_OFFSET		37
#define LCDAC_SEG38_OFFSET		38
#define LCDAC_SEG39_OFFSET		39
#define LCDAC_SEG40_OFFSET		40
#define LCDAC_SEG41_OFFSET		41
#define LCDAC_SEG42_OFFSET		42
#define LCDAC_SEG43_OFFSET		43
#define LCDAC_SEG44_OFFSET		44
#define LCDAC_SEG45_OFFSET		45
#define LCDAC_SEG46_OFFSET		46
#define LCDAC_SEG47_OFFSET		47
#define LCDAC_SEG48_OFFSET		48
#define LCDAC_SEG49_OFFSET		49

//Bit position of common pin.
#define LCDAC_COM_NONE	0x00
#define LCDAC_COM0_BIT	0x08
#define LCDAC_COM1_BIT	0x04
#define LCDAC_COM2_BIT	0x02
#define LCDAC_COM3_BIT	0x01



/* --- Structure --- */
typedef struct lcd_seg_pos_s
{
	unsigned char Common;
	unsigned char Segment;
}LCD_SEG_POS_S;

/* --- external declaration --- */
extern void mid_initLcdAc(void);
extern void mid_onLcdAc(void);
extern void mid_offLcdAc(void);
extern void mid_clrLcdAc(void);
extern void mid_dispLcdAcSeparator(void);
extern void mid_dispLcdAcTemperature(unsigned short unit, unsigned short temp);
extern void mid_dispLcdAcMode(int index);
extern void mid_dispLcdAcWindVert(int index);
extern void mid_dispLcdAcWindHori(int index);
extern void mid_dispLcdAcWindFan(int index);
extern void mid_dispLcdAcBatteryLevel(int level);
extern void mid_dispLcdAcTransmission(int isShow);
extern void mid_dispLcdAcWeek(int index);
extern void mid_showLcdAcAllWeek(void);
extern void mid_hideLcdAcAllWeek(void);
extern void mid_dispLcdAcTime(int position, int rtcaMode, unsigned short amPm, unsigned short bcdHour, unsigned short bcdMinute);
extern void mid_dispLcdAcSerialTime(int position, int rtcaMode, unsigned short seritime);
extern void mid_dispLcdAcDate(unsigned short bcdYear, unsigned short bcdMonth, unsigned short bcdDay, unsigned short week);
extern void mid_dispLcdAcMonthDay(int position, unsigned short bcdMonth, unsigned short bcdDay);
extern void mid_dispLcdAcYear(int position, unsigned short bcdYear);
extern void mid_dispLcdAcClockArea(int position, int offset, const char *pstr);
extern void mid_dispLcdAcTimerOn(int isShow);
extern void mid_dispLcdAcTimerOff(int isShow);
extern void mid_dispLcdAcAmPm(int position, int amPmDisp);
extern void mid_dispLcdAc7Seg(unsigned char area, const LCD_SEG_POS_S *pSegPos, char c);
extern void mid_selectLcdAcSegGrp(unsigned char area, const LCD_SEG_POS_S *pSegPos, int index, int length);
extern void mid_setLcdAcSegGrp(unsigned char area, const LCD_SEG_POS_S *pSegPos, int DispOnOff, int length);
extern void mid_setLcdAcSegPosition(unsigned char area, const LCD_SEG_POS_S *pSegPos, int DispOnOff);

extern const LCD_SEG_POS_S LcdTempUpper7seg[LCDAC_7SEG_COUNTS];
extern const LCD_SEG_POS_S LcdTempLower7seg[LCDAC_7SEG_COUNTS];
extern const LCD_SEG_POS_S LcdTransmissionIcon;
extern const LCD_SEG_POS_S LcdModeItemIcon[];
extern const LCD_SEG_POS_S LcdTempUnitIcon[];
extern const LCD_SEG_POS_S LcdBatteryIcon[];
extern const LCD_SEG_POS_S LcdWindVertSymbolIcon;
extern const LCD_SEG_POS_S LcdWindVertItemIcon[];
extern const LCD_SEG_POS_S LcdWindHoriSymbolIcon;
extern const LCD_SEG_POS_S LcdWindHoriItemIcon[];
extern const LCD_SEG_POS_S LcdWindFanIcon[];
extern const LCD_SEG_POS_S LcdWeekIcon[];
extern const LCD_SEG_POS_S LcdTimerOnIcon;
extern const LCD_SEG_POS_S LcdTimerOffIcon;
extern const LCD_SEG_POS_S LcdLeftDayTimeAmPm[];
extern const LCD_SEG_POS_S LcdRightDayTimeAmPm[];
extern const LCD_SEG_POS_S LcdLeftDayTime7seg[5][LCDAC_7SEG_COUNTS];
extern const LCD_SEG_POS_S LcdRightDayTime7seg[5][LCDAC_7SEG_COUNTS];
extern const LCD_SEG_POS_S LcdSeparatorIcon;
#endif /* MID_LCDAC_H_ */
