/************************************************************************//**
 *
 * @file    c17m30_reg.h
 *
 * @brief   The definition of S1C17M30's register.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ******************************************************************************/

#ifndef C17M30_REG_H__
#define C17M30_REG_H__

#ifdef __cplusplus
extern "C" {
#endif


// Peripheral Register Header files
#include "reg/misc_reg.h"
#include "reg/pwg_reg.h"
#include "reg/clg_m30_m31_m32_m33_m34_reg.h"
#include "reg/itc_m30_m31_m32_m33_m34_reg.h"
#include "reg/wdt2_reg.h"
#include "reg/rtca_reg.h"
#include "reg/svd3_reg.h"
#include "reg/t16_reg.h"
#include "reg/flashc_reg.h"
#include "reg/pport_m30_m31_m32_m33_m34_reg.h"
#include "reg/upmux_m30_m31_m32_m33_m34_reg.h"
#include "reg/uart3_reg.h"
#include "reg/spia_reg.h"
#include "reg/i2c_reg.h"
#include "reg/t16b_reg.h"
#include "reg/snda_reg.h"
#include "reg/remc3_reg.h"
#include "reg/lcd8a_reg.h"
#include "reg/rfc_reg.h"
#include "reg/adc12a_reg.h"
#include "reg/tsrvr_reg.h"


// Peripheral Register Base Address
#define MISC_REG_BASE_ADDR      0x4000      ///< MISC Register Base Address.
#define PWG_REG_BASE_ADDR       0x4020      ///< PWG Register Base Address.
#define CLG_REG_BASE_ADDR       0x4040      ///< CLG Register Base Address.
#define ITC_REG_BASE_ADDR       0x4080      ///< ITC Register Base Address.
#define WDT2_REG_BASE_ADDR      0x40A0      ///< WDT2 Register Base Address.
#define RTCA_REG_BASE_ADDR      0x40C0      ///< RTCA Register Base Address.
#define SVD3_REG_BASE_ADDR      0x4100      ///< SVD3 Register Base Address.
#define T16_0_REG_BASE_ADDR     0x4160      ///< T16_0 Register Base Address.
#define T16_1_REG_BASE_ADDR     0x43A0      ///< T16_1 Register Base Address.
#define T16_2_REG_BASE_ADDR     0x5260      ///< T16_2 Register Base Address.
#define T16_3_REG_BASE_ADDR     0x5480      ///< T16_3 Register Base Address.
#define FLASHC_REG_BASE_ADDR    0x41B0      ///< FLASHC Register Base Address.
#define PPORT_REG_BASE_ADDR     0x4200      ///< PPORT Register Base Address.
#define UPMUX_REG_BASE_ADDR     0x4300      ///< UPMUX Register Base Address.
#define UART3_0_REG_BASE_ADDR   0x4380      ///< UART3_0 Register Base Address.
#define UART3_1_REG_BASE_ADDR   0x5200      ///< UART3_1 Register Base Address.
#define SPIA_0_REG_BASE_ADDR    0x43B0      ///< SPIA_0 Register Base Address.
#define SPIA_1_REG_BASE_ADDR    0x5270      ///< SPIA_1 Register Base Address.
#define I2C_0_REG_BASE_ADDR     0x43C0      ///< I2C_0 Register Base Address.
#define T16B_0_REG_BASE_ADDR    0x5000      ///< T16B_0 Register Base Address.
#define T16B_1_REG_BASE_ADDR    0x5040      ///< T16B_1 Register Base Address.
#define T16B_2_REG_BASE_ADDR    0x5080      ///< T16B_2 Register Base Address.
#define SNDA_REG_BASE_ADDR      0x5300      ///< SNDA Register Base Address.
#define REMC3_REG_BASE_ADDR     0x5320      ///< REMC3 Register Base Address.
#define LCD8A_REG_BASE_ADDR     0x5400      ///< LCD8A Register Base Address.
#define RFC_0_REG_BASE_ADDR     0x5440      ///< RFC_0 Register Base Address.
#define RFC_1_REG_BASE_ADDR     0x5460      ///< RFC_1 Register Base Address.
#define ADC12A_0_REG_BASE_ADDR  0x54A2      ///< ADC12A_0 Register Base Address.
#define TSRVR_0_REG_BASE_ADDR   0x54C0      ///< TSRVR_0 Register Base Address.


// ----- C17XXX Registers -----

/// ----- MISC -----

/// MISC System Protect Register.
#define MSCPROT                 (*((volatile MSCPROT_REG *)(MISC_REG_BASE_ADDR + 0x00))).reg
#define MSCPROT_PROT            (*((volatile MSCPROT_REG *)(MISC_REG_BASE_ADDR + 0x00))).bit.PROT        ///< These bits protect the control registers related to the system against writings.

/// MISC IRAM Size Register.
#define MSCIRAMSZ               (*((volatile MSCIRAMSZ_REG *)(MISC_REG_BASE_ADDR + 0x02))).reg
#define MSCIRAMSZ_IRAMSZ        (*((volatile MSCIRAMSZ_REG *)(MISC_REG_BASE_ADDR + 0x02))).bit.IRAMSZ      ///< These bits set the internal RAM size that can be used.

/// MISC Vector Table Address Low Register.
#define MSCTTBRL                (*((volatile MSCTTBRL_REG *)(MISC_REG_BASE_ADDR + 0x04))).reg
#define MSCTTBRL_TTBR           (*((volatile MSCTTBRL_REG *)(MISC_REG_BASE_ADDR + 0x04))).bit.TTBR        ///< These bits set the vector table base address (16 low-order bits).

/// MISC Vector Table Address High Register.
#define MSCTTBRH                (*((volatile MSCTTBRH_REG *)(MISC_REG_BASE_ADDR + 0x06))).reg
#define MSCTTBRH_TTBR           (*((volatile MSCTTBRH_REG *)(MISC_REG_BASE_ADDR + 0x06))).bit.TTBR        ///< These bits set the vector table base address (eight high-order bits).

/**
 * MISC Vector Table Address Register.
 * .TTBR[31:0]
 *  These bits set the vector table base address (32 order bits).
 */
#define MSCTTBR                 (*((volatile MSCTTBR_DWORD_REG *)(MISC_REG_BASE_ADDR + 0x04))).reg

/// MISC PSR Register.
#define MSCPSR                  (*((volatile MSCPSR_REG *)(MISC_REG_BASE_ADDR + 0x08))).reg
#define MSCPSR_PSRN             (*((volatile MSCPSR_REG *)(MISC_REG_BASE_ADDR + 0x08))).bit.PSRN        ///< The value (0 or 1) of the PSR N (negative) flag can be read out with this bit.
#define MSCPSR_PSRZ             (*((volatile MSCPSR_REG *)(MISC_REG_BASE_ADDR + 0x08))).bit.PSRZ        ///< The value (0 or 1) of the PSR Z (zero) flag can be read out with this bit.
#define MSCPSR_PSRV             (*((volatile MSCPSR_REG *)(MISC_REG_BASE_ADDR + 0x08))).bit.PSRV        ///< The value (0 or 1) of the PSR V (overflow) flag can be read out with this bit.
#define MSCPSR_PSRC             (*((volatile MSCPSR_REG *)(MISC_REG_BASE_ADDR + 0x08))).bit.PSRC        ///< The value (0 or 1) of the PSR C (carry) flag can be read out with this bit.
#define MSCPSR_PSRIE            (*((volatile MSCPSR_REG *)(MISC_REG_BASE_ADDR + 0x08))).bit.PSRIE       ///< The value (0 or 1) of the PSR IE (interrupt enable) bit can be read out with this bit.
#define MSCPSR_PSRIL            (*((volatile MSCPSR_REG *)(MISC_REG_BASE_ADDR + 0x08))).bit.PSRIL       ///< The value (0 to 7) of the PSR IL[2:0] (interrupt level) bits can be read out with these bits.

/// ----- PWG -----

/// PWG VD1 Regulator Control Register.
#define PWGVD1CTL               (*((volatile PWGVD1CTL_REG *)(PWG_REG_BASE_ADDR + 0x00))).reg
#define PWGVD1CTL_REGMODE       (*((volatile PWGVD1CTL_REG *)(PWG_REG_BASE_ADDR + 0x00))).bit.REGMODE     ///< PWG VD1 Regulator Control Register.

/// ----- CLG -----

/// CLG System Clock Control Register
#define CLGSCLK                 (*((volatile CLGSCLK_REG *)(CLG_REG_BASE_ADDR + 0x00))).reg
#define CLGSCLK_CLKSRC          (*((volatile CLGSCLK_REG *)(CLG_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the SYSCLK clock source.
#define CLGSCLK_CLKDIV          (*((volatile CLGSCLK_REG *)(CLG_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits set the division ratio of the clock source to determine the SYSCLK frequency.
#define CLGSCLK_WUPSRC          (*((volatile CLGSCLK_REG *)(CLG_REG_BASE_ADDR + 0x00))).bit.WUPSRC      ///< These bits select the SYSCLK clock source for resetting the CLGSCLK.CLKSRC[1:0] bits at wake-up.
#define CLGSCLK_WUPDIV          (*((volatile CLGSCLK_REG *)(CLG_REG_BASE_ADDR + 0x00))).bit.WUPDIV      ///< These bits select the SYSCLK division ratio for resetting the CLGSCLK.CLKDIV[1:0] bits at wake-up.
#define CLGSCLK_WUPMD           (*((volatile CLGSCLK_REG *)(CLG_REG_BASE_ADDR + 0x00))).bit.WUPMD       ///< This bit enables the SYSCLK switching function at wake-up.

/// CLG Oscillation Control Register.
#define CLGOSC                  (*((volatile CLGOSC_REG *)(CLG_REG_BASE_ADDR + 0x02))).reg
#define CLGOSC_IOSCEN           (*((volatile CLGOSC_REG *)(CLG_REG_BASE_ADDR + 0x02))).bit.IOSCEN      ///< This bit control the clock source(IOSC) operation.
#define CLGOSC_OSC1EN           (*((volatile CLGOSC_REG *)(CLG_REG_BASE_ADDR + 0x02))).bit.OSC1EN      ///< This bit control the clock source(OSC1) operation.
#define CLGOSC_OSC3EN           (*((volatile CLGOSC_REG *)(CLG_REG_BASE_ADDR + 0x02))).bit.OSC3EN      ///< This bit control the clock source(OSC3) operation.
#define CLGOSC_EXOSCEN          (*((volatile CLGOSC_REG *)(CLG_REG_BASE_ADDR + 0x02))).bit.EXOSCEN     ///< This bit control the clock source(EXOSC) operation.
#define CLGOSC_IOSCSLPC         (*((volatile CLGOSC_REG *)(CLG_REG_BASE_ADDR + 0x02))).bit.IOSCSLPC    ///< This bit control the clock source(IOSC) operations in SLEEP mode.
#define CLGOSC_OSC1SLPC         (*((volatile CLGOSC_REG *)(CLG_REG_BASE_ADDR + 0x02))).bit.OSC1SLPC    ///< This bit control the clock source(OSC1) operations in SLEEP mode.
#define CLGOSC_OSC3SLPC         (*((volatile CLGOSC_REG *)(CLG_REG_BASE_ADDR + 0x02))).bit.OSC3SLPC    ///< This bit control the clock source(OSC3) operations in SLEEP mode.
#define CLGOSC_EXOSCSLPC        (*((volatile CLGOSC_REG *)(CLG_REG_BASE_ADDR + 0x02))).bit.EXOSCSLPC   ///< This bit control the clock source(EXOSC) operations in SLEEP mode.

/// CLG OSC1 Control Register.
#define CLGOSC1                 (*((volatile CLGOSC1_REG *)(CLG_REG_BASE_ADDR + 0x06))).reg
#define CLGOSC1_OSC1WT          (*((volatile CLGOSC1_REG *)(CLG_REG_BASE_ADDR + 0x06))).bit.OSC1WT      ///< These bits set the oscillation stabilization waiting time for the OSC1 oscillator circuit.
#define CLGOSC1_INV1N           (*((volatile CLGOSC1_REG *)(CLG_REG_BASE_ADDR + 0x06))).bit.INV1N       ///< These bits set the oscillation inverter gain applied at normal operation of the OSC1 oscillator circuit.
#define CLGOSC1_INV1B           (*((volatile CLGOSC1_REG *)(CLG_REG_BASE_ADDR + 0x06))).bit.INV1B       ///< These bits set the oscillation inverter gain that will be applied at boost startup of the OSC1 oscillator circuit.
#define CLGOSC1_CGI1            (*((volatile CLGOSC1_REG *)(CLG_REG_BASE_ADDR + 0x06))).bit.CGI1        ///< These bits set the internal gate capacitance in the OSC1 oscillator circuit.
#define CLGOSC1_OSC1SELCR       (*((volatile CLGOSC1_REG *)(CLG_REG_BASE_ADDR + 0x06))).bit.OSC1SELCR   ///< This This bit selects an oscillator type of the OSC1 oscillator circuit.
#define CLGOSC1_OSC1BUP         (*((volatile CLGOSC1_REG *)(CLG_REG_BASE_ADDR + 0x06))).bit.OSC1BUP     ///< This bit enables the oscillation startup control circuit in the OSC1 oscillator circuit.
#define CLGOSC1_OSDEN           (*((volatile CLGOSC1_REG *)(CLG_REG_BASE_ADDR + 0x06))).bit.OSDEN       ///< This bit controls the oscillation stop detector in the OSC1 oscillator circuit.
#define CLGOSC1_OSDRB           (*((volatile CLGOSC1_REG *)(CLG_REG_BASE_ADDR + 0x06))).bit.OSDRB       ///< This bit enables the OSC1 oscillator circuit restart function by the oscillation stop detector when OSC1 oscillation stop is detected.

/// CLG OSC3 Control Register.
#define CLGOSC3                 (*((volatile CLGOSC3_REG *)(CLG_REG_BASE_ADDR + 0x08))).reg
#define CLGOSC3_OSC3WT          (*((volatile CLGOSC3_REG *)(CLG_REG_BASE_ADDR + 0x08))).bit.OSC3WT      ///< These bits set the oscillation stabilization waiting time for the OSC3 oscillator circuit.
#define CLGOSC3_OSC3STM         (*((volatile CLGOSC3_REG *)(CLG_REG_BASE_ADDR + 0x08))).bit.OSC3STM     ///< This bit controls the OSC3 internal oscillator auto-trimming function.
#define CLGOSC3_OSC3INV         (*((volatile CLGOSC3_REG *)(CLG_REG_BASE_ADDR + 0x08))).bit.OSC3INV     ///< These bits set the oscillation inverter gain of the OSC3 oscillator circuit.
#define CLGOSC3_OSC3MD          (*((volatile CLGOSC3_REG *)(CLG_REG_BASE_ADDR + 0x08))).bit.OSC3MD      ///< This bit selects an oscillator type of the OSC3 oscillator circuit.
#define CLGOSC3_OSC3FQ          (*((volatile CLGOSC3_REG *)(CLG_REG_BASE_ADDR + 0x08))).bit.OSC3FQ      ///< This bit sets the oscillation frequency of the OSC3 internal oscillator circuit.

/// CLG Interrupt Flag Register.
#define CLGINTF                 (*((volatile CLGINTF_REG *)(CLG_REG_BASE_ADDR + 0x0C))).reg
#define CLGINTF_IOSCSTAIF       (*((volatile CLGINTF_REG *)(CLG_REG_BASE_ADDR + 0x0C))).bit.IOSCSTAIF   ///< This bit indicate the oscillation stabilization waiting completion interrupt cause occurrence status in each clock source(IOSC).
#define CLGINTF_OSC1STAIF       (*((volatile CLGINTF_REG *)(CLG_REG_BASE_ADDR + 0x0C))).bit.OSC1STAIF   ///< This bit indicate the oscillation stabilization waiting completion interrupt cause occurrence status in each clock source(OSC1).
#define CLGINTF_OSC3STAIF       (*((volatile CLGINTF_REG *)(CLG_REG_BASE_ADDR + 0x0C))).bit.OSC3STAIF   ///< This bit indicate the oscillation stabilization waiting completion interrupt cause occurrence status in each clock source(OSC3).
#define CLGINTF_OSC3TEDIF       (*((volatile CLGINTF_REG *)(CLG_REG_BASE_ADDR + 0x0C))).bit.OSC3TEDIF   ///< This bit indicate the OSC3 oscillation auto-trimming completion interrupt cause occurrence statuses.
#define CLGINTF_OSC1STPIF       (*((volatile CLGINTF_REG *)(CLG_REG_BASE_ADDR + 0x0C))).bit.OSC1STPIF   ///< This bit indicate the OSC1 oscillation stop interrupt cause occurrence statuses.

/// CLG Interrupt Enable Register.
#define CLGINTE                 (*((volatile CLGINTE_REG *)(CLG_REG_BASE_ADDR + 0x0E))).reg
#define CLGINTE_IOSCSTAIE       (*((volatile CLGINTE_REG *)(CLG_REG_BASE_ADDR + 0x0E))).bit.IOSCSTAIE   ///< This bit enable the oscillation stabilization waiting completion interrupt of each clock source(IOSC).
#define CLGINTE_OSC1STAIE       (*((volatile CLGINTE_REG *)(CLG_REG_BASE_ADDR + 0x0E))).bit.OSC1STAIE   ///< This bit enable the oscillation stabilization waiting completion interrupt of each clock source(OSC1).
#define CLGINTE_OSC3STAIE       (*((volatile CLGINTE_REG *)(CLG_REG_BASE_ADDR + 0x0E))).bit.OSC3STAIE   ///< This bit enable the oscillation stabilization waiting completion interrupt of each clock source(OSC3).
#define CLGINTE_OSC3TEDIE       (*((volatile CLGINTE_REG *)(CLG_REG_BASE_ADDR + 0x0E))).bit.OSC3TEDIE   ///< This bit enable the OSC3 oscillation auto-trimming completion interrupt.
#define CLGINTE_OSC1STPIE       (*((volatile CLGINTE_REG *)(CLG_REG_BASE_ADDR + 0x0E))).bit.OSC1STPIE   ///< This bit enable the OSC1 oscillation stop.

/// CLG FOUT Control Register.
#define CLGFOUT                 (*((volatile CLGFOUT_REG *)(CLG_REG_BASE_ADDR + 0x10))).reg
#define CLGFOUT_FOUTEN          (*((volatile CLGFOUT_REG *)(CLG_REG_BASE_ADDR + 0x10))).bit.FOUTEN      ///< This bit controls the FOUT clock external output.
#define CLGFOUT_FOUTSRC         (*((volatile CLGFOUT_REG *)(CLG_REG_BASE_ADDR + 0x10))).bit.FOUTSRC     ///< These bits select the FOUT clock source.
#define CLGFOUT_FOUTDIV         (*((volatile CLGFOUT_REG *)(CLG_REG_BASE_ADDR + 0x10))).bit.FOUTDIV     ///< These bits set the FOUT clock division ratio.

/// ----- ITC -----

/// ITC Interrupt Level Setup Register 0
#define ITCLV0                  (*((volatile ITCLV0_REG *)(ITC_REG_BASE_ADDR + 0x00))).reg
#define ITCLV0_ILV0             (*((volatile ITCLV0_REG *)(ITC_REG_BASE_ADDR + 0x00))).bit.ILV0        ///< Supply voltage detector interrupt.
#define ITCLV0_ILV1             (*((volatile ITCLV0_REG *)(ITC_REG_BASE_ADDR + 0x00))).bit.ILV1        ///< Port interrupt.

/// ITC Interrupt Level Setup Register 1
#define ITCLV1                  (*((volatile ITCLV1_REG *)(ITC_REG_BASE_ADDR + 0x02))).reg
#define ITCLV1_ILV3             (*((volatile ITCLV1_REG *)(ITC_REG_BASE_ADDR + 0x02))).bit.ILV3        ///< Clock generator interrupt.

/// ITC Interrupt Level Setup Register 2
#define ITCLV2                  (*((volatile ITCLV2_REG *)(ITC_REG_BASE_ADDR + 0x04))).reg
#define ITCLV2_ILV4             (*((volatile ITCLV2_REG *)(ITC_REG_BASE_ADDR + 0x04))).bit.ILV4        ///< Real-time clock interrupt.
#define ITCLV2_ILV5             (*((volatile ITCLV2_REG *)(ITC_REG_BASE_ADDR + 0x04))).bit.ILV5        ///< 16-bit timer Ch.0 interrupt.

/// ITC Interrupt Level Setup Register 3
#define ITCLV3                  (*((volatile ITCLV3_REG *)(ITC_REG_BASE_ADDR + 0x06))).reg
#define ITCLV3_ILV6             (*((volatile ITCLV3_REG *)(ITC_REG_BASE_ADDR + 0x06))).bit.ILV6        ///< UART Ch.0 interrupt.
#define ITCLV3_ILV7             (*((volatile ITCLV3_REG *)(ITC_REG_BASE_ADDR + 0x06))).bit.ILV7        ///< 16-bit timer Ch.1 interrupt.

/// ITC Interrupt Level Setup Register 4
#define ITCLV4                  (*((volatile ITCLV4_REG *)(ITC_REG_BASE_ADDR + 0x08))).reg
#define ITCLV4_ILV8             (*((volatile ITCLV4_REG *)(ITC_REG_BASE_ADDR + 0x08))).bit.ILV8        ///< Synchronous serial interface Ch.0 interrupt.
#define ITCLV4_ILV9             (*((volatile ITCLV4_REG *)(ITC_REG_BASE_ADDR + 0x08))).bit.ILV9        ///< I2C Ch.0 interrupt.

/// ITC Interrupt Level Setup Register 5
#define ITCLV5                  (*((volatile ITCLV5_REG *)(ITC_REG_BASE_ADDR + 0x0A))).reg
#define ITCLV5_ILV10            (*((volatile ITCLV5_REG *)(ITC_REG_BASE_ADDR + 0x0A))).bit.ILV10       ///< 16-bit PWM timer Ch.0 interrupt.
#define ITCLV5_ILV11            (*((volatile ITCLV5_REG *)(ITC_REG_BASE_ADDR + 0x0A))).bit.ILV11       ///< 16-bit PWM timer Ch.1 interrupt.

/// ITC Interrupt Level Setup Register 6
#define ITCLV6                  (*((volatile ITCLV6_REG *)(ITC_REG_BASE_ADDR + 0x0C))).reg
#define ITCLV6_ILV12            (*((volatile ITCLV6_REG *)(ITC_REG_BASE_ADDR + 0x0C))).bit.ILV12       ///< UART Ch.1 interrupt.
#define ITCLV6_ILV13            (*((volatile ITCLV6_REG *)(ITC_REG_BASE_ADDR + 0x0C))).bit.ILV13       ///< Sound generator interrupt.

/// ITC Interrupt Level Setup Register 7
#define ITCLV7                  (*((volatile ITCLV7_REG *)(ITC_REG_BASE_ADDR + 0x0E))).reg
#define ITCLV7_ILV14            (*((volatile ITCLV7_REG *)(ITC_REG_BASE_ADDR + 0x0E))).bit.ILV14       ///< IR remote controller interrupt.
#define ITCLV7_ILV15            (*((volatile ITCLV7_REG *)(ITC_REG_BASE_ADDR + 0x0E))).bit.ILV15       ///< LCD driver interrupt.

/// ITC Interrupt Level Setup Register 8
#define ITCLV8                  (*((volatile ITCLV8_REG *)(ITC_REG_BASE_ADDR + 0x10))).reg
#define ITCLV8_ILV16            (*((volatile ITCLV8_REG *)(ITC_REG_BASE_ADDR + 0x10))).bit.ILV16       ///< R/F converter Ch.0 interrupt
#define ITCLV8_ILV17            (*((volatile ITCLV8_REG *)(ITC_REG_BASE_ADDR + 0x10))).bit.ILV17       ///< R/F converter Ch.1 interrupt.

/// ITC Interrupt Level Setup Register 9
#define ITCLV9                  (*((volatile ITCLV9_REG *)(ITC_REG_BASE_ADDR + 0x12))).reg
#define ITCLV9_ILV18            (*((volatile ITCLV9_REG *)(ITC_REG_BASE_ADDR + 0x12))).bit.ILV18       ///< 16-bit timer Ch.2 interrupt.
#define ITCLV9_ILV19            (*((volatile ITCLV9_REG *)(ITC_REG_BASE_ADDR + 0x12))).bit.ILV19       ///< Synchronous serial interface Ch.1 interrupt.

/// ITC Interrupt Level Setup Register 10
#define ITCLV10                 (*((volatile ITCLV10_REG *)(ITC_REG_BASE_ADDR + 0x14))).reg
#define ITCLV10_ILV20           (*((volatile ITCLV10_REG *)(ITC_REG_BASE_ADDR + 0x14))).bit.ILV20       ///< 16-bit timer Ch.3 interrupt.
#define ITCLV10_ILV21           (*((volatile ITCLV10_REG *)(ITC_REG_BASE_ADDR + 0x14))).bit.ILV21       ///< 12-bit A/D converter interrupt.

/// ITC Interrupt Level Setup Register 11
#define ITCLV11                 (*((volatile ITCLV11_REG *)(ITC_REG_BASE_ADDR + 0x16))).reg
#define ITCLV11_ILV22           (*((volatile ITCLV11_REG *)(ITC_REG_BASE_ADDR + 0x16))).bit.ILV22       ///< 16-bit PWM timer Ch.2 interrupt.


// Interrupt Level Registers.
#define ILVSVD					(ITCLV0_ILV0) 		///< Supply voltage detector interrupt level.
#define ILVPPORT				(ITCLV0_ILV1) 		///< Port interrupt level.
#define ILVCLG					(ITCLV1_ILV3) 		///< Clock generator interrupt level.
#define ILVRTCA_0				(ITCLV2_ILV4) 		///< Real-time clock interrupt.
#define ILVT16_0				(ITCLV2_ILV5) 		///< 16-bit timer Ch.0 interrupt level.
#define ILVUART_0				(ITCLV3_ILV6) 		///< UART Ch.0 interrupt level.
#define ILVT16_1				(ITCLV3_ILV7) 		///< 16-bit timer Ch.1 interrupt level.
#define ILVSPIA_0				(ITCLV4_ILV8) 		///< Synchronous serial interface Ch.0 interrupt level.
#define ILVI2C_0				(ITCLV4_ILV9) 		///< I2C interrupt Ch.0 level.
#define ILVT16B_0				(ITCLV5_ILV10)		///< 16-bit PWM timer Ch.0 interrupt level.
#define ILVT16B_1				(ITCLV5_ILV11)		///< 16-bit PWM timer Ch.1 interrupt level.
#define ILVUART_1				(ITCLV6_ILV12)		///< UART Ch.1 interrupt level.
#define ILVSNDA_0				(ITCLV6_ILV13)		///< Sound generator interrupt level.
#define ILVREMC_0				(ITCLV7_ILV14)		///< IR remote controller interrupt level.
#define ILVLCD8A				(ITCLV7_ILV15)		///< LCD driver interrupt level.
#define ILVRFC_0				(ITCLV8_ILV16)		///< R/F converter Ch.0 interrupt level.
#define ILVRFC_1				(ITCLV8_ILV17)		///< R/F converter Ch.1 interrupt level.
#define ILVT16_2				(ITCLV9_ILV18)		///< 16-bit timer Ch.2 interrupt.
#define ILVSPIA_1				(ITCLV9_ILV19)		///< Synchronous serial interface Ch.1 interrupt level.
#define ILVT16_3				(ITCLV10_ILV20)		///< 16-bit timer Ch.3 interrupt level.
#define ILVADC12_0				(ITCLV10_ILV21)		///< 12-bit A/D converter interrupt level.
#define ILVT16B_2				(ITCLV11_ILV22)		///< 16-bit PWM timer Ch.2 interrupt level.



/// ----- WDT2 -----

/// WDT2 Clock Control Register
#define WDTCLK                  (*((volatile WDTCLK_REG *)(WDT2_REG_BASE_ADDR + 0x00))).reg
#define WDTCLK_CLKSRC           (*((volatile WDTCLK_REG *)(WDT2_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of WDT2.
#define WDTCLK_CLKDIV           (*((volatile WDTCLK_REG *)(WDT2_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the WDT2 operating clock (counter clock).

/// This bit sets whether the WDT operating clock is supplied in DEBUG mode or not.
#define WDTCLK_DBRUN            (*((volatile WDTCLK_REG *)(WDT2_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// WDT2 Control Register
#define WDTCTL                  (*((volatile WDTCTL_REG *)(WDT2_REG_BASE_ADDR + 0x02))).reg
#define WDTCTL_WDTRUN           (*((volatile WDTCTL_REG *)(WDT2_REG_BASE_ADDR + 0x02))).bit.WDTRUN      ///< These bits control WDT2 to run and stop.
#define WDTCTL_WDTCNTRST        (*((volatile WDTCTL_REG *)(WDT2_REG_BASE_ADDR + 0x02))).bit.WDTCNTRST   ///< This bit resets the 10-bit counter and the WDTCTL.STATNMI bit.
#define WDTCTL_STATNMI          (*((volatile WDTCTL_REG *)(WDT2_REG_BASE_ADDR + 0x02))).bit.STATNMI     ///< This bit indicates that a counter overflow and NMI have occurred.
#define WDTCTL_MOD              (*((volatile WDTCTL_REG *)(WDT2_REG_BASE_ADDR + 0x02))).bit.MOD         ///< These bits set the WDT2 operating mode.

/// WDT2 Counter Compare Match Register.
#define WDTCMP                  (*((volatile WDTCMP_REG *)(WDT2_REG_BASE_ADDR + 0x04))).reg
#define WDTCMP_CMP              (*((volatile WDTCMP_REG *)(WDT2_REG_BASE_ADDR + 0x04))).bit.CMP         ///< These bits set the NMI/reset generation cycle.

/// ----- RTCA -----

/// RTCA Control Register
#define RTCCTLL                 (*((volatile RTCCTLL_REG *)(RTCA_REG_BASE_ADDR + 0x00))).reg
#define RTCCTLL_RTCRUN          (*((volatile RTCCTLL_REG *)(RTCA_REG_BASE_ADDR + 0x00))).bit.RTCRUN      ///< This bit starts/stops the real-time clock counter.
#define RTCCTLL_RTCRST          (*((volatile RTCCTLL_REG *)(RTCA_REG_BASE_ADDR + 0x00))).bit.RTCRST      ///< This bit resets the 1 Hz counter, the RTCCTL.RTCADJ bit, and the RTCCTL.RTCHLD bit.
#define RTCCTLL_RTCADJ          (*((volatile RTCCTLL_REG *)(RTCA_REG_BASE_ADDR + 0x00))).bit.RTCADJ      ///< This bit executes the 30-second correction time adjustment function.
#define RTCCTLL_RTC24H          (*((volatile RTCCTLL_REG *)(RTCA_REG_BASE_ADDR + 0x00))).bit.RTC24H      ///< This bit sets the hour counter to 24H mode or 12H mode.
#define RTCCTLL_RTCHLD          (*((volatile RTCCTLL_REG *)(RTCA_REG_BASE_ADDR + 0x00))).bit.RTCHLD      ///< This bit halts the count-up operation of the real-time clock counter.
#define RTCCTLL_RTCBSY          (*((volatile RTCCTLL_REG *)(RTCA_REG_BASE_ADDR + 0x00))).bit.RTCBSY      ///< This bit indicates whether the counter is performing count-up operation or not.

/// RTCA Control Register
#define RTCCTLH                 (*((volatile RTCCTLH_REG *)(RTCA_REG_BASE_ADDR + 0x01))).reg
#define RTCCTLH_RTCTRM          (*((volatile RTCCTLH_REG *)(RTCA_REG_BASE_ADDR + 0x01))).bit.RTCTRM      ///< Write the correction value for adjusting the 1 Hz frequency to these bits to execute theoretical regulation.
#define RTCCTLH_RTCTRMBSY       (*((volatile RTCCTLH_REG *)(RTCA_REG_BASE_ADDR + 0x01))).bit.RTCTRMBSY   ///< This bit indicates whether the theoretical regulation is currently executed or not.

/// RTCA Second Alarm Register
#define RTCALM1                 (*((volatile RTCALM1_REG *)(RTCA_REG_BASE_ADDR + 0x02))).reg
#define RTCALM1_RTCSLA          (*((volatile RTCALM1_REG *)(RTCA_REG_BASE_ADDR + 0x02))).bit.RTCSLA      ///< There bits set the 1-second digit of the alarm time.
#define RTCALM1_RTCSHA          (*((volatile RTCALM1_REG *)(RTCA_REG_BASE_ADDR + 0x02))).bit.RTCSHA      ///< There bits set the 10-second digit of the alarm time.

/// RTCA Hour/Minute Alarm Register
#define RTCALM2                 (*((volatile RTCALM2_REG *)(RTCA_REG_BASE_ADDR + 0x04))).reg
#define RTCALM2_RTCMILA         (*((volatile RTCALM2_REG *)(RTCA_REG_BASE_ADDR + 0x04))).bit.RTCMILA     ///< There bits set the 1-minute digit of the alarm time.
#define RTCALM2_RTCMIHA         (*((volatile RTCALM2_REG *)(RTCA_REG_BASE_ADDR + 0x04))).bit.RTCMIHA     ///< There bits set the 10-minute digit of the alarm time.
#define RTCALM2_RTCHLA          (*((volatile RTCALM2_REG *)(RTCA_REG_BASE_ADDR + 0x04))).bit.RTCHLA      ///< There bits set the 1-hour digit of the alarm time.
#define RTCALM2_RTCHHA          (*((volatile RTCALM2_REG *)(RTCA_REG_BASE_ADDR + 0x04))).bit.RTCHHA      ///< There bits set the 10-hour digit of the alarm time.
#define RTCALM2_RTCAPA          (*((volatile RTCALM2_REG *)(RTCA_REG_BASE_ADDR + 0x04))).bit.RTCAPA      ///< This bit set A.M. or P.M. of the alarm time in 12H mode (RTCCTL.RTC24H bit = 0).

/// RTCA Stopwatch Control Register
#define RTCSWCTL                (*((volatile RTCSWCTL_REG *)(RTCA_REG_BASE_ADDR + 0x06))).reg
#define RTCSWCTL_SWRUN          (*((volatile RTCSWCTL_REG *)(RTCA_REG_BASE_ADDR + 0x06))).bit.SWRUN       ///< This bit starts/stops the stop watch counter.
#define RTCSWCTL_SWRST          (*((volatile RTCSWCTL_REG *)(RTCA_REG_BASE_ADDR + 0x06))).bit.SWRST       ///< This bit resets the stop watch counter to 0x00.
#define RTCSWCTL_BCD100         (*((volatile RTCSWCTL_REG *)(RTCA_REG_BASE_ADDR + 0x06))).bit.BCD100      ///< The 1/100-second digits of the stop watch counter can be read as a BCD code.
#define RTCSWCTL_BCD10          (*((volatile RTCSWCTL_REG *)(RTCA_REG_BASE_ADDR + 0x06))).bit.BCD10       ///< The 1/10-second digits of the stop watch counter can be read as a BCD code.

/// RTCA Second/1[Hz] Register
#define RTCSEC                  (*((volatile RTCSEC_REG *)(RTCA_REG_BASE_ADDR + 0x08))).reg
#define RTCSEC_RTC128HZ         (*((volatile RTCSEC_REG *)(RTCA_REG_BASE_ADDR + 0x08))).bit.RTC128HZ    ///< 1 Hz counter data can be read from these bits(128Hz).
#define RTCSEC_RTC64HZ          (*((volatile RTCSEC_REG *)(RTCA_REG_BASE_ADDR + 0x08))).bit.RTC64HZ     ///< 1 Hz counter data can be read from these bits(64Hz).
#define RTCSEC_RTC32HZ          (*((volatile RTCSEC_REG *)(RTCA_REG_BASE_ADDR + 0x08))).bit.RTC32HZ     ///< 1 Hz counter data can be read from these bits(32Hz).
#define RTCSEC_RTC16HZ          (*((volatile RTCSEC_REG *)(RTCA_REG_BASE_ADDR + 0x08))).bit.RTC16HZ     ///< 1 Hz counter data can be read from these bits(16Hz).
#define RTCSEC_RTC8HZ           (*((volatile RTCSEC_REG *)(RTCA_REG_BASE_ADDR + 0x08))).bit.RTC8HZ      ///< 1 Hz counter data can be read from these bits(8Hz).
#define RTCSEC_RTC4HZ           (*((volatile RTCSEC_REG *)(RTCA_REG_BASE_ADDR + 0x08))).bit.RTC4HZ      ///< 1 Hz counter data can be read from these bits(4Hz).
#define RTCSEC_RTC2HZ           (*((volatile RTCSEC_REG *)(RTCA_REG_BASE_ADDR + 0x08))).bit.RTC2HZ      ///< 1 Hz counter data can be read from these bits(2Hz).
#define RTCSEC_RTC1HZ           (*((volatile RTCSEC_REG *)(RTCA_REG_BASE_ADDR + 0x08))).bit.RTC1HZ      ///< 1 Hz counter data can be read from these bits(1Hz).
#define RTCSEC_RTCSL            (*((volatile RTCSEC_REG *)(RTCA_REG_BASE_ADDR + 0x08))).bit.RTCSL       ///< There bits are used to set and read the 1-second digit of the second counter.
#define RTCSEC_RTCSH            (*((volatile RTCSEC_REG *)(RTCA_REG_BASE_ADDR + 0x08))).bit.RTCSH       ///< There bits are used to set and read the 10-second digit of the second counter.

/// RTCA Hour/Minute Register
#define RTCHUR                  (*((volatile RTCHUR_REG *)(RTCA_REG_BASE_ADDR + 0x0A))).reg
#define RTCHUR_RTCMIL           (*((volatile RTCHUR_REG *)(RTCA_REG_BASE_ADDR + 0x0A))).bit.RTCMIL      ///< There bits are used to set and read the 1-minute digit of the minute counter.
#define RTCHUR_RTCMIH           (*((volatile RTCHUR_REG *)(RTCA_REG_BASE_ADDR + 0x0A))).bit.RTCMIH      ///< There bits are used to set and read the 10-minute digit of the minute counter.
#define RTCHUR_RTCHL            (*((volatile RTCHUR_REG *)(RTCA_REG_BASE_ADDR + 0x0A))).bit.RTCHL       ///< There bits are used to set and read the 1-hour digit of the hour counter.
#define RTCHUR_RTCHH            (*((volatile RTCHUR_REG *)(RTCA_REG_BASE_ADDR + 0x0A))).bit.RTCHH       ///< There bits are used to set and read the 10-hour digit of the hour counter.
#define RTCHUR_RTCAP            (*((volatile RTCHUR_REG *)(RTCA_REG_BASE_ADDR + 0x0A))).bit.RTCAP       ///< This bit is used to set and read A.M. or P.M. data in 12H mode (RTCCTL.RTC24H bit = 0).

/// RTCA Month/Day Register
#define RTCMON                  (*((volatile RTCMON_REG *)(RTCA_REG_BASE_ADDR + 0x0C))).reg
#define RTCMON_RTCDL            (*((volatile RTCMON_REG *)(RTCA_REG_BASE_ADDR + 0x0C))).bit.RTCDL       ///< There bits are used to set and read the 1-day digit of the day counter.
#define RTCMON_RTCDH            (*((volatile RTCMON_REG *)(RTCA_REG_BASE_ADDR + 0x0C))).bit.RTCDH       ///< There bits are used to set and read the 10-day digit of the day counter.
#define RTCMON_RTCMOL           (*((volatile RTCMON_REG *)(RTCA_REG_BASE_ADDR + 0x0C))).bit.RTCMOL      ///< There bits are used to set and read the 1-month digit of the month counter.
#define RTCMON_RTCMOH           (*((volatile RTCMON_REG *)(RTCA_REG_BASE_ADDR + 0x0C))).bit.RTCMOH      ///< There bits are used to set and read the 10-month digit of the month counter.

/// RTCA Year/Week Register
#define RTCYAR                  (*((volatile RTCYAR_REG *)(RTCA_REG_BASE_ADDR + 0x0E))).reg
#define RTCYAR_RTCYL            (*((volatile RTCYAR_REG *)(RTCA_REG_BASE_ADDR + 0x0E))).bit.RTCYL       ///< There bits are used to set and read the 1-year digit of the year counter.
#define RTCYAR_RTCYH            (*((volatile RTCYAR_REG *)(RTCA_REG_BASE_ADDR + 0x0E))).bit.RTCYH       ///< There bits are used to set and read the 10-year digit of the year counter.

/// These bits are used to set and read day of the week.
#define RTCYAR_RTCWK            (*((volatile RTCYAR_REG *)(RTCA_REG_BASE_ADDR + 0x0E))).byte_reg[1]

/// RTCA Interrupt Flag Register
#define RTCINTF                 (*((volatile RTCINTF_REG *)(RTCA_REG_BASE_ADDR + 0x10))).reg
#define RTCINTF_1_32SECIF       (*((volatile RTCINTF_REG *)(RTCA_REG_BASE_ADDR + 0x10))).bit._1_32SECIF  ///< This bit indicate 1/32-second interrupt cause occurrence status.
#define RTCINTF_1_8SECIF        (*((volatile RTCINTF_REG *)(RTCA_REG_BASE_ADDR + 0x10))).bit._1_8SECIF   ///< This bit indicate 1/8-second interrupt cause occurrence status.
#define RTCINTF_1_4SECIF        (*((volatile RTCINTF_REG *)(RTCA_REG_BASE_ADDR + 0x10))).bit._1_4SECIF   ///< This bit indicate 1/4-second interrupt cause occurrence status.
#define RTCINTF_1_2SECIF        (*((volatile RTCINTF_REG *)(RTCA_REG_BASE_ADDR + 0x10))).bit._1_2SECIF   ///< This bit indicate 1/2-second interrupt cause occurrence status.
#define RTCINTF_1SECIF          (*((volatile RTCINTF_REG *)(RTCA_REG_BASE_ADDR + 0x10))).bit._1SECIF     ///< This bit indicate 1-second interrupt cause occurrence status.
#define RTCINTF_1MINIF          (*((volatile RTCINTF_REG *)(RTCA_REG_BASE_ADDR + 0x10))).bit._1MINIF     ///< This bit indicate 1-minute interrupt cause occurrence status.
#define RTCINTF_1HURIF          (*((volatile RTCINTF_REG *)(RTCA_REG_BASE_ADDR + 0x10))).bit._1HURIF     ///< This bit indicate 1-day interrupt cause occurrence status.
#define RTCINTF_1DAYIF          (*((volatile RTCINTF_REG *)(RTCA_REG_BASE_ADDR + 0x10))).bit._1DAYIF     ///< This bit indicate 1-day interrupt cause occurrence status.
#define RTCINTF_ALARMIF         (*((volatile RTCINTF_REG *)(RTCA_REG_BASE_ADDR + 0x10))).bit.ALARMIF     ///< This bit indicate Alarm interrupt cause occurrence status.
#define RTCINTF_SW100IF         (*((volatile RTCINTF_REG *)(RTCA_REG_BASE_ADDR + 0x10))).bit.SW100IF     ///< This bit indicate Stop watch 100 Hz interrupt cause occurrence status.
#define RTCINTF_SW10IF          (*((volatile RTCINTF_REG *)(RTCA_REG_BASE_ADDR + 0x10))).bit.SW10IF      ///< This bit indicate Stop watch 10 Hz interrupt cause occurrence status.
#define RTCINTF_SW1IF           (*((volatile RTCINTF_REG *)(RTCA_REG_BASE_ADDR + 0x10))).bit.SW1IF       ///< This bit indicate Stop watch 1 Hz interrupt cause occurrence status.
#define RTCINTF_RTCTRMIF        (*((volatile RTCINTF_REG *)(RTCA_REG_BASE_ADDR + 0x10))).bit.RTCTRMIF    ///< This bit indicate Theoretical regulation completion interrupt cause occurrence status.

/// RTCA Interrupt Enable Register
#define RTCINTE                 (*((volatile RTCINTE_REG *)(RTCA_REG_BASE_ADDR + 0x12))).reg
#define RTCINTE_1_32SECIE       (*((volatile RTCINTE_REG *)(RTCA_REG_BASE_ADDR + 0x12))).bit._1_32SECIE  ///< This bits enable 1/32-second interrupt.
#define RTCINTE_1_8SECIE        (*((volatile RTCINTE_REG *)(RTCA_REG_BASE_ADDR + 0x12))).bit._1_8SECIE   ///< This bits enable 1/8-second interrupt.
#define RTCINTE_1_4SECIE        (*((volatile RTCINTE_REG *)(RTCA_REG_BASE_ADDR + 0x12))).bit._1_4SECIE   ///< This bits enable 1/4-second interrupt.
#define RTCINTE_1_2SECIE        (*((volatile RTCINTE_REG *)(RTCA_REG_BASE_ADDR + 0x12))).bit._1_2SECIE   ///< This bits enable 1/2-second interrupt.
#define RTCINTE_1SECIE          (*((volatile RTCINTE_REG *)(RTCA_REG_BASE_ADDR + 0x12))).bit._1SECIE     ///< This bits enable 1-second interrupt.
#define RTCINTE_1MINIE          (*((volatile RTCINTE_REG *)(RTCA_REG_BASE_ADDR + 0x12))).bit._1MINIE     ///< This bits enable 1-minute interrupt.
#define RTCINTE_1HURIE          (*((volatile RTCINTE_REG *)(RTCA_REG_BASE_ADDR + 0x12))).bit._1HURIE     ///< This bits enable 1-hour interrupt.
#define RTCINTE_1DAYIE          (*((volatile RTCINTE_REG *)(RTCA_REG_BASE_ADDR + 0x12))).bit._1DAYIE     ///< This bits enable 1-day interrupt.
#define RTCINTE_ALARMIE         (*((volatile RTCINTE_REG *)(RTCA_REG_BASE_ADDR + 0x12))).bit.ALARMIE     ///< This bits enable Alarm interrupt.
#define RTCINTE_SW100IE         (*((volatile RTCINTE_REG *)(RTCA_REG_BASE_ADDR + 0x12))).bit.SW100IE     ///< This bit enable Stop watch 100 Hz interrupt.
#define RTCINTE_SW10IE          (*((volatile RTCINTE_REG *)(RTCA_REG_BASE_ADDR + 0x12))).bit.SW10IE      ///< This bit enable Stop watch 10 Hz interrupt.
#define RTCINTE_SW1IE           (*((volatile RTCINTE_REG *)(RTCA_REG_BASE_ADDR + 0x12))).bit.SW1IE       ///< This bit enable Stop watch 1 Hz interrupt.
#define RTCINTE_RTCTRMIE        (*((volatile RTCINTE_REG *)(RTCA_REG_BASE_ADDR + 0x12))).bit.RTCTRMIE    ///< This bit enable Theoretical regulation completion interrupt.

/// ----  SVD3 ----

/// SVD Clock Control Register
#define SVDCLK                  (*((volatile SVDCLK_REG *)(SVD3_REG_BASE_ADDR + 0x00))).reg
#define SVDCLK_CLKSRC           (*((volatile SVDCLK_REG *)(SVD3_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of SVD3.
#define SVDCLK_CLKDIV           (*((volatile SVDCLK_REG *)(SVD3_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the SVD3 operating clock.

/// This bit sets whether the SVD3 operating clock is supplied in DEBUG mode or not.
#define SVDCLK_DBRUN            (*((volatile SVDCLK_REG *)(SVD3_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// SVD3 Control Register
#define SVDCTL                  (*((volatile SVDCTL_REG *)(SVD3_REG_BASE_ADDR + 0x02))).reg
#define SVDCTL_MODEN            (*((volatile SVDCTL_REG *)(SVD3_REG_BASE_ADDR + 0x02))).bit.MODEN       ///< This bit enables/disables for the SVD3 circuit to operate.
#define SVDCTL_SVDMD            (*((volatile SVDCTL_REG *)(SVD3_REG_BASE_ADDR + 0x02))).bit.SVDMD       ///< These bits select intermittent operation mode and its detection cycle.
#define SVDCTL_EXSEL            (*((volatile SVDCTL_REG *)(SVD3_REG_BASE_ADDR + 0x02))).bit.EXSEL       ///< This bit selects the external voltage to be detected when the SVDCTL.VDSEL bit = 1.
#define SVDCTL_SVDRE            (*((volatile SVDCTL_REG *)(SVD3_REG_BASE_ADDR + 0x02))).bit.SVDRE       ///< These bits enable/disable the reset issuance function when a low power supply voltage is detected.
#define SVDCTL_SVDC             (*((volatile SVDCTL_REG *)(SVD3_REG_BASE_ADDR + 0x02))).bit.SVDC        ///< These bits select an SVD3 detection voltage VSVD  for detecting low voltage.
#define SVDCTL_SVDSC            (*((volatile SVDCTL_REG *)(SVD3_REG_BASE_ADDR + 0x02))).bit.SVDSC       ///< These bits set the condition to generate an interrupt/reset in intermittent operation mode.
#define SVDCTL_VDSEL            (*((volatile SVDCTL_REG *)(SVD3_REG_BASE_ADDR + 0x02))).bit.VDSEL       ///< This bit selects the power supply voltage to be detected by SVD3.

/// SVD3 Status and Interrupt Flag Register
#define SVDINTF                 (*((volatile SVDINTF_REG *)(SVD3_REG_BASE_ADDR + 0x04))).reg

/// This bit indicates the low power supply voltage detection interrupt cause occurrence status.
#define SVDINTF_SVDIF           (*((volatile SVDINTF_REG *)(SVD3_REG_BASE_ADDR + 0x04))).byte_reg[0]

/// The power supply voltage detection results can be read out from this bit.
#define SVDINTF_SVDDT           (*((volatile SVDINTF_REG *)(SVD3_REG_BASE_ADDR + 0x04))).byte_reg[1]

/// SVD3 Interrupt Enable Register
#define SVDINTE                 (*((volatile SVDINTE_REG *)(SVD3_REG_BASE_ADDR + 0x06))).reg
#define SVDINTE_SVDIE           (*((volatile SVDINTE_REG *)(SVD3_REG_BASE_ADDR + 0x06))).bit.SVDIE       ///< SVD3 Interrupt Enable Register

/// ----- T16 -----

/// T16 Ch.0 Clock Control Register
#define T16_0CLK                (*((volatile T16_NCLK_REG *)(T16_0_REG_BASE_ADDR + 0x00))).reg
#define T16_0CLK_CLKSRC         (*((volatile T16_NCLK_REG *)(T16_0_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of T16 Ch.0.
#define T16_0CLK_CLKDIV         (*((volatile T16_NCLK_REG *)(T16_0_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the T16 Ch.0 operating clock (counter clock).

/// This bit sets whether the T16 Ch.0 operating clock is supplied in DEBUG mode or not.
#define T16_0CLK_DBRUN          (*((volatile T16_NCLK_REG *)(T16_0_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// T16 Ch.0 Mode Register
#define T16_0MOD                (*((volatile T16_NMOD_REG *)(T16_0_REG_BASE_ADDR + 0x02))).reg
#define T16_0MOD_TRMD           (*((volatile T16_NMOD_REG *)(T16_0_REG_BASE_ADDR + 0x02))).bit.TRMD        ///< This bit selects the T16 operation mode.

/// T16 Ch.0 Control Register
#define T16_0CTL                (*((volatile T16_NCTL_REG *)(T16_0_REG_BASE_ADDR + 0x04))).reg
#define T16_0CTL_MODEN          (*((volatile T16_NCTL_REG *)(T16_0_REG_BASE_ADDR + 0x04))).bit.MODEN       ///< This bit enables the T16 Ch.0 operations.
#define T16_0CTL_PRESET         (*((volatile T16_NCTL_REG *)(T16_0_REG_BASE_ADDR + 0x04))).bit.PRESET      ///< This bit presets the reload data stored in the T16_0TR register to the counter.

/// This bit starts/stops the timer(Ch.0).
#define T16_0CTL_PRUN           (*((volatile T16_NCTL_REG *)(T16_0_REG_BASE_ADDR + 0x04))).byte_reg[1]

/// T16 Ch.0 Reload Data Register
#define T16_0TR                 (*((volatile T16_NTR_REG *)(T16_0_REG_BASE_ADDR + 0x06))).reg
#define T16_0TR_TR              (*((volatile T16_NTR_REG *)(T16_0_REG_BASE_ADDR + 0x06))).bit.TR          ///< These bits are used to set the initial value to be preset to the counter.

/// T16 Ch.0 Counter Data Register
#define T16_0TC                 (*((volatile T16_NTC_REG *)(T16_0_REG_BASE_ADDR + 0x08))).reg
#define T16_0TC_TC              (*((volatile T16_NTC_REG *)(T16_0_REG_BASE_ADDR + 0x08))).bit.TC          ///< The current counter value can be read out from these bits.

/// T16 Ch.0 Interrupt Flag Register
#define T16_0INTF               (*((volatile T16_NINTF_REG *)(T16_0_REG_BASE_ADDR + 0x0A))).reg
#define T16_0INTF_UFIF          (*((volatile T16_NINTF_REG *)(T16_0_REG_BASE_ADDR + 0x0A))).bit.UFIF        ///< This bit indicates the T16 Ch.0 underflow interrupt cause occurrence status.

/// T16 Ch.0 Interrupt Enable Register
#define T16_0INTE               (*((volatile T16_NINTE_REG *)(T16_0_REG_BASE_ADDR + 0x0C))).reg
#define T16_0INTE_UFIE          (*((volatile T16_NINTE_REG *)(T16_0_REG_BASE_ADDR + 0x0C))).bit.UFIE        ///< This bit enables T16 Ch.0 underflow interrupts.

///

/// T16 Ch.1 Clock Control Register
#define T16_1CLK                (*((volatile T16_NCLK_REG *)(T16_1_REG_BASE_ADDR + 0x00))).reg
#define T16_1CLK_CLKSRC         (*((volatile T16_NCLK_REG *)(T16_1_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of T16 Ch.1.
#define T16_1CLK_CLKDIV         (*((volatile T16_NCLK_REG *)(T16_1_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the T16 Ch.1 operating clock (counter clock).

/// This bit sets whether the T16 Ch.1 operating clock is supplied in DEBUG mode or not.
#define T16_1CLK_DBRUN          (*((volatile T16_NCLK_REG *)(T16_1_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// T16 Ch.1 Mode Register
#define T16_1MOD                (*((volatile T16_NMOD_REG *)(T16_1_REG_BASE_ADDR + 0x02))).reg
#define T16_1MOD_TRMD           (*((volatile T16_NMOD_REG *)(T16_1_REG_BASE_ADDR + 0x02))).bit.TRMD        ///< This bit selects the T16 operation mode.

/// T16 Ch.1 Control Register
#define T16_1CTL                (*((volatile T16_NCTL_REG *)(T16_1_REG_BASE_ADDR + 0x04))).reg
#define T16_1CTL_MODEN          (*((volatile T16_NCTL_REG *)(T16_1_REG_BASE_ADDR + 0x04))).bit.MODEN       ///< This bit enables the T16 Ch.1 operations.
#define T16_1CTL_PRESET         (*((volatile T16_NCTL_REG *)(T16_1_REG_BASE_ADDR + 0x04))).bit.PRESET      ///< This bit presets the reload data stored in the T16_1TR register to the counter.

/// This bit starts/stops the timer.
#define T16_1CTL_PRUN           (*((volatile T16_NCTL_REG *)(T16_1_REG_BASE_ADDR + 0x04))).byte_reg[1]

/// T16 Ch.1 Reload Data Register
#define T16_1TR                 (*((volatile T16_NTR_REG *)(T16_1_REG_BASE_ADDR + 0x06))).reg
#define T16_1TR_TR              (*((volatile T16_NTR_REG *)(T16_1_REG_BASE_ADDR + 0x06))).bit.TR          ///< These bits are used to set the initial value to be preset to the counter.

/// T16 Ch.1 Counter Data Register
#define T16_1TC                 (*((volatile T16_NTC_REG *)(T16_1_REG_BASE_ADDR + 0x08))).reg
#define T16_1TC_TC              (*((volatile T16_NTC_REG *)(T16_1_REG_BASE_ADDR + 0x08))).bit.TC          ///< The current counter value can be read out from these bits.

/// T16 Ch.1 Interrupt Flag Register
#define T16_1INTF               (*((volatile T16_NINTF_REG *)(T16_1_REG_BASE_ADDR + 0x0A))).reg
#define T16_1INTF_UFIF          (*((volatile T16_NINTF_REG *)(T16_1_REG_BASE_ADDR + 0x0A))).bit.UFIF        ///< This bit indicates the T16 Ch.1 underflow interrupt cause occurrence status.

/// T16 Ch.1 Interrupt Enable Register
#define T16_1INTE               (*((volatile T16_NINTE_REG *)(T16_1_REG_BASE_ADDR + 0x0C))).reg
#define T16_1INTE_UFIE          (*((volatile T16_NINTE_REG *)(T16_1_REG_BASE_ADDR + 0x0C))).bit.UFIE        ///< This bit enables T16 Ch.1 underflow interrupts.

///

/// T16 Ch.2 Clock Control Register
#define T16_2CLK                (*((volatile T16_NCLK_REG *)(T16_2_REG_BASE_ADDR + 0x00))).reg
#define T16_2CLK_CLKSRC         (*((volatile T16_NCLK_REG *)(T16_2_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of T16 Ch.2.
#define T16_2CLK_CLKDIV         (*((volatile T16_NCLK_REG *)(T16_2_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the T16 Ch.2 operating clock (counter clock).

/// This bit sets whether the T16 Ch.2 operating clock is supplied in DEBUG mode or not.
#define T16_2CLK_DBRUN          (*((volatile T16_NCLK_REG *)(T16_2_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// T16 Ch.2 Mode Register
#define T16_2MOD                (*((volatile T16_NMOD_REG *)(T16_2_REG_BASE_ADDR + 0x02))).reg
#define T16_2MOD_TRMD           (*((volatile T16_NMOD_REG *)(T16_2_REG_BASE_ADDR + 0x02))).bit.TRMD        ///< This bit selects the T16 operation mode.

/// T16 Ch.2 Control Register
#define T16_2CTL                (*((volatile T16_NCTL_REG *)(T16_2_REG_BASE_ADDR + 0x04))).reg
#define T16_2CTL_MODEN          (*((volatile T16_NCTL_REG *)(T16_2_REG_BASE_ADDR + 0x04))).bit.MODEN       ///< This bit enables the T16 Ch.2 operations.
#define T16_2CTL_PRESET         (*((volatile T16_NCTL_REG *)(T16_2_REG_BASE_ADDR + 0x04))).bit.PRESET      ///< This bit presets the reload data stored in the T16_2TR register to the counter.

/// This bit starts/stops the timer.
#define T16_2CTL_PRUN           (*((volatile T16_NCTL_REG *)(T16_2_REG_BASE_ADDR + 0x04))).byte_reg[1]

/// T16 Ch.2 Reload Data Register
#define T16_2TR                 (*((volatile T16_NTR_REG *)(T16_2_REG_BASE_ADDR + 0x06))).reg
#define T16_2TR_TR              (*((volatile T16_NTR_REG *)(T16_2_REG_BASE_ADDR + 0x06))).bit.TR          ///< These bits are used to set the initial value to be preset to the counter.

/// T16 Ch.2 Counter Data Register
#define T16_2TC                 (*((volatile T16_NTC_REG *)(T16_2_REG_BASE_ADDR + 0x08))).reg
#define T16_2TC_TC              (*((volatile T16_NTC_REG *)(T16_2_REG_BASE_ADDR + 0x08))).bit.TC          ///< The current counter value can be read out from these bits.

/// T16 Ch.2 Interrupt Flag Register
#define T16_2INTF               (*((volatile T16_NINTF_REG *)(T16_2_REG_BASE_ADDR + 0x0A))).reg
#define T16_2INTF_UFIF          (*((volatile T16_NINTF_REG *)(T16_2_REG_BASE_ADDR + 0x0A))).bit.UFIF        ///< This bit indicates the T16 Ch.2 underflow interrupt cause occurrence status.

/// T16 Ch.2 Interrupt Enable Register
#define T16_2INTE               (*((volatile T16_NINTE_REG *)(T16_2_REG_BASE_ADDR + 0x0C))).reg
#define T16_2INTE_UFIE          (*((volatile T16_NINTE_REG *)(T16_2_REG_BASE_ADDR + 0x0C))).bit.UFIE        ///< This bit enables T16 Ch.2 underflow interrupts.

///

/// T16 Ch.3 Clock Control Register
#define T16_3CLK                (*((volatile T16_NCLK_REG *)(T16_3_REG_BASE_ADDR + 0x00))).reg
#define T16_3CLK_CLKSRC         (*((volatile T16_NCLK_REG *)(T16_3_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of T16 Ch.3.
#define T16_3CLK_CLKDIV         (*((volatile T16_NCLK_REG *)(T16_3_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the T16 Ch.3 operating clock (counter clock).

/// This bit sets whether the T16 Ch.3 operating clock is supplied in DEBUG mode or not.
#define T16_3CLK_DBRUN          (*((volatile T16_NCLK_REG *)(T16_3_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// T16 Ch.3 Mode Register
#define T16_3MOD                (*((volatile T16_NMOD_REG *)(T16_3_REG_BASE_ADDR + 0x02))).reg
#define T16_3MOD_TRMD           (*((volatile T16_NMOD_REG *)(T16_3_REG_BASE_ADDR + 0x02))).bit.TRMD        ///< This bit selects the T16 operation mode.

/// T16 Ch.3 Control Register
#define T16_3CTL                (*((volatile T16_NCTL_REG *)(T16_3_REG_BASE_ADDR + 0x04))).reg
#define T16_3CTL_MODEN          (*((volatile T16_NCTL_REG *)(T16_3_REG_BASE_ADDR + 0x04))).bit.MODEN       ///< This bit enables the T16 Ch.3 operations.
#define T16_3CTL_PRESET         (*((volatile T16_NCTL_REG *)(T16_3_REG_BASE_ADDR + 0x04))).bit.PRESET      ///< This bit presets the reload data stored in the T16_3TR register to the counter.

/// This bit starts/stops the timer.
#define T16_3CTL_PRUN           (*((volatile T16_NCTL_REG *)(T16_3_REG_BASE_ADDR + 0x04))).byte_reg[1]

/// T16 Ch.3 Reload Data Register
#define T16_3TR                 (*((volatile T16_NTR_REG *)(T16_3_REG_BASE_ADDR + 0x06))).reg
#define T16_3TR_TR              (*((volatile T16_NTR_REG *)(T16_3_REG_BASE_ADDR + 0x06))).bit.TR          ///< These bits are used to set the initial value to be preset to the counter.

/// T16 Ch.3 Counter Data Register
#define T16_3TC                 (*((volatile T16_NTC_REG *)(T16_3_REG_BASE_ADDR + 0x08))).reg
#define T16_3TC_TC              (*((volatile T16_NTC_REG *)(T16_3_REG_BASE_ADDR + 0x08))).bit.TC          ///< The current counter value can be read out from these bits.

/// T16 Ch.3 Interrupt Flag Register
#define T16_3INTF               (*((volatile T16_NINTF_REG *)(T16_3_REG_BASE_ADDR + 0x0A))).reg
#define T16_3INTF_UFIF          (*((volatile T16_NINTF_REG *)(T16_3_REG_BASE_ADDR + 0x0A))).bit.UFIF        ///< This bit indicates the T16 Ch.3 underflow interrupt cause occurrence status.

/// T16 Ch.3 Interrupt Enable Register
#define T16_3INTE               (*((volatile T16_NINTE_REG *)(T16_3_REG_BASE_ADDR + 0x0C))).reg
#define T16_3INTE_UFIE          (*((volatile T16_NINTE_REG *)(T16_3_REG_BASE_ADDR + 0x0C))).bit.UFIE        ///< This bit enables T16 Ch.3 underflow interrupts.

/// ----- FLASHC -----

/// FLASHC Flash Read Cycle Register
#define FLASHCWAIT              (*((volatile FLASHCWAIT_REG *)(FLASHC_REG_BASE_ADDR + 0x00))).reg
#define FLASHCWAIT_RDWAIT       (*((volatile FLASHCWAIT_REG *)(FLASHC_REG_BASE_ADDR + 0x00))).bit.RDWAIT      ///< These bits set the number of bus access cycles for reading from the Flash memory.

/// ----- PPORT -----

/// P0 Port Data Register
#define P0DAT                   (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).reg
#define P0DAT_P00IN             (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P00IN       ///< The GPIO port pin status can be read out from this bit.
#define P0DAT_P01IN             (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P01IN       ///< The GPIO port pin status can be read out from this bit.
#define P0DAT_P02IN             (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P02IN       ///< The GPIO port pin status can be read out from this bit.
#define P0DAT_P03IN             (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P03IN       ///< The GPIO port pin status can be read out from this bit.
#define P0DAT_P04IN             (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P04IN       ///< The GPIO port pin status can be read out from this bit.
#define P0DAT_P05IN             (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P05IN       ///< The GPIO port pin status can be read out from this bit.
#define P0DAT_P06IN             (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P06IN       ///< The GPIO port pin status can be read out from this bit.
#define P0DAT_P07IN             (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P07IN       ///< The GPIO port pin status can be read out from this bit.
#define P0DAT_P00OUT            (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P00OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P0DAT_P01OUT            (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P01OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P0DAT_P02OUT            (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P02OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P0DAT_P03OUT            (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P03OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P0DAT_P04OUT            (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P04OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P0DAT_P05OUT            (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P05OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P0DAT_P06OUT            (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P06OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P0DAT_P07OUT            (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).bit.P07OUT      ///< This bit is used to set data to be output from the GPIO port pin.

/// The GPIO port pin status can be read out from these bits.
#define P0DAT_P0IN              (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).byte_reg[0]

/// These bits are used to set data to be output from the GPIO port pins.
#define P0DAT_P0OUT             (*((volatile P0DAT_REG *)(PPORT_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// P0 Port Enable Register
#define P0IOEN                  (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).reg
#define P0IOEN_P00OEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P00OEN      ///< This bit enable/disable the GPIO port output.
#define P0IOEN_P01OEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P01OEN      ///< This bit enable/disable the GPIO port output.
#define P0IOEN_P02OEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P02OEN      ///< This bit enable/disable the GPIO port output.
#define P0IOEN_P03OEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P03OEN      ///< This bit enable/disable the GPIO port output.
#define P0IOEN_P04OEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P04OEN      ///< This bit enable/disable the GPIO port output.
#define P0IOEN_P05OEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P05OEN      ///< This bit enable/disable the GPIO port output.
#define P0IOEN_P06OEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P06OEN      ///< This bit enable/disable the GPIO port output.
#define P0IOEN_P07OEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P07OEN      ///< This bit enable/disable the GPIO port output.
#define P0IOEN_P00IEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P00IEN      ///< This bit enable/disable the GPIO port input.
#define P0IOEN_P01IEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P01IEN      ///< This bit enable/disable the GPIO port input.
#define P0IOEN_P02IEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P02IEN      ///< This bit enable/disable the GPIO port input.
#define P0IOEN_P03IEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P03IEN      ///< This bit enable/disable the GPIO port input.
#define P0IOEN_P04IEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P04IEN      ///< This bit enable/disable the GPIO port input.
#define P0IOEN_P05IEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P05IEN      ///< This bit enable/disable the GPIO port input.
#define P0IOEN_P06IEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P06IEN      ///< This bit enable/disable the GPIO port input.
#define P0IOEN_P07IEN           (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).bit.P07IEN      ///< This bit enable/disable the GPIO port input.

/// These bits enable/disable the GPIO port output.
#define P0IOEN_P0OEN            (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).byte_reg[0]

/// These bits enable/disable the GPIO port input.
#define P0IOEN_P0IEN            (*((volatile P0IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x02))).byte_reg[1]

/// P0 Port Pull-up/down Control Register
#define P0RCTL                  (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).reg
#define P0RCTL_P00REN           (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P00REN      ///< This bit enable/disable the port pull-up/down control.
#define P0RCTL_P01REN           (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P01REN      ///< This bit enable/disable the port pull-up/down control.
#define P0RCTL_P02REN           (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P02REN      ///< This bit enable/disable the port pull-up/down control.
#define P0RCTL_P03REN           (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P03REN      ///< This bit enable/disable the port pull-up/down control.
#define P0RCTL_P04REN           (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P04REN      ///< This bit enable/disable the port pull-up/down control.
#define P0RCTL_P05REN           (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P05REN      ///< This bit enable/disable the port pull-up/down control.
#define P0RCTL_P06REN           (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P06REN      ///< This bit enable/disable the port pull-up/down control.
#define P0RCTL_P07REN           (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P07REN      ///< This bit enable/disable the port pull-up/down control.
#define P0RCTL_P00PDPU          (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P00PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P0RCTL_P01PDPU          (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P01PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P0RCTL_P02PDPU          (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P02PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P0RCTL_P03PDPU          (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P03PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P0RCTL_P04PDPU          (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P04PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P0RCTL_P05PDPU          (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P05PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P0RCTL_P06PDPU          (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P06PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P0RCTL_P07PDPU          (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).bit.P07PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.

/// These bits enable/disable the port pull-up/down control.
#define P0RCTL_P0REN            (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).byte_reg[0]

/// These bits select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P0RCTL_P0PDPU           (*((volatile P0RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x04))).byte_reg[1]

/// P0 Port Interrupt Flag Register
#define P0INTF                  (*((volatile P0INTF_REG *)(PPORT_REG_BASE_ADDR + 0x06))).reg
#define P0INTF_P00IF            (*((volatile P0INTF_REG *)(PPORT_REG_BASE_ADDR + 0x06))).bit.P00IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P0INTF_P01IF            (*((volatile P0INTF_REG *)(PPORT_REG_BASE_ADDR + 0x06))).bit.P01IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P0INTF_P02IF            (*((volatile P0INTF_REG *)(PPORT_REG_BASE_ADDR + 0x06))).bit.P02IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P0INTF_P03IF            (*((volatile P0INTF_REG *)(PPORT_REG_BASE_ADDR + 0x06))).bit.P03IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P0INTF_P04IF            (*((volatile P0INTF_REG *)(PPORT_REG_BASE_ADDR + 0x06))).bit.P04IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P0INTF_P05IF            (*((volatile P0INTF_REG *)(PPORT_REG_BASE_ADDR + 0x06))).bit.P05IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P0INTF_P06IF            (*((volatile P0INTF_REG *)(PPORT_REG_BASE_ADDR + 0x06))).bit.P06IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P0INTF_P07IF            (*((volatile P0INTF_REG *)(PPORT_REG_BASE_ADDR + 0x06))).bit.P07IF       ///< This bit indicate the port input interrupt cause occurrence status.

/// P0 Port Interrupt Control Register
#define P0INTCTL                (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).reg
#define P0INTCTL_P00IE          (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P00IE       ///< This bit enable port input interrupt.
#define P0INTCTL_P01IE          (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P01IE       ///< This bit enable port input interrupt.
#define P0INTCTL_P02IE          (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P02IE       ///< This bit enable port input interrupt.
#define P0INTCTL_P03IE          (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P03IE       ///< This bit enable port input interrupt.
#define P0INTCTL_P04IE          (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P04IE       ///< This bit enable port input interrupt.
#define P0INTCTL_P05IE          (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P05IE       ///< This bit enable port input interrupt.
#define P0INTCTL_P06IE          (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P06IE       ///< This bit enable port input interrupt.
#define P0INTCTL_P07IE          (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P07IE       ///< This bit enable port input interrupt.
#define P0INTCTL_P00EDGE        (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P00EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P0INTCTL_P01EDGE        (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P01EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P0INTCTL_P02EDGE        (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P02EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P0INTCTL_P03EDGE        (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P03EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P0INTCTL_P04EDGE        (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P04EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P0INTCTL_P05EDGE        (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P05EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P0INTCTL_P06EDGE        (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P06EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P0INTCTL_P07EDGE        (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).bit.P07EDGE     ///< This bit select the input signal edge to generate a port input interrupt.

/// These bits enable port input interrupt.
#define P0INTCTL_P0IE           (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).byte_reg[0]

/// These bits select the input signal edge to generate a port input interrupt.
#define P0INTCTL_P0EDGE         (*((volatile P0INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x08))).byte_reg[1]

/// P0 Port Chattering Filter Enable Register
#define P0CHATEN                (*((volatile P0CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x0A))).reg
#define P0CHATEN_P00CHATEN      (*((volatile P0CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x0A))).bit.P00CHATEN   ///< This bit enable/disable the chattering filter function.
#define P0CHATEN_P01CHATEN      (*((volatile P0CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x0A))).bit.P01CHATEN   ///< This bit enable/disable the chattering filter function.
#define P0CHATEN_P02CHATEN      (*((volatile P0CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x0A))).bit.P02CHATEN   ///< This bit enable/disable the chattering filter function.
#define P0CHATEN_P03CHATEN      (*((volatile P0CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x0A))).bit.P03CHATEN   ///< This bit enable/disable the chattering filter function.
#define P0CHATEN_P04CHATEN      (*((volatile P0CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x0A))).bit.P04CHATEN   ///< This bit enable/disable the chattering filter function.
#define P0CHATEN_P05CHATEN      (*((volatile P0CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x0A))).bit.P05CHATEN   ///< This bit enable/disable the chattering filter function.
#define P0CHATEN_P06CHATEN      (*((volatile P0CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x0A))).bit.P06CHATEN   ///< This bit enable/disable the chattering filter function.
#define P0CHATEN_P07CHATEN      (*((volatile P0CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x0A))).bit.P07CHATEN   ///< This bit enable/disable the chattering filter function.

/// P0 Port Mode Select Register
#define P0MODSEL                (*((volatile P0MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0C))).reg
#define P0MODSEL_P00SEL         (*((volatile P0MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0C))).bit.P00SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P0MODSEL_P01SEL         (*((volatile P0MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0C))).bit.P01SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P0MODSEL_P02SEL         (*((volatile P0MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0C))).bit.P02SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P0MODSEL_P03SEL         (*((volatile P0MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0C))).bit.P03SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P0MODSEL_P04SEL         (*((volatile P0MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0C))).bit.P04SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P0MODSEL_P05SEL         (*((volatile P0MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0C))).bit.P05SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P0MODSEL_P06SEL         (*((volatile P0MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0C))).bit.P06SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P0MODSEL_P07SEL         (*((volatile P0MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0C))).bit.P07SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.

/// P0 Port Function Select Register
#define P0FNCSEL                (*((volatile P0FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0E))).reg
#define P0FNCSEL_P00MUX         (*((volatile P0FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0E))).bit.P00MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P0FNCSEL_P01MUX         (*((volatile P0FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0E))).bit.P01MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P0FNCSEL_P02MUX         (*((volatile P0FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0E))).bit.P02MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P0FNCSEL_P03MUX         (*((volatile P0FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0E))).bit.P03MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P0FNCSEL_P04MUX         (*((volatile P0FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0E))).bit.P04MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P0FNCSEL_P05MUX         (*((volatile P0FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0E))).bit.P05MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P0FNCSEL_P06MUX         (*((volatile P0FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0E))).bit.P06MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P0FNCSEL_P07MUX         (*((volatile P0FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x0E))).bit.P07MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.

/// P1 Port Data Register
#define P1DAT                   (*((volatile P1DAT_REG *)(PPORT_REG_BASE_ADDR + 0x10))).reg
#define P1DAT_P10IN             (*((volatile P1DAT_REG *)(PPORT_REG_BASE_ADDR + 0x10))).bit.P10IN       ///< The GPIO port pin status can be read out from this bit.
#define P1DAT_P11IN             (*((volatile P1DAT_REG *)(PPORT_REG_BASE_ADDR + 0x10))).bit.P11IN       ///< The GPIO port pin status can be read out from this bit.
#define P1DAT_P12IN             (*((volatile P1DAT_REG *)(PPORT_REG_BASE_ADDR + 0x10))).bit.P12IN       ///< The GPIO port pin status can be read out from this bit.
#define P1DAT_P13IN             (*((volatile P1DAT_REG *)(PPORT_REG_BASE_ADDR + 0x10))).bit.P13IN       ///< The GPIO port pin status can be read out from this bit.
#define P1DAT_P10OUT            (*((volatile P1DAT_REG *)(PPORT_REG_BASE_ADDR + 0x10))).bit.P10OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P1DAT_P11OUT            (*((volatile P1DAT_REG *)(PPORT_REG_BASE_ADDR + 0x10))).bit.P11OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P1DAT_P12OUT            (*((volatile P1DAT_REG *)(PPORT_REG_BASE_ADDR + 0x10))).bit.P12OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P1DAT_P13OUT            (*((volatile P1DAT_REG *)(PPORT_REG_BASE_ADDR + 0x10))).bit.P13OUT      ///< This bit is used to set data to be output from the GPIO port pin.

/// The GPIO port pin status can be read out from these bits.
#define P1DAT_P1IN              (*((volatile P1DAT_REG *)(PPORT_REG_BASE_ADDR + 0x10))).byte_reg[0]

/// These bits are used to set data to be output from the GPIO port pins.
#define P1DAT_P1OUT             (*((volatile P1DAT_REG *)(PPORT_REG_BASE_ADDR + 0x10))).byte_reg[1]

/// P1 Port Enable Register
#define P1IOEN                  (*((volatile P1IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x12))).reg
#define P1IOEN_P10OEN           (*((volatile P1IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x12))).bit.P10OEN      ///< This bit enable/disable the GPIO port output.
#define P1IOEN_P11OEN           (*((volatile P1IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x12))).bit.P11OEN      ///< This bit enable/disable the GPIO port output.
#define P1IOEN_P12OEN           (*((volatile P1IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x12))).bit.P12OEN      ///< This bit enable/disable the GPIO port output.
#define P1IOEN_P13OEN           (*((volatile P1IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x12))).bit.P13OEN      ///< This bit enable/disable the GPIO port output.
#define P1IOEN_P10IEN           (*((volatile P1IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x12))).bit.P10IEN      ///< This bit enable/disable the GPIO port input.
#define P1IOEN_P11IEN           (*((volatile P1IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x12))).bit.P11IEN      ///< This bit enable/disable the GPIO port input.
#define P1IOEN_P12IEN           (*((volatile P1IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x12))).bit.P12IEN      ///< This bit enable/disable the GPIO port input.
#define P1IOEN_P13IEN           (*((volatile P1IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x12))).bit.P13IEN      ///< This bit enable/disable the GPIO port input.

/// These bits enable/disable the GPIO port output.
#define P1IOEN_P1OEN            (*((volatile P1IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x12))).byte_reg[0]

/// These bits enable/disable the GPIO port input.
#define P1IOEN_P1IEN            (*((volatile P1IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x12))).byte_reg[1]

/// P1 Port Pull-up/down Control Register
#define P1RCTL                  (*((volatile P1RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x14))).reg
#define P1RCTL_P10REN           (*((volatile P1RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x14))).bit.P10REN      ///< This bit enable/disable the port pull-up/down control.
#define P1RCTL_P11REN           (*((volatile P1RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x14))).bit.P11REN      ///< This bit enable/disable the port pull-up/down control.
#define P1RCTL_P12REN           (*((volatile P1RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x14))).bit.P12REN      ///< This bit enable/disable the port pull-up/down control.
#define P1RCTL_P13REN           (*((volatile P1RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x14))).bit.P13REN      ///< This bit enable/disable the port pull-up/down control.
#define P1RCTL_P10PDPU          (*((volatile P1RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x14))).bit.P10PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P1RCTL_P11PDPU          (*((volatile P1RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x14))).bit.P11PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P1RCTL_P12PDPU          (*((volatile P1RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x14))).bit.P12PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P1RCTL_P13PDPU          (*((volatile P1RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x14))).bit.P13PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.

/// These bits enable/disable the port pull-up/down control.
#define P1RCTL_P1REN            (*((volatile P1RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x14))).byte_reg[0]

/// These bits select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P1RCTL_P1PDPU           (*((volatile P1RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x14))).byte_reg[1]

/// P1 Port Interrupt Flag Register
#define P1INTF                  (*((volatile P1INTF_REG *)(PPORT_REG_BASE_ADDR + 0x16))).reg
#define P1INTF_P10IF            (*((volatile P1INTF_REG *)(PPORT_REG_BASE_ADDR + 0x16))).bit.P10IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P1INTF_P11IF            (*((volatile P1INTF_REG *)(PPORT_REG_BASE_ADDR + 0x16))).bit.P11IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P1INTF_P12IF            (*((volatile P1INTF_REG *)(PPORT_REG_BASE_ADDR + 0x16))).bit.P12IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P1INTF_P13IF            (*((volatile P1INTF_REG *)(PPORT_REG_BASE_ADDR + 0x16))).bit.P13IF       ///< This bit indicate the port input interrupt cause occurrence status.

/// P1 Port Interrupt Control Register
#define P1INTCTL                (*((volatile P1INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x18))).reg
#define P1INTCTL_P10IE          (*((volatile P1INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x18))).bit.P10IE       ///< This bit enable port input interrupt.
#define P1INTCTL_P11IE          (*((volatile P1INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x18))).bit.P11IE       ///< This bit enable port input interrupt.
#define P1INTCTL_P12IE          (*((volatile P1INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x18))).bit.P12IE       ///< This bit enable port input interrupt.
#define P1INTCTL_P13IE          (*((volatile P1INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x18))).bit.P13IE       ///< This bit enable port input interrupt.
#define P1INTCTL_P10EDGE        (*((volatile P1INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x18))).bit.P10EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P1INTCTL_P11EDGE        (*((volatile P1INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x18))).bit.P11EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P1INTCTL_P12EDGE        (*((volatile P1INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x18))).bit.P12EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P1INTCTL_P13EDGE        (*((volatile P1INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x18))).bit.P13EDGE     ///< This bit select the input signal edge to generate a port input interrupt.

/// These bits enable port input interrupt.
#define P1INTCTL_P1IE           (*((volatile P1INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x18))).byte_reg[0]

/// These bits select the input signal edge to generate a port input interrupt.
#define P1INTCTL_P1EDGE         (*((volatile P1INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x18))).byte_reg[1]

/// P1 Port Chattering Filter Enable Register
#define P1CHATEN                (*((volatile P1CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x1A))).reg
#define P1CHATEN_P10CHATEN      (*((volatile P1CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x1A))).bit.P10CHATEN   ///< This bit enable/disable the chattering filter function.
#define P1CHATEN_P11CHATEN      (*((volatile P1CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x1A))).bit.P11CHATEN   ///< This bit enable/disable the chattering filter function.
#define P1CHATEN_P12CHATEN      (*((volatile P1CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x1A))).bit.P12CHATEN   ///< This bit enable/disable the chattering filter function.
#define P1CHATEN_P13CHATEN      (*((volatile P1CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x1A))).bit.P13CHATEN   ///< This bit enable/disable the chattering filter function.

/// P1 Port Mode Select Register
#define P1MODSEL                (*((volatile P1MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x1C))).reg
#define P1MODSEL_P10SEL         (*((volatile P1MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x1C))).bit.P10SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P1MODSEL_P11SEL         (*((volatile P1MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x1C))).bit.P11SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P1MODSEL_P12SEL         (*((volatile P1MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x1C))).bit.P12SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P1MODSEL_P13SEL         (*((volatile P1MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x1C))).bit.P13SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.

/// P1 Port Function Select Register
#define P1FNCSEL                (*((volatile P1FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x1E))).reg
#define P1FNCSEL_P10MUX         (*((volatile P1FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x1E))).bit.P10MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P1FNCSEL_P11MUX         (*((volatile P1FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x1E))).bit.P11MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P1FNCSEL_P12MUX         (*((volatile P1FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x1E))).bit.P12MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P1FNCSEL_P13MUX         (*((volatile P1FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x1E))).bit.P13MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.

/// P2 Port Data Register
#define P2DAT                   (*((volatile P2DAT_REG *)(PPORT_REG_BASE_ADDR + 0x20))).reg
#define P2DAT_P20IN             (*((volatile P2DAT_REG *)(PPORT_REG_BASE_ADDR + 0x20))).bit.P20IN       ///< The GPIO port pin status can be read out from this bit.
#define P2DAT_P21IN             (*((volatile P2DAT_REG *)(PPORT_REG_BASE_ADDR + 0x20))).bit.P21IN       ///< The GPIO port pin status can be read out from this bit.
#define P2DAT_P22IN             (*((volatile P2DAT_REG *)(PPORT_REG_BASE_ADDR + 0x20))).bit.P22IN       ///< The GPIO port pin status can be read out from this bit.
#define P2DAT_P23IN             (*((volatile P2DAT_REG *)(PPORT_REG_BASE_ADDR + 0x20))).bit.P23IN       ///< The GPIO port pin status can be read out from this bit.
#define P2DAT_P20OUT            (*((volatile P2DAT_REG *)(PPORT_REG_BASE_ADDR + 0x20))).bit.P20OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P2DAT_P21OUT            (*((volatile P2DAT_REG *)(PPORT_REG_BASE_ADDR + 0x20))).bit.P21OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P2DAT_P22OUT            (*((volatile P2DAT_REG *)(PPORT_REG_BASE_ADDR + 0x20))).bit.P22OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P2DAT_P23OUT            (*((volatile P2DAT_REG *)(PPORT_REG_BASE_ADDR + 0x20))).bit.P23OUT      ///< This bit is used to set data to be output from the GPIO port pin.

/// The GPIO port pin status can be read out from these bits.
#define P2DAT_P2IN              (*((volatile P2DAT_REG *)(PPORT_REG_BASE_ADDR + 0x20))).byte_reg[0]

/// These bits are used to set data to be output from the GPIO port pins.
#define P2DAT_P2OUT             (*((volatile P2DAT_REG *)(PPORT_REG_BASE_ADDR + 0x20))).byte_reg[1]

/// P2 Port Enable Register
#define P2IOEN                  (*((volatile P2IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x22))).reg
#define P2IOEN_P20OEN           (*((volatile P2IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x22))).bit.P20OEN      ///< This bit enable/disable the GPIO port output.
#define P2IOEN_P21OEN           (*((volatile P2IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x22))).bit.P21OEN      ///< This bit enable/disable the GPIO port output.
#define P2IOEN_P22OEN           (*((volatile P2IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x22))).bit.P22OEN      ///< This bit enable/disable the GPIO port output.
#define P2IOEN_P23OEN           (*((volatile P2IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x22))).bit.P23OEN      ///< This bit enable/disable the GPIO port output.
#define P2IOEN_P20IEN           (*((volatile P2IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x22))).bit.P20IEN      ///< This bit enable/disable the GPIO port input.
#define P2IOEN_P21IEN           (*((volatile P2IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x22))).bit.P21IEN      ///< This bit enable/disable the GPIO port input.
#define P2IOEN_P22IEN           (*((volatile P2IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x22))).bit.P22IEN      ///< This bit enable/disable the GPIO port input.
#define P2IOEN_P23IEN           (*((volatile P2IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x22))).bit.P23IEN      ///< This bit enable/disable the GPIO port input.

/// These bits enable/disable the GPIO port output.
#define P2IOEN_P2OEN            (*((volatile P2IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x22))).byte_reg[0]

/// These bits enable/disable the GPIO port input.
#define P2IOEN_P2IEN            (*((volatile P2IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x22))).byte_reg[1]

/// P2 Port Pull-up/down Control Register
#define P2RCTL                  (*((volatile P2RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x24))).reg
#define P2RCTL_P20REN           (*((volatile P2RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x24))).bit.P20REN      ///< This bit enable/disable the port pull-up/down control.
#define P2RCTL_P21REN           (*((volatile P2RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x24))).bit.P21REN      ///< This bit enable/disable the port pull-up/down control.
#define P2RCTL_P22REN           (*((volatile P2RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x24))).bit.P22REN      ///< This bit enable/disable the port pull-up/down control.
#define P2RCTL_P23REN           (*((volatile P2RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x24))).bit.P23REN      ///< This bit enable/disable the port pull-up/down control.
#define P2RCTL_P20PDPU          (*((volatile P2RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x24))).bit.P20PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P2RCTL_P21PDPU          (*((volatile P2RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x24))).bit.P21PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P2RCTL_P22PDPU          (*((volatile P2RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x24))).bit.P22PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P2RCTL_P23PDPU          (*((volatile P2RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x24))).bit.P23PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.

/// These bits enable/disable the port pull-up/down control.
#define P2RCTL_P2REN            (*((volatile P2RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x24))).byte_reg[0]

/// These bits select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P2RCTL_P2PDPU           (*((volatile P2RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x24))).byte_reg[1]

/// P2 Port Interrupt Flag Register
#define P2INTF                  (*((volatile P2INTF_REG *)(PPORT_REG_BASE_ADDR + 0x26))).reg
#define P2INTF_P20IF            (*((volatile P2INTF_REG *)(PPORT_REG_BASE_ADDR + 0x26))).bit.P20IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P2INTF_P21IF            (*((volatile P2INTF_REG *)(PPORT_REG_BASE_ADDR + 0x26))).bit.P21IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P2INTF_P22IF            (*((volatile P2INTF_REG *)(PPORT_REG_BASE_ADDR + 0x26))).bit.P22IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P2INTF_P23IF            (*((volatile P2INTF_REG *)(PPORT_REG_BASE_ADDR + 0x26))).bit.P23IF       ///< This bit indicate the port input interrupt cause occurrence status.

/// P2 Port Interrupt Control Register
#define P2INTCTL                (*((volatile P2INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x28))).reg
#define P2INTCTL_P20IE          (*((volatile P2INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x28))).bit.P20IE       ///< This bit enable port input interrupt.
#define P2INTCTL_P21IE          (*((volatile P2INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x28))).bit.P21IE       ///< This bit enable port input interrupt.
#define P2INTCTL_P22IE          (*((volatile P2INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x28))).bit.P22IE       ///< This bit enable port input interrupt.
#define P2INTCTL_P23IE          (*((volatile P2INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x28))).bit.P23IE       ///< This bit enable port input interrupt.
#define P2INTCTL_P20EDGE        (*((volatile P2INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x28))).bit.P20EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P2INTCTL_P21EDGE        (*((volatile P2INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x28))).bit.P21EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P2INTCTL_P22EDGE        (*((volatile P2INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x28))).bit.P22EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P2INTCTL_P23EDGE        (*((volatile P2INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x28))).bit.P23EDGE     ///< This bit select the input signal edge to generate a port input interrupt.

/// This bit enable port input interrupt.
#define P2INTCTL_P2IE           (*((volatile P2INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x28))).byte_reg[0]

/// This bit select the input signal edge to generate a port input interrupt.
#define P2INTCTL_P2EDGE         (*((volatile P2INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x28))).byte_reg[1]

/// P2 Port Chattering Filter Enable Register
#define P2CHATEN                (*((volatile P2CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x2A))).reg
#define P2CHATEN_P20CHATEN      (*((volatile P2CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x2A))).bit.P20CHATEN   ///< This bit enable/disable the chattering filter function.
#define P2CHATEN_P21CHATEN      (*((volatile P2CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x2A))).bit.P21CHATEN   ///< This bit enable/disable the chattering filter function.
#define P2CHATEN_P22CHATEN      (*((volatile P2CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x2A))).bit.P22CHATEN   ///< This bit enable/disable the chattering filter function.
#define P2CHATEN_P23CHATEN      (*((volatile P2CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x2A))).bit.P23CHATEN   ///< This bit enable/disable the chattering filter function.

/// P2 Port Mode Select Register
#define P2MODSEL                (*((volatile P2MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x2C))).reg
#define P2MODSEL_P20SEL         (*((volatile P2MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x2C))).bit.P20SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P2MODSEL_P21SEL         (*((volatile P2MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x2C))).bit.P21SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P2MODSEL_P22SEL         (*((volatile P2MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x2C))).bit.P22SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P2MODSEL_P23SEL         (*((volatile P2MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x2C))).bit.P23SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.

/// P2 Port Function Select Register
#define P2FNCSEL                (*((volatile P2FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x2E))).reg
#define P2FNCSEL_P20MUX         (*((volatile P2FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x2E))).bit.P20MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P2FNCSEL_P21MUX         (*((volatile P2FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x2E))).bit.P21MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P2FNCSEL_P22MUX         (*((volatile P2FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x2E))).bit.P22MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P2FNCSEL_P23MUX         (*((volatile P2FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x2E))).bit.P23MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.

/// P3 Port Data Register
#define P3DAT                   (*((volatile P3DAT_REG *)(PPORT_REG_BASE_ADDR + 0x30))).reg
#define P3DAT_P30IN             (*((volatile P3DAT_REG *)(PPORT_REG_BASE_ADDR + 0x30))).bit.P30IN       ///< The GPIO port pin status can be read out from this bit.
#define P3DAT_P31IN             (*((volatile P3DAT_REG *)(PPORT_REG_BASE_ADDR + 0x30))).bit.P31IN       ///< The GPIO port pin status can be read out from this bit.
#define P3DAT_P32IN             (*((volatile P3DAT_REG *)(PPORT_REG_BASE_ADDR + 0x30))).bit.P32IN       ///< The GPIO port pin status can be read out from this bit.
#define P3DAT_P33IN             (*((volatile P3DAT_REG *)(PPORT_REG_BASE_ADDR + 0x30))).bit.P33IN       ///< The GPIO port pin status can be read out from this bit.
#define P3DAT_P34IN             (*((volatile P3DAT_REG *)(PPORT_REG_BASE_ADDR + 0x30))).bit.P34IN       ///< The GPIO port pin status can be read out from this bit.
#define P3DAT_P30OUT            (*((volatile P3DAT_REG *)(PPORT_REG_BASE_ADDR + 0x30))).bit.P30OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P3DAT_P31OUT            (*((volatile P3DAT_REG *)(PPORT_REG_BASE_ADDR + 0x30))).bit.P31OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P3DAT_P32OUT            (*((volatile P3DAT_REG *)(PPORT_REG_BASE_ADDR + 0x30))).bit.P32OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P3DAT_P33OUT            (*((volatile P3DAT_REG *)(PPORT_REG_BASE_ADDR + 0x30))).bit.P33OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P3DAT_P34OUT            (*((volatile P3DAT_REG *)(PPORT_REG_BASE_ADDR + 0x30))).bit.P34OUT      ///< This bit is used to set data to be output from the GPIO port pin.

/// The GPIO port pin status can be read out from these bits.
#define P3DAT_P3IN              (*((volatile P3DAT_REG *)(PPORT_REG_BASE_ADDR + 0x30))).byte_reg[0]

/// These bits are used to set data to be output from the GPIO port pins.
#define P3DAT_P3OUT             (*((volatile P3DAT_REG *)(PPORT_REG_BASE_ADDR + 0x30))).byte_reg[1]

/// P3 Port Enable Register
#define P3IOEN                  (*((volatile P3IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x32))).reg
#define P3IOEN_P30OEN           (*((volatile P3IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x32))).bit.P30OEN      ///< This bit enable/disable the GPIO port output.
#define P3IOEN_P31OEN           (*((volatile P3IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x32))).bit.P31OEN      ///< This bit enable/disable the GPIO port output.
#define P3IOEN_P32OEN           (*((volatile P3IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x32))).bit.P32OEN      ///< This bit enable/disable the GPIO port output.
#define P3IOEN_P33OEN           (*((volatile P3IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x32))).bit.P33OEN      ///< This bit enable/disable the GPIO port output.
#define P3IOEN_P34OEN           (*((volatile P3IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x32))).bit.P34OEN      ///< This bit enable/disable the GPIO port output.
#define P3IOEN_P30IEN           (*((volatile P3IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x32))).bit.P30IEN      ///< This bit enable/disable the GPIO port input.
#define P3IOEN_P31IEN           (*((volatile P3IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x32))).bit.P31IEN      ///< This bit enable/disable the GPIO port input.
#define P3IOEN_P32IEN           (*((volatile P3IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x32))).bit.P32IEN      ///< This bit enable/disable the GPIO port input.
#define P3IOEN_P33IEN           (*((volatile P3IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x32))).bit.P33IEN      ///< This bit enable/disable the GPIO port input.
#define P3IOEN_P34IEN           (*((volatile P3IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x32))).bit.P34IEN      ///< This bit enable/disable the GPIO port input.

/// These bits enable/disable the GPIO port output.
#define P3IOEN_P3OEN            (*((volatile P3IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x32))).byte_reg[0]

/// These bits enable/disable the GPIO port input.
#define P3IOEN_P3IEN            (*((volatile P3IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x32))).byte_reg[1]

/// P3 Port Pull-up/down Control Register
#define P3RCTL                  (*((volatile P3RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x34))).reg
#define P3RCTL_P30REN           (*((volatile P3RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x34))).bit.P30REN      ///< This bit enable/disable the port pull-up/down control.
#define P3RCTL_P31REN           (*((volatile P3RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x34))).bit.P31REN      ///< This bit enable/disable the port pull-up/down control.
#define P3RCTL_P32REN           (*((volatile P3RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x34))).bit.P32REN      ///< This bit enable/disable the port pull-up/down control.
#define P3RCTL_P33REN           (*((volatile P3RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x34))).bit.P33REN      ///< This bit enable/disable the port pull-up/down control.
#define P3RCTL_P34REN           (*((volatile P3RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x34))).bit.P34REN      ///< This bit enable/disable the port pull-up/down control.
#define P3RCTL_P30PDPU          (*((volatile P3RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x34))).bit.P30PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P3RCTL_P31PDPU          (*((volatile P3RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x34))).bit.P31PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P3RCTL_P32PDPU          (*((volatile P3RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x34))).bit.P32PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P3RCTL_P33PDPU          (*((volatile P3RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x34))).bit.P33PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P3RCTL_P34PDPU          (*((volatile P3RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x34))).bit.P34PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.

/// These bits enable/disable the port pull-up/down control.
#define P3RCTL_P3REN            (*((volatile P3RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x34))).byte_reg[0]

/// These bits select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P3RCTL_P3PDPU           (*((volatile P3RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x34))).byte_reg[1]

/// P3 Port Interrupt Flag Register
#define P3INTF                  (*((volatile P3INTF_REG *)(PPORT_REG_BASE_ADDR + 0x36))).reg
#define P3INTF_P30IF            (*((volatile P3INTF_REG *)(PPORT_REG_BASE_ADDR + 0x36))).bit.P30IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P3INTF_P31IF            (*((volatile P3INTF_REG *)(PPORT_REG_BASE_ADDR + 0x36))).bit.P31IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P3INTF_P32IF            (*((volatile P3INTF_REG *)(PPORT_REG_BASE_ADDR + 0x36))).bit.P32IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P3INTF_P33IF            (*((volatile P3INTF_REG *)(PPORT_REG_BASE_ADDR + 0x36))).bit.P33IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P3INTF_P34IF            (*((volatile P3INTF_REG *)(PPORT_REG_BASE_ADDR + 0x36))).bit.P34IF       ///< This bit indicate the port input interrupt cause occurrence status.

/// P3 Port Interrupt Control Register
#define P3INTCTL                (*((volatile P3INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x38))).reg
#define P3INTCTL_P30IE          (*((volatile P3INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x38))).bit.P30IE       ///< This bit enable port input interrupt.
#define P3INTCTL_P31IE          (*((volatile P3INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x38))).bit.P31IE       ///< This bit enable port input interrupt.
#define P3INTCTL_P32IE          (*((volatile P3INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x38))).bit.P32IE       ///< This bit enable port input interrupt.
#define P3INTCTL_P33IE          (*((volatile P3INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x38))).bit.P33IE       ///< This bit enable port input interrupt.
#define P3INTCTL_P34IE          (*((volatile P3INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x38))).bit.P34IE       ///< This bit enable port input interrupt.
#define P3INTCTL_P30EDGE        (*((volatile P3INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x38))).bit.P30EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P3INTCTL_P31EDGE        (*((volatile P3INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x38))).bit.P31EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P3INTCTL_P32EDGE        (*((volatile P3INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x38))).bit.P32EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P3INTCTL_P33EDGE        (*((volatile P3INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x38))).bit.P33EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P3INTCTL_P34EDGE        (*((volatile P3INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x38))).bit.P34EDGE     ///< This bit select the input signal edge to generate a port input interrupt.

/// These bits enable port input interrupt.
#define P3INTCTL_P3IE           (*((volatile P3INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x38))).byte_reg[0]

/// These bits select the input signal edge to generate a port input interrupt.
#define P3INTCTL_P3EDGE         (*((volatile P3INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x38))).byte_reg[1]

/// P3 Port Chattering Filter Enable Register
#define P3CHATEN                (*((volatile P3CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x3A))).reg
#define P3CHATEN_P30CHATEN      (*((volatile P3CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x3A))).bit.P30CHATEN   ///< This bit enable/disable the chattering filter function.
#define P3CHATEN_P31CHATEN      (*((volatile P3CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x3A))).bit.P31CHATEN   ///< This bit enable/disable the chattering filter function.
#define P3CHATEN_P32CHATEN      (*((volatile P3CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x3A))).bit.P32CHATEN   ///< This bit enable/disable the chattering filter function.
#define P3CHATEN_P33CHATEN      (*((volatile P3CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x3A))).bit.P33CHATEN   ///< This bit enable/disable the chattering filter function.
#define P3CHATEN_P34CHATEN      (*((volatile P3CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x3A))).bit.P34CHATEN   ///< This bit enable/disable the chattering filter function.

/// P3 Port Mode Select Register
#define P3MODSEL                (*((volatile P3MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x3C))).reg
#define P3MODSEL_P30SEL         (*((volatile P3MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x3C))).bit.P30SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P3MODSEL_P31SEL         (*((volatile P3MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x3C))).bit.P31SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P3MODSEL_P32SEL         (*((volatile P3MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x3C))).bit.P32SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P3MODSEL_P33SEL         (*((volatile P3MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x3C))).bit.P33SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P3MODSEL_P34SEL         (*((volatile P3MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x3C))).bit.P34SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.

/// P3 Port Function Select Register
#define P3FNCSEL                (*((volatile P3FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x3E))).reg
#define P3FNCSEL_P30MUX         (*((volatile P3FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x3E))).bit.P30MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P3FNCSEL_P31MUX         (*((volatile P3FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x3E))).bit.P31MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P3FNCSEL_P32MUX         (*((volatile P3FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x3E))).bit.P32MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P3FNCSEL_P33MUX         (*((volatile P3FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x3E))).bit.P33MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P3FNCSEL_P34MUX         (*((volatile P3FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x3E))).bit.P34MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.

/// P4 Port Data Register
#define P4DAT                   (*((volatile P4DAT_REG *)(PPORT_REG_BASE_ADDR + 0x40))).reg
#define P4DAT_P45IN             (*((volatile P4DAT_REG *)(PPORT_REG_BASE_ADDR + 0x40))).bit.P45IN       ///< The GPIO port pin status can be read out from this bit.
#define P4DAT_P45OUT            (*((volatile P4DAT_REG *)(PPORT_REG_BASE_ADDR + 0x40))).bit.P45OUT      ///< This bit is used to set data to be output from the GPIO port pin.

/// The GPIO port pin status can be read out from these bits.
#define P4DAT_P4IN              (*((volatile P4DAT_REG *)(PPORT_REG_BASE_ADDR + 0x40))).byte_reg[0]

/// These bits are used to set data to be output from the GPIO port pins.
#define P4DAT_P4OUT             (*((volatile P4DAT_REG *)(PPORT_REG_BASE_ADDR + 0x40))).byte_reg[1]

/// P4 Port Enable Register
#define P4IOEN                  (*((volatile P4IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x42))).reg
#define P4IOEN_P45OEN           (*((volatile P4IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x42))).bit.P45OEN      ///< This bit enable/disable the GPIO port output.
#define P4IOEN_P45IEN           (*((volatile P4IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x42))).bit.P45IEN      ///< This bit enable/disable the GPIO port input.

/// These bits enable/disable the GPIO port output.
#define P4IOEN_P4OEN            (*((volatile P4IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x42))).byte_reg[0]

/// These bits enable/disable the GPIO port input.
#define P4IOEN_P4IEN            (*((volatile P4IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x42))).byte_reg[1]

/// P4 Port Pull-up/down Control Register
#define P4RCTL                  (*((volatile P4RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x44))).reg
#define P4RCTL_P45REN           (*((volatile P4RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x44))).bit.P45REN      ///< This bit enable/disable the port pull-up/down control.
#define P4RCTL_P45PDPU          (*((volatile P4RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x44))).bit.P45PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.

/// These bits enable/disable the port pull-up/down control.
#define P4RCTL_P4REN            (*((volatile P4RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x44))).byte_reg[0]

/// These bits select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P4RCTL_P4PDPU           (*((volatile P4RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x44))).byte_reg[1]

/// P4 Port Interrupt Flag Register
#define P4INTF                  (*((volatile P4INTF_REG *)(PPORT_REG_BASE_ADDR + 0x46))).reg
#define P4INTF_P45IF            (*((volatile P4INTF_REG *)(PPORT_REG_BASE_ADDR + 0x46))).bit.P45IF       ///< This bit indicate the port input interrupt cause occurrence status.

/// P4 Port Interrupt Control Register
#define P4INTCTL                (*((volatile P4INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x48))).reg
#define P4INTCTL_P45IE          (*((volatile P4INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x48))).bit.P45IE       ///< This bit enable port input interrupt.
#define P4INTCTL_P45EDGE        (*((volatile P4INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x48))).bit.P45EDGE     ///< This bit select the input signal edge to generate a port input interrupt.

/// These bits enable port input interrupt.
#define P4INTCTL_P4IE           (*((volatile P4INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x48))).byte_reg[0]

/// These bits select the input signal edge to generate a port input interrupt.
#define P4INTCTL_P4EDGE         (*((volatile P4INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x48))).byte_reg[1]

/// P4 Port Chattering Filter Enable Register
#define P4CHATEN                (*((volatile P4CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x4A))).reg
#define P4CHATEN_P45CHATEN      (*((volatile P4CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x4A))).bit.P45CHATEN   ///< This bit enable/disable the chattering filter function.

/// P4 Port Mode Select Register
#define P4MODSEL                (*((volatile P4MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x4C))).reg
#define P4MODSEL_P45SEL         (*((volatile P4MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x4C))).bit.P45SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.

/// P4 Port Function Select Register
#define P4FNCSEL                (*((volatile P4FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x4E))).reg
#define P4FNCSEL_P45MUX         (*((volatile P4FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x4E))).bit.P45MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.

/// P6 Port Data Register
#define P6DAT                   (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).reg
#define P6DAT_P60IN             (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P60IN       ///< The GPIO port pin status can be read out from this bit.
#define P6DAT_P61IN             (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P61IN       ///< The GPIO port pin status can be read out from this bit.
#define P6DAT_P62IN             (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P62IN       ///< The GPIO port pin status can be read out from this bit.
#define P6DAT_P63IN             (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P63IN       ///< The GPIO port pin status can be read out from this bit.
#define P6DAT_P64IN             (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P64IN       ///< The GPIO port pin status can be read out from this bit.
#define P6DAT_P65IN             (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P65IN       ///< The GPIO port pin status can be read out from this bit.
#define P6DAT_P66IN             (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P66IN       ///< The GPIO port pin status can be read out from this bit.
#define P6DAT_P67IN             (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P67IN       ///< The GPIO port pin status can be read out from this bit.
#define P6DAT_P60OUT            (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P60OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P6DAT_P61OUT            (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P61OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P6DAT_P62OUT            (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P62OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P6DAT_P63OUT            (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P63OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P6DAT_P64OUT            (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P64OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P6DAT_P65OUT            (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P65OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P6DAT_P66OUT            (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P66OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P6DAT_P67OUT            (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).bit.P67OUT      ///< This bit is used to set data to be output from the GPIO port pin.

/// The GPIO port pin status can be read out from these bits.
#define P6DAT_P6IN              (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).byte_reg[0]

/// These bits are used to set data to be output from the GPIO port pins.
#define P6DAT_P6OUT             (*((volatile P6DAT_REG *)(PPORT_REG_BASE_ADDR + 0x60))).byte_reg[1]

/// P6 Port Enable Register
#define P6IOEN                  (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).reg
#define P6IOEN_P60OEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P60OEN      ///< This bit enable/disable the GPIO port output.
#define P6IOEN_P61OEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P61OEN      ///< This bit enable/disable the GPIO port output.
#define P6IOEN_P62OEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P62OEN      ///< This bit enable/disable the GPIO port output.
#define P6IOEN_P63OEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P63OEN      ///< This bit enable/disable the GPIO port output.
#define P6IOEN_P64OEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P64OEN      ///< This bit enable/disable the GPIO port output.
#define P6IOEN_P65OEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P65OEN      ///< This bit enable/disable the GPIO port output.
#define P6IOEN_P66OEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P66OEN      ///< This bit enable/disable the GPIO port output.
#define P6IOEN_P67OEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P67OEN      ///< This bit enable/disable the GPIO port output.
#define P6IOEN_P60IEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P60IEN      ///< This bit enable/disable the GPIO port input.
#define P6IOEN_P61IEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P61IEN      ///< This bit enable/disable the GPIO port input.
#define P6IOEN_P62IEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P62IEN      ///< This bit enable/disable the GPIO port input.
#define P6IOEN_P63IEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P63IEN      ///< This bit enable/disable the GPIO port input.
#define P6IOEN_P64IEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P64IEN      ///< This bit enable/disable the GPIO port input.
#define P6IOEN_P65IEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P65IEN      ///< This bit enable/disable the GPIO port input.
#define P6IOEN_P66IEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P66IEN      ///< This bit enable/disable the GPIO port input.
#define P6IOEN_P67IEN           (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).bit.P67IEN      ///< This bit enable/disable the GPIO port input.

/// These bits enable/disable the GPIO port output.
#define P6IOEN_P6OEN            (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).byte_reg[0]

/// These bits enable/disable the GPIO port input.
#define P6IOEN_P6IEN            (*((volatile P6IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x62))).byte_reg[1]

/// P6 Port Pull-up/down Control Register
#define P6RCTL                  (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).reg
#define P6RCTL_P60REN           (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P60REN      ///< This bit enable/disable the port pull-up/down control.
#define P6RCTL_P61REN           (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P61REN      ///< This bit enable/disable the port pull-up/down control.
#define P6RCTL_P62REN           (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P62REN      ///< This bit enable/disable the port pull-up/down control.
#define P6RCTL_P63REN           (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P63REN      ///< This bit enable/disable the port pull-up/down control.
#define P6RCTL_P64REN           (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P64REN      ///< This bit enable/disable the port pull-up/down control.
#define P6RCTL_P65REN           (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P65REN      ///< This bit enable/disable the port pull-up/down control.
#define P6RCTL_P66REN           (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P66REN      ///< This bit enable/disable the port pull-up/down control.
#define P6RCTL_P67REN           (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P67REN      ///< This bit enable/disable the port pull-up/down control.
#define P6RCTL_P60PDPU          (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P60PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P6RCTL_P61PDPU          (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P61PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P6RCTL_P62PDPU          (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P62PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P6RCTL_P63PDPU          (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P63PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P6RCTL_P64PDPU          (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P64PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P6RCTL_P65PDPU          (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P65PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P6RCTL_P66PDPU          (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P66PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P6RCTL_P67PDPU          (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).bit.P67PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.

/// These bits enable/disable the port pull-up/down control.
#define P6RCTL_P6REN            (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).byte_reg[0]

/// These bits select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P6RCTL_P6PDPU           (*((volatile P6RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x64))).byte_reg[1]

/// P6 Port Interrupt Flag Register
#define P6INTF                  (*((volatile P6INTF_REG *)(PPORT_REG_BASE_ADDR + 0x66))).reg
#define P6INTF_P60IF            (*((volatile P6INTF_REG *)(PPORT_REG_BASE_ADDR + 0x66))).bit.P60IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P6INTF_P61IF            (*((volatile P6INTF_REG *)(PPORT_REG_BASE_ADDR + 0x66))).bit.P61IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P6INTF_P62IF            (*((volatile P6INTF_REG *)(PPORT_REG_BASE_ADDR + 0x66))).bit.P62IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P6INTF_P63IF            (*((volatile P6INTF_REG *)(PPORT_REG_BASE_ADDR + 0x66))).bit.P63IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P6INTF_P64IF            (*((volatile P6INTF_REG *)(PPORT_REG_BASE_ADDR + 0x66))).bit.P64IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P6INTF_P65IF            (*((volatile P6INTF_REG *)(PPORT_REG_BASE_ADDR + 0x66))).bit.P65IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P6INTF_P66IF            (*((volatile P6INTF_REG *)(PPORT_REG_BASE_ADDR + 0x66))).bit.P66IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P6INTF_P67IF            (*((volatile P6INTF_REG *)(PPORT_REG_BASE_ADDR + 0x66))).bit.P67IF       ///< This bit indicate the port input interrupt cause occurrence status.

/// P6 Port Interrupt Control Register
#define P6INTCTL                (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).reg
#define P6INTCTL_P60IE          (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P60IE       ///< This bit enable port input interrupt.
#define P6INTCTL_P61IE          (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P61IE       ///< This bit enable port input interrupt.
#define P6INTCTL_P62IE          (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P62IE       ///< This bit enable port input interrupt.
#define P6INTCTL_P63IE          (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P63IE       ///< This bit enable port input interrupt.
#define P6INTCTL_P64IE          (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P64IE       ///< This bit enable port input interrupt.
#define P6INTCTL_P65IE          (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P65IE       ///< This bit enable port input interrupt.
#define P6INTCTL_P66IE          (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P66IE       ///< This bit enable port input interrupt.
#define P6INTCTL_P67IE          (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P67IE       ///< This bit enable port input interrupt.
#define P6INTCTL_P60EDGE        (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P60EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P6INTCTL_P61EDGE        (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P61EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P6INTCTL_P62EDGE        (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P62EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P6INTCTL_P63EDGE        (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P63EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P6INTCTL_P64EDGE        (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P64EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P6INTCTL_P65EDGE        (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P65EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P6INTCTL_P66EDGE        (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P66EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P6INTCTL_P67EDGE        (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).bit.P67EDGE     ///< This bit select the input signal edge to generate a port input interrupt.

/// These bits enable port input interrupt.
#define P6INTCTL_P6IE           (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).byte_reg[0]

/// These bits select the input signal edge to generate a port input interrupt.
#define P6INTCTL_P6EDGE         (*((volatile P6INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x68))).byte_reg[1]

/// P6 Port Chattering Filter Enable Register
#define P6CHATEN                (*((volatile P6CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x6A))).reg
#define P6CHATEN_P60CHATEN      (*((volatile P6CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x6A))).bit.P60CHATEN   ///< This bit enable/disable the chattering filter function.
#define P6CHATEN_P61CHATEN      (*((volatile P6CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x6A))).bit.P61CHATEN   ///< This bit enable/disable the chattering filter function.
#define P6CHATEN_P62CHATEN      (*((volatile P6CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x6A))).bit.P62CHATEN   ///< This bit enable/disable the chattering filter function.
#define P6CHATEN_P63CHATEN      (*((volatile P6CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x6A))).bit.P63CHATEN   ///< This bit enable/disable the chattering filter function.
#define P6CHATEN_P64CHATEN      (*((volatile P6CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x6A))).bit.P64CHATEN   ///< This bit enable/disable the chattering filter function.
#define P6CHATEN_P65CHATEN      (*((volatile P6CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x6A))).bit.P65CHATEN   ///< This bit enable/disable the chattering filter function.
#define P6CHATEN_P66CHATEN      (*((volatile P6CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x6A))).bit.P66CHATEN   ///< This bit enable/disable the chattering filter function.
#define P6CHATEN_P67CHATEN      (*((volatile P6CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x6A))).bit.P67CHATEN   ///< This bit enable/disable the chattering filter function.

/// P6 Port Mode Select Register
#define P6MODSEL                (*((volatile P6MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6C))).reg
#define P6MODSEL_P60SEL         (*((volatile P6MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6C))).bit.P60SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P6MODSEL_P61SEL         (*((volatile P6MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6C))).bit.P61SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P6MODSEL_P62SEL         (*((volatile P6MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6C))).bit.P62SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P6MODSEL_P63SEL         (*((volatile P6MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6C))).bit.P63SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P6MODSEL_P64SEL         (*((volatile P6MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6C))).bit.P64SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P6MODSEL_P65SEL         (*((volatile P6MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6C))).bit.P65SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P6MODSEL_P66SEL         (*((volatile P6MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6C))).bit.P66SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P6MODSEL_P67SEL         (*((volatile P6MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6C))).bit.P67SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.

/// P6 Port Function Select Register
#define P6FNCSEL                (*((volatile P6FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6E))).reg
#define P6FNCSEL_P60MUX         (*((volatile P6FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6E))).bit.P60MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P6FNCSEL_P61MUX         (*((volatile P6FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6E))).bit.P61MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P6FNCSEL_P62MUX         (*((volatile P6FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6E))).bit.P62MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P6FNCSEL_P63MUX         (*((volatile P6FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6E))).bit.P63MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P6FNCSEL_P64MUX         (*((volatile P6FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6E))).bit.P64MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P6FNCSEL_P65MUX         (*((volatile P6FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6E))).bit.P65MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P6FNCSEL_P66MUX         (*((volatile P6FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6E))).bit.P66MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P6FNCSEL_P67MUX         (*((volatile P6FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x6E))).bit.P67MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.

/// P7 Port Data Register
#define P7DAT                   (*((volatile P7DAT_REG *)(PPORT_REG_BASE_ADDR + 0x70))).reg
#define P7DAT_P71IN             (*((volatile P7DAT_REG *)(PPORT_REG_BASE_ADDR + 0x70))).bit.P71IN       ///< The GPIO port pin status can be read out from this bit.
#define P7DAT_P72IN             (*((volatile P7DAT_REG *)(PPORT_REG_BASE_ADDR + 0x70))).bit.P72IN       ///< The GPIO port pin status can be read out from this bit.
#define P7DAT_P73IN             (*((volatile P7DAT_REG *)(PPORT_REG_BASE_ADDR + 0x70))).bit.P73IN       ///< The GPIO port pin status can be read out from this bit.
#define P7DAT_P71OUT            (*((volatile P7DAT_REG *)(PPORT_REG_BASE_ADDR + 0x70))).bit.P71OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P7DAT_P72OUT            (*((volatile P7DAT_REG *)(PPORT_REG_BASE_ADDR + 0x70))).bit.P72OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define P7DAT_P73OUT            (*((volatile P7DAT_REG *)(PPORT_REG_BASE_ADDR + 0x70))).bit.P73OUT      ///< This bit is used to set data to be output from the GPIO port pin.

/// The GPIO port pin status can be read out from these bits.
#define P7DAT_P7IN              (*((volatile P7DAT_REG *)(PPORT_REG_BASE_ADDR + 0x70))).byte_reg[0]

/// These bits are used to set data to be output from the GPIO port pins.
#define P7DAT_P7OUT             (*((volatile P7DAT_REG *)(PPORT_REG_BASE_ADDR + 0x70))).byte_reg[1]

/// P7 Port Enable Register
#define P7IOEN                  (*((volatile P7IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x72))).reg
#define P7IOEN_P71OEN           (*((volatile P7IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x72))).bit.P71OEN      ///< This bit enable/disable the GPIO port output.
#define P7IOEN_P72OEN           (*((volatile P7IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x72))).bit.P72OEN      ///< This bit enable/disable the GPIO port output.
#define P7IOEN_P73OEN           (*((volatile P7IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x72))).bit.P73OEN      ///< This bit enable/disable the GPIO port output.
#define P7IOEN_P71IEN           (*((volatile P7IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x72))).bit.P71IEN      ///< This bit enable/disable the GPIO port input.
#define P7IOEN_P72IEN           (*((volatile P7IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x72))).bit.P72IEN      ///< This bit enable/disable the GPIO port input.
#define P7IOEN_P73IEN           (*((volatile P7IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x72))).bit.P73IEN      ///< This bit enable/disable the GPIO port input.

/// These bits enable/disable the GPIO port output.
#define P7IOEN_P7OEN            (*((volatile P7IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x72))).byte_reg[0]

/// These bits enable/disable the GPIO port input.
#define P7IOEN_P7IEN            (*((volatile P7IOEN_REG *)(PPORT_REG_BASE_ADDR + 0x72))).byte_reg[1]

/// P7 Port Pull-up/down Control Register
#define P7RCTL                  (*((volatile P7RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x74))).reg
#define P7RCTL_P71REN           (*((volatile P7RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x74))).bit.P71REN      ///< This bit enable/disable the port pull-up/down control.
#define P7RCTL_P72REN           (*((volatile P7RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x74))).bit.P72REN      ///< This bit enable/disable the port pull-up/down control.
#define P7RCTL_P73REN           (*((volatile P7RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x74))).bit.P73REN      ///< This bit enable/disable the port pull-up/down control.
#define P7RCTL_P71PDPU          (*((volatile P7RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x74))).bit.P71PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P7RCTL_P72PDPU          (*((volatile P7RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x74))).bit.P72PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P7RCTL_P73PDPU          (*((volatile P7RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x74))).bit.P73PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.

/// These bits enable/disable the port pull-up/down control.
#define P7RCTL_P7REN            (*((volatile P7RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x74))).byte_reg[0]

/// These bits select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define P7RCTL_P7PDPU           (*((volatile P7RCTL_REG *)(PPORT_REG_BASE_ADDR + 0x74))).byte_reg[1]

/// P7 Port Interrupt Flag Register
#define P7INTF                  (*((volatile P7INTF_REG *)(PPORT_REG_BASE_ADDR + 0x76))).reg
#define P7INTF_P71IF            (*((volatile P7INTF_REG *)(PPORT_REG_BASE_ADDR + 0x76))).bit.P71IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P7INTF_P72IF            (*((volatile P7INTF_REG *)(PPORT_REG_BASE_ADDR + 0x76))).bit.P72IF       ///< This bit indicate the port input interrupt cause occurrence status.
#define P7INTF_P73IF            (*((volatile P7INTF_REG *)(PPORT_REG_BASE_ADDR + 0x76))).bit.P73IF       ///< This bit indicate the port input interrupt cause occurrence status.

/// P7 Port Interrupt Control Register
#define P7INTCTL                (*((volatile P7INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x78))).reg
#define P7INTCTL_P71IE          (*((volatile P7INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x78))).bit.P71IE       ///< This bit enable port input interrupt.
#define P7INTCTL_P72IE          (*((volatile P7INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x78))).bit.P72IE       ///< This bit enable port input interrupt.
#define P7INTCTL_P73IE          (*((volatile P7INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x78))).bit.P73IE       ///< This bit enable port input interrupt.
#define P7INTCTL_P71EDGE        (*((volatile P7INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x78))).bit.P71EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P7INTCTL_P72EDGE        (*((volatile P7INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x78))).bit.P72EDGE     ///< This bit select the input signal edge to generate a port input interrupt.
#define P7INTCTL_P73EDGE        (*((volatile P7INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x78))).bit.P73EDGE     ///< This bit select the input signal edge to generate a port input interrupt.

/// This bit enable port input interrupt.
#define P7INTCTL_P7IE           (*((volatile P7INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x78))).byte_reg[0]

/// This bit select the input signal edge to generate a port input interrupt.
#define P7INTCTL_P7EDGE         (*((volatile P7INTCTL_REG *)(PPORT_REG_BASE_ADDR + 0x78))).byte_reg[1]

/// P7 Port Chattering Filter Enable Register
#define P7CHATEN                (*((volatile P7CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x7A))).reg
#define P7CHATEN_P71CHATEN      (*((volatile P7CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x7A))).bit.P71CHATEN   ///< This bit enable/disable the chattering filter function.
#define P7CHATEN_P72CHATEN      (*((volatile P7CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x7A))).bit.P72CHATEN   ///< This bit enable/disable the chattering filter function.
#define P7CHATEN_P73CHATEN      (*((volatile P7CHATEN_REG *)(PPORT_REG_BASE_ADDR + 0x7A))).bit.P73CHATEN   ///< This bit enable/disable the chattering filter function.

/// P7 Port Mode Select Register
#define P7MODSEL                (*((volatile P7MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x7C))).reg
#define P7MODSEL_P71SEL         (*((volatile P7MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x7C))).bit.P71SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P7MODSEL_P72SEL         (*((volatile P7MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x7C))).bit.P72SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define P7MODSEL_P73SEL         (*((volatile P7MODSEL_REG *)(PPORT_REG_BASE_ADDR + 0x7C))).bit.P73SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.

/// P7 Port Function Select Register
#define P7FNCSEL                (*((volatile P7FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x7E))).reg
#define P7FNCSEL_P71MUX         (*((volatile P7FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x7E))).bit.P71MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P7FNCSEL_P72MUX         (*((volatile P7FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x7E))).bit.P72MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define P7FNCSEL_P73MUX         (*((volatile P7FNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0x7E))).bit.P73MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.

/// Pd Port Data Register
#define PDDAT                   (*((volatile PDDAT_REG *)(PPORT_REG_BASE_ADDR + 0xD0))).reg
#define PDDAT_PD0IN             (*((volatile PDDAT_REG *)(PPORT_REG_BASE_ADDR + 0xD0))).bit.PD0IN       ///< The GPIO port pin status can be read out from this bit.
#define PDDAT_PD1IN             (*((volatile PDDAT_REG *)(PPORT_REG_BASE_ADDR + 0xD0))).bit.PD1IN       ///< The GPIO port pin status can be read out from this bit.
#define PDDAT_PD3IN             (*((volatile PDDAT_REG *)(PPORT_REG_BASE_ADDR + 0xD0))).bit.PD3IN       ///< The GPIO port pin status can be read out from this bit.
#define PDDAT_PD4IN             (*((volatile PDDAT_REG *)(PPORT_REG_BASE_ADDR + 0xD0))).bit.PD4IN       ///< The GPIO port pin status can be read out from this bit.
#define PDDAT_PD0OUT            (*((volatile PDDAT_REG *)(PPORT_REG_BASE_ADDR + 0xD0))).bit.PD0OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define PDDAT_PD1OUT            (*((volatile PDDAT_REG *)(PPORT_REG_BASE_ADDR + 0xD0))).bit.PD1OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define PDDAT_PD2OUT            (*((volatile PDDAT_REG *)(PPORT_REG_BASE_ADDR + 0xD0))).bit.PD2OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define PDDAT_PD3OUT            (*((volatile PDDAT_REG *)(PPORT_REG_BASE_ADDR + 0xD0))).bit.PD3OUT      ///< This bit is used to set data to be output from the GPIO port pin.
#define PDDAT_PD4OUT            (*((volatile PDDAT_REG *)(PPORT_REG_BASE_ADDR + 0xD0))).bit.PD4OUT      ///< This bit is used to set data to be output from the GPIO port pin.

/// The GPIO port pin status can be read out from these bits.
#define PDDAT_PDIN              (*((volatile PDDAT_REG *)(PPORT_REG_BASE_ADDR + 0xD0))).byte_reg[0]

/// These bits is used to set data to be output from the GPIO port pin.
#define PDDAT_PDOUT             (*((volatile PDDAT_REG *)(PPORT_REG_BASE_ADDR + 0xD0))).byte_reg[1]

/// Pd Port Enable Register
#define PDIOEN                  (*((volatile PDIOEN_REG *)(PPORT_REG_BASE_ADDR + 0xD2))).reg
#define PDIOEN_PD0OEN           (*((volatile PDIOEN_REG *)(PPORT_REG_BASE_ADDR + 0xD2))).bit.PD0OEN      ///< This bit enable/disable the GPIO port output.
#define PDIOEN_PD1OEN           (*((volatile PDIOEN_REG *)(PPORT_REG_BASE_ADDR + 0xD2))).bit.PD1OEN      ///< This bit enable/disable the GPIO port output.
#define PDIOEN_PD3OEN           (*((volatile PDIOEN_REG *)(PPORT_REG_BASE_ADDR + 0xD2))).bit.PD3OEN      ///< This bit enable/disable the GPIO port output.
#define PDIOEN_PD4OEN           (*((volatile PDIOEN_REG *)(PPORT_REG_BASE_ADDR + 0xD2))).bit.PD4OEN      ///< This bit enable/disable the GPIO port output.
#define PDIOEN_PD0IEN           (*((volatile PDIOEN_REG *)(PPORT_REG_BASE_ADDR + 0xD2))).bit.PD0IEN      ///< This bit enable/disable the GPIO port input.
#define PDIOEN_PD1IEN           (*((volatile PDIOEN_REG *)(PPORT_REG_BASE_ADDR + 0xD2))).bit.PD1IEN      ///< This bit enable/disable the GPIO port input.
#define PDIOEN_PD3IEN           (*((volatile PDIOEN_REG *)(PPORT_REG_BASE_ADDR + 0xD2))).bit.PD3IEN      ///< This bit enable/disable the GPIO port input.
#define PDIOEN_PD4IEN           (*((volatile PDIOEN_REG *)(PPORT_REG_BASE_ADDR + 0xD2))).bit.PD4IEN      ///< This bit enable/disable the GPIO port input.

/// These bits enable/disable the GPIO port output.
#define PDIOEN_PDOEN            (*((volatile PDIOEN_REG *)(PPORT_REG_BASE_ADDR + 0xD2))).byte_reg[0]

/// These bits enable/disable the GPIO port input.
#define PDIOEN_PDIEN            (*((volatile PDIOEN_REG *)(PPORT_REG_BASE_ADDR + 0xD2))).byte_reg[1]

/// Pd Port Pull-up/down Control Register
#define PDRCTL                  (*((volatile PDRCTL_REG *)(PPORT_REG_BASE_ADDR + 0xD4))).reg
#define PDRCTL_PD0REN           (*((volatile PDRCTL_REG *)(PPORT_REG_BASE_ADDR + 0xD4))).bit.PD0REN      ///< This bit enable/disable the port pull-up/down control.
#define PDRCTL_PD1REN           (*((volatile PDRCTL_REG *)(PPORT_REG_BASE_ADDR + 0xD4))).bit.PD1REN      ///< This bit enable/disable the port pull-up/down control.
#define PDRCTL_PD3REN           (*((volatile PDRCTL_REG *)(PPORT_REG_BASE_ADDR + 0xD4))).bit.PD3REN      ///< This bit enable/disable the port pull-up/down control.
#define PDRCTL_PD4REN           (*((volatile PDRCTL_REG *)(PPORT_REG_BASE_ADDR + 0xD4))).bit.PD4REN      ///< This bit enable/disable the port pull-up/down control.
#define PDRCTL_PD0PDPU          (*((volatile PDRCTL_REG *)(PPORT_REG_BASE_ADDR + 0xD4))).bit.PD0PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define PDRCTL_PD1PDPU          (*((volatile PDRCTL_REG *)(PPORT_REG_BASE_ADDR + 0xD4))).bit.PD1PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define PDRCTL_PD3PDPU          (*((volatile PDRCTL_REG *)(PPORT_REG_BASE_ADDR + 0xD4))).bit.PD3PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define PDRCTL_PD4PDPU          (*((volatile PDRCTL_REG *)(PPORT_REG_BASE_ADDR + 0xD4))).bit.PD4PDPU     ///< This bit select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.

/// These bits enable/disable the port pull-up/down control.
#define PDRCTL_PDREN            (*((volatile PDRCTL_REG *)(PPORT_REG_BASE_ADDR + 0xD4))).byte_reg[0]

/// These bits select either the pull-up resistor or the pull-down resistor when using a resistor built into the port.
#define PDRCTL_PDPDPU           (*((volatile PDRCTL_REG *)(PPORT_REG_BASE_ADDR + 0xD4))).byte_reg[1]

/// Pd Port Mode Select Register
#define PDMODSEL                (*((volatile PDMODSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDC))).reg
#define PDMODSEL_PD0SEL         (*((volatile PDMODSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDC))).bit.PD0SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define PDMODSEL_PD1SEL         (*((volatile PDMODSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDC))).bit.PD1SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define PDMODSEL_PD2SEL         (*((volatile PDMODSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDC))).bit.PD2SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define PDMODSEL_PD3SEL         (*((volatile PDMODSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDC))).bit.PD3SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.
#define PDMODSEL_PD4SEL         (*((volatile PDMODSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDC))).bit.PD4SEL      ///< This bit select whether each port is used for the GPIO function or a peripheral I/O function.

/// Pd Port Function Select Register
#define PDFNCSEL                (*((volatile PDFNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDE))).reg
#define PDFNCSEL_PD0MUX         (*((volatile PDFNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDE))).bit.PD0MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define PDFNCSEL_PD1MUX         (*((volatile PDFNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDE))).bit.PD1MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define PDFNCSEL_PD2MUX         (*((volatile PDFNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDE))).bit.PD2MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.
#define PDFNCSEL_PD3MUX         (*((volatile PDFNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDE))).bit.PD3MUX      ///< These bits select the peripheral I/O function to be assigned to each port pin.

/// These bits select the peripheral I/O function to be assigned to each port pin.
#define PDFNCSEL_PD4MUX         (*((volatile PDFNCSEL_REG *)(PPORT_REG_BASE_ADDR + 0xDE))).byte_reg[1]

/// P Port Clock Control Register
#define PCLK                    (*((volatile PCLK_REG *)(PPORT_REG_BASE_ADDR + 0xE0))).reg
#define PCLK_CLKSRC             (*((volatile PCLK_REG *)(PPORT_REG_BASE_ADDR + 0xE0))).bit.CLKSRC      ///< These bits select the clock source of PPORT (chattering filter).
#define PCLK_KRSTCFG            (*((volatile PCLK_REG *)(PPORT_REG_BASE_ADDR + 0xE0))).bit.KRSTCFG     ///< These bits configure the key-entry reset function.
#define PCLK_CLKDIV             (*((volatile PCLK_REG *)(PPORT_REG_BASE_ADDR + 0xE0))).bit.CLKDIV      ///< These bits select the division ratio of the PPORT operating clock (chattering filter clock).

/// This bit sets whether the PPORT operating clock is supplied in DEBUG mode or not.
#define PCLK_DBRUN              (*((volatile PCLK_REG *)(PPORT_REG_BASE_ADDR + 0xE0))).byte_reg[1]

/// P Port Interrupt Flag Group Register
#define PINTFGRP                (*((volatile PINTFGRP_REG *)(PPORT_REG_BASE_ADDR + 0xE2))).reg
#define PINTFGRP_P0INT          (*((volatile PINTFGRP_REG *)(PPORT_REG_BASE_ADDR + 0xE2))).bit.P0INT       ///< This bit indicate that P0 port group includes a port that has generated an interrupt.
#define PINTFGRP_P1INT          (*((volatile PINTFGRP_REG *)(PPORT_REG_BASE_ADDR + 0xE2))).bit.P1INT       ///< This bit indicate that P1 port group includes a port that has generated an interrupt.
#define PINTFGRP_P2INT          (*((volatile PINTFGRP_REG *)(PPORT_REG_BASE_ADDR + 0xE2))).bit.P2INT       ///< This bit indicate that P2 port group includes a port that has generated an interrupt.
#define PINTFGRP_P3INT          (*((volatile PINTFGRP_REG *)(PPORT_REG_BASE_ADDR + 0xE2))).bit.P3INT       ///< This bit indicate that P3 port group includes a port that has generated an interrupt.
#define PINTFGRP_P4INT          (*((volatile PINTFGRP_REG *)(PPORT_REG_BASE_ADDR + 0xE2))).bit.P4INT       ///< This bit indicate that P4 port group includes a port that has generated an interrupt.
#define PINTFGRP_P6INT          (*((volatile PINTFGRP_REG *)(PPORT_REG_BASE_ADDR + 0xE2))).bit.P6INT       ///< This bit indicate that P4 port group includes a port that has generated an interrupt.
#define PINTFGRP_P7INT          (*((volatile PINTFGRP_REG *)(PPORT_REG_BASE_ADDR + 0xE2))).bit.P7INT       ///< This bit indicate that P4 port group includes a port that has generated an interrupt.

/// ----- UPMUX ----

/// P00-01 Universal Port Multiplexer Setting Register
#define P0UPMUX0                (*((volatile P0UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x00))).reg
#define P0UPMUX0_P00PERISEL     (*((volatile P0UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x00))).bit.P00PERISEL  ///< These bits specify a peripheral circuit.
#define P0UPMUX0_P00PERICH      (*((volatile P0UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x00))).bit.P00PERICH   ///< These bits specify a peripheral circuit channel number.
#define P0UPMUX0_P00PPFNC       (*((volatile P0UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x00))).bit.P00PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.
#define P0UPMUX0_P01PERISEL     (*((volatile P0UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x00))).bit.P01PERISEL  ///< These bits specify a peripheral circuit.
#define P0UPMUX0_P01PERICH      (*((volatile P0UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x00))).bit.P01PERICH   ///< These bits specify a peripheral circuit channel number.
#define P0UPMUX0_P01PPFNC       (*((volatile P0UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x00))).bit.P01PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.

/// P02-03 Universal Port Multiplexer Setting Register
#define P0UPMUX1                (*((volatile P0UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x02))).reg
#define P0UPMUX1_P02PERISEL     (*((volatile P0UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x02))).bit.P02PERISEL  ///< These bits specify a peripheral circuit.
#define P0UPMUX1_P02PERICH      (*((volatile P0UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x02))).bit.P02PERICH   ///< These bits specify a peripheral circuit channel number.
#define P0UPMUX1_P02PPFNC       (*((volatile P0UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x02))).bit.P02PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.
#define P0UPMUX1_P03PERISEL     (*((volatile P0UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x02))).bit.P03PERISEL  ///< These bits specify a peripheral circuit.
#define P0UPMUX1_P03PERICH      (*((volatile P0UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x02))).bit.P03PERICH   ///< These bits specify a peripheral circuit channel number.
#define P0UPMUX1_P03PPFNC       (*((volatile P0UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x02))).bit.P03PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.

/// P04-05 Universal Port Multiplexer Setting Register
#define P0UPMUX2                (*((volatile P0UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x04))).reg
#define P0UPMUX2_P04PERISEL     (*((volatile P0UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x04))).bit.P04PERISEL  ///< These bits specify a peripheral circuit.
#define P0UPMUX2_P04PERICH      (*((volatile P0UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x04))).bit.P04PERICH   ///< These bits specify a peripheral circuit channel number.
#define P0UPMUX2_P04PPFNC       (*((volatile P0UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x04))).bit.P04PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.
#define P0UPMUX2_P05PERISEL     (*((volatile P0UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x04))).bit.P05PERISEL  ///< These bits specify a peripheral circuit.
#define P0UPMUX2_P05PERICH      (*((volatile P0UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x04))).bit.P05PERICH   ///< These bits specify a peripheral circuit channel number.
#define P0UPMUX2_P05PPFNC       (*((volatile P0UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x04))).bit.P05PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.

/// P06-07 Universal Port Multiplexer Setting Register
#define P0UPMUX3                (*((volatile P0UPMUX3_REG *)(UPMUX_REG_BASE_ADDR + 0x06))).reg
#define P0UPMUX3_P06PERISEL     (*((volatile P0UPMUX3_REG *)(UPMUX_REG_BASE_ADDR + 0x06))).bit.P06PERISEL  ///< These bits specify a peripheral circuit.
#define P0UPMUX3_P06PERICH      (*((volatile P0UPMUX3_REG *)(UPMUX_REG_BASE_ADDR + 0x06))).bit.P06PERICH   ///< These bits specify a peripheral circuit channel number.
#define P0UPMUX3_P06PPFNC       (*((volatile P0UPMUX3_REG *)(UPMUX_REG_BASE_ADDR + 0x06))).bit.P06PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.
#define P0UPMUX3_P07PERISEL     (*((volatile P0UPMUX3_REG *)(UPMUX_REG_BASE_ADDR + 0x06))).bit.P07PERISEL  ///< These bits specify a peripheral circuit.
#define P0UPMUX3_P07PERICH      (*((volatile P0UPMUX3_REG *)(UPMUX_REG_BASE_ADDR + 0x06))).bit.P07PERICH   ///< These bits specify a peripheral circuit channel number.
#define P0UPMUX3_P07PPFNC       (*((volatile P0UPMUX3_REG *)(UPMUX_REG_BASE_ADDR + 0x06))).bit.P07PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.

/// P10-11 Universal Port Multiplexer Setting Register
#define P1UPMUX0                (*((volatile P1UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x08))).reg
#define P1UPMUX0_P10PERISEL     (*((volatile P1UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x08))).bit.P10PERISEL  ///< These bits specify a peripheral circuit.
#define P1UPMUX0_P10PERICH      (*((volatile P1UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x08))).bit.P10PERICH   ///< These bits specify a peripheral circuit channel number.
#define P1UPMUX0_P10PPFNC       (*((volatile P1UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x08))).bit.P10PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.
#define P1UPMUX0_P11PERISEL     (*((volatile P1UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x08))).bit.P11PERISEL  ///< These bits specify a peripheral circuit.
#define P1UPMUX0_P11PERICH      (*((volatile P1UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x08))).bit.P11PERICH   ///< These bits specify a peripheral circuit channel number.
#define P1UPMUX0_P11PPFNC       (*((volatile P1UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x08))).bit.P11PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.

/// P12-13 Universal Port Multiplexer Setting Register
#define P1UPMUX1                (*((volatile P1UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x0A))).reg
#define P1UPMUX1_P12PERISEL     (*((volatile P1UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x0A))).bit.P12PERISEL  ///< These bits specify a peripheral circuit.
#define P1UPMUX1_P12PERICH      (*((volatile P1UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x0A))).bit.P12PERICH   ///< These bits specify a peripheral circuit channel number.
#define P1UPMUX1_P12PPFNC       (*((volatile P1UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x0A))).bit.P12PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.
#define P1UPMUX1_P13PERISEL     (*((volatile P1UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x0A))).bit.P13PERISEL  ///< These bits specify a peripheral circuit.
#define P1UPMUX1_P13PERICH      (*((volatile P1UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x0A))).bit.P13PERICH   ///< These bits specify a peripheral circuit channel number.
#define P1UPMUX1_P13PPFNC       (*((volatile P1UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x0A))).bit.P13PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.

/// P20-21 Universal Port Multiplexer Setting Register
#define P2UPMUX0                (*((volatile P2UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x10))).reg
#define P2UPMUX0_P20PERISEL     (*((volatile P2UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x10))).bit.P20PERISEL  ///< These bits specify a peripheral circuit.
#define P2UPMUX0_P20PERICH      (*((volatile P2UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x10))).bit.P20PERICH   ///< These bits specify a peripheral circuit channel number.
#define P2UPMUX0_P20PPFNC       (*((volatile P2UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x10))).bit.P20PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.
#define P2UPMUX0_P21PERISEL     (*((volatile P2UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x10))).bit.P21PERISEL  ///< These bits specify a peripheral circuit.
#define P2UPMUX0_P21PERICH      (*((volatile P2UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x10))).bit.P21PERICH   ///< These bits specify a peripheral circuit channel number.
#define P2UPMUX0_P21PPFNC       (*((volatile P2UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x10))).bit.P21PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.

/// P22-23 Universal Port Multiplexer Setting Register
#define P2UPMUX1                (*((volatile P2UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x12))).reg
#define P2UPMUX1_P22PERISEL     (*((volatile P2UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x12))).bit.P22PERISEL  ///< These bits specify a peripheral circuit.
#define P2UPMUX1_P22PERICH      (*((volatile P2UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x12))).bit.P22PERICH   ///< These bits specify a peripheral circuit channel number.
#define P2UPMUX1_P22PPFNC       (*((volatile P2UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x12))).bit.P22PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.
#define P2UPMUX1_P23PERISEL     (*((volatile P2UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x12))).bit.P23PERISEL  ///< These bits specify a peripheral circuit.
#define P2UPMUX1_P23PERICH      (*((volatile P2UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x12))).bit.P23PERICH   ///< These bits specify a peripheral circuit channel number.
#define P2UPMUX1_P23PPFNC       (*((volatile P2UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x12))).bit.P23PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.

/// P30-31 Universal Port Multiplexer Setting Register
#define P3UPMUX0                (*((volatile P3UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x18))).reg
#define P3UPMUX0_P30PERISEL     (*((volatile P3UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x18))).bit.P30PERISEL  ///< These bits specify a peripheral circuit.
#define P3UPMUX0_P30PERICH      (*((volatile P3UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x18))).bit.P30PERICH   ///< These bits specify a peripheral circuit channel number.
#define P3UPMUX0_P30PPFNC       (*((volatile P3UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x18))).bit.P30PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.
#define P3UPMUX0_P31PERISEL     (*((volatile P3UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x18))).bit.P31PERISEL  ///< These bits specify a peripheral circuit.
#define P3UPMUX0_P31PERICH      (*((volatile P3UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x18))).bit.P31PERICH   ///< These bits specify a peripheral circuit channel number.
#define P3UPMUX0_P31PPFNC       (*((volatile P3UPMUX0_REG *)(UPMUX_REG_BASE_ADDR + 0x18))).bit.P31PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.

/// P32-33 Universal Port Multiplexer Setting Register
#define P3UPMUX1                (*((volatile P3UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x1A))).reg
#define P3UPMUX1_P32PERISEL     (*((volatile P3UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x1A))).bit.P32PERISEL  ///< These bits specify a peripheral circuit.
#define P3UPMUX1_P32PERICH      (*((volatile P3UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x1A))).bit.P32PERICH   ///< These bits specify a peripheral circuit channel number.
#define P3UPMUX1_P32PPFNC       (*((volatile P3UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x1A))).bit.P32PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.
#define P3UPMUX1_P33PERISEL     (*((volatile P3UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x1A))).bit.P33PERISEL  ///< These bits specify a peripheral circuit.
#define P3UPMUX1_P33PERICH      (*((volatile P3UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x1A))).bit.P33PERICH   ///< These bits specify a peripheral circuit channel number.
#define P3UPMUX1_P33PPFNC       (*((volatile P3UPMUX1_REG *)(UPMUX_REG_BASE_ADDR + 0x1A))).bit.P33PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.

/// P34-35 Universal Port Multiplexer Setting Register
#define P3UPMUX2                (*((volatile P3UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x1C))).reg
#define P3UPMUX2_P34PERISEL     (*((volatile P3UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x1C))).bit.P34PERISEL  ///< These bits specify a peripheral circuit.
#define P3UPMUX2_P34PERICH      (*((volatile P3UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x1C))).bit.P34PERICH   ///< These bits specify a peripheral circuit channel number.
#define P3UPMUX2_P34PPFNC       (*((volatile P3UPMUX2_REG *)(UPMUX_REG_BASE_ADDR + 0x1C))).bit.P34PPFNC    ///< These bits specify the peripheral I/O function to be assigned to the port.

/// ---- UART3 -----

/// UART3 Ch.0 Clock Control Register
#define UA0CLK                  (*((volatile UANCLK_REG *)(UART3_0_REG_BASE_ADDR + 0x00))).reg
#define UA0CLK_CLKSRC           (*((volatile UANCLK_REG *)(UART3_0_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of the UART3.
#define UA0CLK_CLKDIV           (*((volatile UANCLK_REG *)(UART3_0_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the UART3 operating clock.

/// This bit sets whether the UART operating clock is supplied in DEBUG mode or not.
#define UA0CLK_DBRUN            (*((volatile UANCLK_REG *)(UART3_0_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// UART3 Ch.0 Mode Register
#define UA0MOD                  (*((volatile UANMOD_REG *)(UART3_0_REG_BASE_ADDR + 0x02))).reg
#define UA0MOD_STPB             (*((volatile UANMOD_REG *)(UART3_0_REG_BASE_ADDR + 0x02))).bit.STPB        ///< This bit sets the stop bit length.
#define UA0MOD_PRMD             (*((volatile UANMOD_REG *)(UART3_0_REG_BASE_ADDR + 0x02))).bit.PRMD        ///< This bit selects either odd parity or even parity when using the parity function.
#define UA0MOD_PREN             (*((volatile UANMOD_REG *)(UART3_0_REG_BASE_ADDR + 0x02))).bit.PREN        ///< This bit sets the data length.
#define UA0MOD_CHLN             (*((volatile UANMOD_REG *)(UART3_0_REG_BASE_ADDR + 0x02))).bit.CHLN        ///< This bit sets the data length.
#define UA0MOD_IRMD             (*((volatile UANMOD_REG *)(UART3_0_REG_BASE_ADDR + 0x02))).bit.IRMD        ///< This bit enables the IrDA interface function.
#define UA0MOD_OUTMD            (*((volatile UANMOD_REG *)(UART3_0_REG_BASE_ADDR + 0x02))).bit.OUTMD       ///< This bit sets the USOUT0 pin output mode.
#define UA0MOD_PUEN             (*((volatile UANMOD_REG *)(UART3_0_REG_BASE_ADDR + 0x02))).bit.PUEN        ///< This bit enables pull-up of the USIN0 pin.
#define UA0MOD_INVTX            (*((volatile UANMOD_REG *)(UART3_0_REG_BASE_ADDR + 0x02))).bit.INVTX       ///< This bit enables the USOUT0 output inverting function.
#define UA0MOD_INVRX            (*((volatile UANMOD_REG *)(UART3_0_REG_BASE_ADDR + 0x02))).bit.INVRX       ///< This bit enables the USIN0 input inverting function.
#define UA0MOD_BRDIV            (*((volatile UANMOD_REG *)(UART3_0_REG_BASE_ADDR + 0x02))).bit.BRDIV       ///< This bit sets the UART3 operating clock division ratio for generating the transfer (sampling) clock using the baud rate generator.
#define UA0MOD_CAREN            (*((volatile UANMOD_REG *)(UART3_0_REG_BASE_ADDR + 0x02))).bit.CAREN       ///< This bit enables the carrier modulation function.
#define UA0MOD_PECAR            (*((volatile UANMOD_REG *)(UART3_0_REG_BASE_ADDR + 0x02))).bit.PECAR       ///< This bit selects the carrier modulation period.

/// UART3 Ch.0 Baud-Rate Register
#define UA0BR                   (*((volatile UANBR_REG *)(UART3_0_REG_BASE_ADDR + 0x04))).reg

/// These bits set the UART3 transfer rate.
#define UA0BR_BRT               (*((volatile UANBR_REG *)(UART3_0_REG_BASE_ADDR + 0x04))).byte_reg[0]

/// These bits set the UART3 transfer rate.
#define UA0BR_FMD               (*((volatile UANBR_REG *)(UART3_0_REG_BASE_ADDR + 0x04))).byte_reg[1]

/// UART3 Ch.0 Control Register
#define UA0CTL                  (*((volatile UANCTL_REG *)(UART3_0_REG_BASE_ADDR + 0x06))).reg
#define UA0CTL_MODEN            (*((volatile UANCTL_REG *)(UART3_0_REG_BASE_ADDR + 0x06))).bit.MODEN       ///< This bit enables the UART3 operations.
#define UA0CTL_SFTRST           (*((volatile UANCTL_REG *)(UART3_0_REG_BASE_ADDR + 0x06))).bit.SFTRST      ///< This bit issues software reset to the UART3.

/// UART3 Ch.0 Transmit Data Register
#define UA0TXD                  (*((volatile UANTXD_REG *)(UART3_0_REG_BASE_ADDR + 0x08))).reg
#define UA0TXD_TXD              (*((volatile UANTXD_REG *)(UART3_0_REG_BASE_ADDR + 0x08))).bit.TXD         ///< Data can be written to the transmit data buffer through these bits.

/// UART3 Ch.0 Receive Data Register
#define UA0RXD                  (*((volatile UANRXD_REG *)(UART3_0_REG_BASE_ADDR + 0x0A))).reg
#define UA0RXD_RXD              (*((volatile UANRXD_REG *)(UART3_0_REG_BASE_ADDR + 0x0A))).bit.RXD         ///< The receive data buffer can be read through these bits.

/// UART3 Ch.0 Status and Interrupt Flag Register
#define UA0INTF                 (*((volatile UANINTF_REG *)(UART3_0_REG_BASE_ADDR + 0x0C))).reg
#define UA0INTF_TBEIF           (*((volatile UANINTF_REG *)(UART3_0_REG_BASE_ADDR + 0x0C))).bit.TBEIF       ///< These bits indicate Transmit buffer empty interrupt cause occurrence status.
#define UA0INTF_RB1FIF          (*((volatile UANINTF_REG *)(UART3_0_REG_BASE_ADDR + 0x0C))).bit.RB1FIF      ///< These bits indicate Receive buffer one byte full interrupt cause occurrence status.
#define UA0INTF_RB2FIF          (*((volatile UANINTF_REG *)(UART3_0_REG_BASE_ADDR + 0x0C))).bit.RB2FIF      ///< These bits indicate Receive buffer two bytes full interrupt cause occurrence status.
#define UA0INTF_OEIF            (*((volatile UANINTF_REG *)(UART3_0_REG_BASE_ADDR + 0x0C))).bit.OEIF        ///< These bits indicate Overrun error interrupt cause occurrence status.
#define UA0INTF_PEIF            (*((volatile UANINTF_REG *)(UART3_0_REG_BASE_ADDR + 0x0C))).bit.PEIF        ///< These bits indicate Parity error interrupt cause occurrence status.
#define UA0INTF_FEIF            (*((volatile UANINTF_REG *)(UART3_0_REG_BASE_ADDR + 0x0C))).bit.FEIF        ///< These bits indicate Framing error interrupt cause occurrence status.
#define UA0INTF_TENDIF          (*((volatile UANINTF_REG *)(UART3_0_REG_BASE_ADDR + 0x0C))).bit.TENDIF      ///< These bits indicate End-of-transmission interrupt cause occurrence status.
#define UA0INTF_TBSY            (*((volatile UANINTF_REG *)(UART3_0_REG_BASE_ADDR + 0x0C))).bit.TBSY        ///< This bit indicates the sending status.
#define UA0INTF_RBSY            (*((volatile UANINTF_REG *)(UART3_0_REG_BASE_ADDR + 0x0C))).bit.RBSY        ///< This bit indicates the receiving status.

/// UART3 Ch.0 Interrupt Enable Register
#define UA0INTE                 (*((volatile UANINTE_REG *)(UART3_0_REG_BASE_ADDR + 0x0E))).reg
#define UA0INTE_TBEIE           (*((volatile UANINTE_REG *)(UART3_0_REG_BASE_ADDR + 0x0E))).bit.TBEIE       ///< These bits enable Transmit buffer empty interrupt.
#define UA0INTE_RB1FIE          (*((volatile UANINTE_REG *)(UART3_0_REG_BASE_ADDR + 0x0E))).bit.RB1FIE      ///< These bits enable Receive buffer one byte full interrupt.
#define UA0INTE_RB2FIE          (*((volatile UANINTE_REG *)(UART3_0_REG_BASE_ADDR + 0x0E))).bit.RB2FIE      ///< These bits enable Receive buffer two bytes full interrupt.
#define UA0INTE_OEIE            (*((volatile UANINTE_REG *)(UART3_0_REG_BASE_ADDR + 0x0E))).bit.OEIE        ///< These bits enable Overrun error interrupt.
#define UA0INTE_PEIE            (*((volatile UANINTE_REG *)(UART3_0_REG_BASE_ADDR + 0x0E))).bit.PEIE        ///< These bits enable Parity error interrupt.
#define UA0INTE_FEIE            (*((volatile UANINTE_REG *)(UART3_0_REG_BASE_ADDR + 0x0E))).bit.FEIE        ///< These bits enable Framing error interrupt.
#define UA0INTE_TENDIE          (*((volatile UANINTE_REG *)(UART3_0_REG_BASE_ADDR + 0x0E))).bit.TENDIE      ///< These bits enable End-of-transmission interrupt.

/// UART3 Ch.0 Carrier Waveform Register
#define UA0CAWF                 (*((volatile UANCAWF_REG *)(UART3_0_REG_BASE_ADDR + 0x10))).reg
#define UA0CAWF_CRPER           (*((volatile UANCAWF_REG *)(UART3_0_REG_BASE_ADDR + 0x10))).bit.CRPER       ///< These bits set the carrier modulation output frequency.

///

/// UART3 Ch.1 Clock Control Register
#define UA1CLK                  (*((volatile UANCLK_REG *)(UART3_1_REG_BASE_ADDR + 0x00))).reg
#define UA1CLK_CLKSRC           (*((volatile UANCLK_REG *)(UART3_1_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of the UART3.
#define UA1CLK_CLKDIV           (*((volatile UANCLK_REG *)(UART3_1_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the UART3 operating clock.

/// This bit sets whether the UART operating clock is supplied in DEBUG mode or not.
#define UA1CLK_DBRUN            (*((volatile UANCLK_REG *)(UART3_1_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// UART3 Ch.1 Mode Register
#define UA1MOD                  (*((volatile UANMOD_REG *)(UART3_1_REG_BASE_ADDR + 0x02))).reg
#define UA1MOD_STPB             (*((volatile UANMOD_REG *)(UART3_1_REG_BASE_ADDR + 0x02))).bit.STPB        ///< This bit sets the stop bit length.
#define UA1MOD_PRMD             (*((volatile UANMOD_REG *)(UART3_1_REG_BASE_ADDR + 0x02))).bit.PRMD        ///< This bit selects either odd parity or even parity when using the parity function.
#define UA1MOD_PREN             (*((volatile UANMOD_REG *)(UART3_1_REG_BASE_ADDR + 0x02))).bit.PREN        ///< This bit sets the data length.
#define UA1MOD_CHLN             (*((volatile UANMOD_REG *)(UART3_1_REG_BASE_ADDR + 0x02))).bit.CHLN        ///< This bit sets the data length.
#define UA1MOD_IRMD             (*((volatile UANMOD_REG *)(UART3_1_REG_BASE_ADDR + 0x02))).bit.IRMD        ///< This bit enables the IrDA interface function.
#define UA1MOD_OUTMD            (*((volatile UANMOD_REG *)(UART3_1_REG_BASE_ADDR + 0x02))).bit.OUTMD       ///< This bit sets the USOUT1 pin output mode.
#define UA1MOD_PUEN             (*((volatile UANMOD_REG *)(UART3_1_REG_BASE_ADDR + 0x02))).bit.PUEN        ///< This bit enables pull-up of the USIN1 pin.
#define UA1MOD_INVTX            (*((volatile UANMOD_REG *)(UART3_1_REG_BASE_ADDR + 0x02))).bit.INVTX       ///< This bit enables the USOUT1 output inverting function.
#define UA1MOD_INVRX            (*((volatile UANMOD_REG *)(UART3_1_REG_BASE_ADDR + 0x02))).bit.INVRX       ///< This bit enables the USIN1 input inverting function.
#define UA1MOD_BRDIV            (*((volatile UANMOD_REG *)(UART3_1_REG_BASE_ADDR + 0x02))).bit.BRDIV       ///< This bit sets the UART3 operating clock division ratio for generating the transfer (sampling) clock using the baud rate generator.
#define UA1MOD_CAREN            (*((volatile UANMOD_REG *)(UART3_1_REG_BASE_ADDR + 0x02))).bit.CAREN       ///< This bit enables the carrier modulation function.
#define UA1MOD_PECAR            (*((volatile UANMOD_REG *)(UART3_1_REG_BASE_ADDR + 0x02))).bit.PECAR       ///< This bit selects the carrier modulation period.

/// UART3 Ch.1 Baud-Rate Register
#define UA1BR                   (*((volatile UANBR_REG *)(UART3_1_REG_BASE_ADDR + 0x04))).reg

/// These bits set the UART3 transfer rate.
#define UA1BR_BRT               (*((volatile UANBR_REG *)(UART3_1_REG_BASE_ADDR + 0x04))).byte_reg[0]

/// These bits set the UART3 transfer rate.
#define UA1BR_FMD               (*((volatile UANBR_REG *)(UART3_1_REG_BASE_ADDR + 0x04))).byte_reg[1]

/// UART3 Ch.1 Control Register
#define UA1CTL                  (*((volatile UANCTL_REG *)(UART3_1_REG_BASE_ADDR + 0x06))).reg
#define UA1CTL_MODEN            (*((volatile UANCTL_REG *)(UART3_1_REG_BASE_ADDR + 0x06))).bit.MODEN       ///< This bit enables the UART3 operations.
#define UA1CTL_SFTRST           (*((volatile UANCTL_REG *)(UART3_1_REG_BASE_ADDR + 0x06))).bit.SFTRST      ///< This bit issues software reset to the UART3.

/// UART3 Ch.1 Transmit Data Register
#define UA1TXD                  (*((volatile UANTXD_REG *)(UART3_1_REG_BASE_ADDR + 0x08))).reg
#define UA1TXD_TXD              (*((volatile UANTXD_REG *)(UART3_1_REG_BASE_ADDR + 0x08))).bit.TXD         ///< Data can be written to the transmit data buffer through these bits.

/// UART3 Ch.1 Receive Data Register
#define UA1RXD                  (*((volatile UANRXD_REG *)(UART3_1_REG_BASE_ADDR + 0x0A))).reg
#define UA1RXD_RXD              (*((volatile UANRXD_REG *)(UART3_1_REG_BASE_ADDR + 0x0A))).bit.RXD         ///< The receive data buffer can be read through these bits.

/// UART3 Ch.1 Status and Interrupt Flag Register
#define UA1INTF                 (*((volatile UANINTF_REG *)(UART3_1_REG_BASE_ADDR + 0x0C))).reg
#define UA1INTF_TBEIF           (*((volatile UANINTF_REG *)(UART3_1_REG_BASE_ADDR + 0x0C))).bit.TBEIF       ///< These bits indicate Transmit buffer empty interrupt cause occurrence status.
#define UA1INTF_RB1FIF          (*((volatile UANINTF_REG *)(UART3_1_REG_BASE_ADDR + 0x0C))).bit.RB1FIF      ///< These bits indicate Receive buffer one byte full interrupt cause occurrence status.
#define UA1INTF_RB2FIF          (*((volatile UANINTF_REG *)(UART3_1_REG_BASE_ADDR + 0x0C))).bit.RB2FIF      ///< These bits indicate Receive buffer two bytes full interrupt cause occurrence status.
#define UA1INTF_OEIF            (*((volatile UANINTF_REG *)(UART3_1_REG_BASE_ADDR + 0x0C))).bit.OEIF        ///< These bits indicate Overrun error interrupt cause occurrence status.
#define UA1INTF_PEIF            (*((volatile UANINTF_REG *)(UART3_1_REG_BASE_ADDR + 0x0C))).bit.PEIF        ///< These bits indicate Parity error interrupt cause occurrence status.
#define UA1INTF_FEIF            (*((volatile UANINTF_REG *)(UART3_1_REG_BASE_ADDR + 0x0C))).bit.FEIF        ///< These bits indicate Framing error interrupt cause occurrence status.
#define UA1INTF_TENDIF          (*((volatile UANINTF_REG *)(UART3_1_REG_BASE_ADDR + 0x0C))).bit.TENDIF      ///< These bits indicate End-of-transmission interrupt cause occurrence status.
#define UA1INTF_TBSY            (*((volatile UANINTF_REG *)(UART3_1_REG_BASE_ADDR + 0x0C))).bit.TBSY        ///< This bit indicates the sending status.
#define UA1INTF_RBSY            (*((volatile UANINTF_REG *)(UART3_1_REG_BASE_ADDR + 0x0C))).bit.RBSY        ///< This bit indicates the receiving status.

/// UART3 Ch.1 Interrupt Enable Register
#define UA1INTE                 (*((volatile UANINTE_REG *)(UART3_1_REG_BASE_ADDR + 0x0E))).reg
#define UA1INTE_TBEIE           (*((volatile UANINTE_REG *)(UART3_1_REG_BASE_ADDR + 0x0E))).bit.TBEIE       ///< These bits enable Transmit buffer empty interrupt.
#define UA1INTE_RB1FIE          (*((volatile UANINTE_REG *)(UART3_1_REG_BASE_ADDR + 0x0E))).bit.RB1FIE      ///< These bits enable Receive buffer one byte full interrupt.
#define UA1INTE_RB2FIE          (*((volatile UANINTE_REG *)(UART3_1_REG_BASE_ADDR + 0x0E))).bit.RB2FIE      ///< These bits enable Receive buffer two bytes full interrupt.
#define UA1INTE_OEIE            (*((volatile UANINTE_REG *)(UART3_1_REG_BASE_ADDR + 0x0E))).bit.OEIE        ///< These bits enable Overrun error interrupt.
#define UA1INTE_PEIE            (*((volatile UANINTE_REG *)(UART3_1_REG_BASE_ADDR + 0x0E))).bit.PEIE        ///< These bits enable Parity error interrupt.
#define UA1INTE_FEIE            (*((volatile UANINTE_REG *)(UART3_1_REG_BASE_ADDR + 0x0E))).bit.FEIE        ///< These bits enable Framing error interrupt.
#define UA1INTE_TENDIE          (*((volatile UANINTE_REG *)(UART3_1_REG_BASE_ADDR + 0x0E))).bit.TENDIE      ///< These bits enable End-of-transmission interrupt.

/// UART3 Ch.1 Carrier Waveform Register
#define UA1CAWF                 (*((volatile UANCAWF_REG *)(UART3_1_REG_BASE_ADDR + 0x10))).reg
#define UA1CAWF_CRPER           (*((volatile UANCAWF_REG *)(UART3_1_REG_BASE_ADDR + 0x10))).bit.CRPER       ///< These bits set the carrier modulation output frequency.

/// ----- SPIA ----

/// SPIA Ch.0 Mode Register
#define SPI0MOD                 (*((volatile SPINMOD_REG *)(SPIA_0_REG_BASE_ADDR + 0x00))).reg
#define SPI0MOD_MST             (*((volatile SPINMOD_REG *)(SPIA_0_REG_BASE_ADDR + 0x00))).bit.MST         ///< This bit sets the SPIA operating mode (master mode or slave mode).
#define SPI0MOD_CPOL            (*((volatile SPINMOD_REG *)(SPIA_0_REG_BASE_ADDR + 0x00))).bit.CPOL        ///< This bit set the SPI clock polarity.
#define SPI0MOD_CPHA            (*((volatile SPINMOD_REG *)(SPIA_0_REG_BASE_ADDR + 0x00))).bit.CPHA        ///< This bit set the SPI clock phase polarity.
#define SPI0MOD_LSBFST          (*((volatile SPINMOD_REG *)(SPIA_0_REG_BASE_ADDR + 0x00))).bit.LSBFST      ///< This bit configures the data format (input/output permutation).
#define SPI0MOD_NOCLKDIV        (*((volatile SPINMOD_REG *)(SPIA_0_REG_BASE_ADDR + 0x00))).bit.NOCLKDIV    ///< This bit selects SPICLKn in master mode. This setting is ineffective in slave mode.
#define SPI0MOD_PUEN            (*((volatile SPINMOD_REG *)(SPIA_0_REG_BASE_ADDR + 0x00))).bit.PUEN        ///< This bit enables pull-up/down of the input pins.

/// These bits set the bit length of transfer data.
#define SPI0MOD_CHLN            (*((volatile SPINMOD_REG *)(SPIA_0_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// SPIA Ch.0 Control Register
#define SPI0CTL                 (*((volatile SPINCTL_REG *)(SPIA_0_REG_BASE_ADDR + 0x02))).reg
#define SPI0CTL_MODEN           (*((volatile SPINCTL_REG *)(SPIA_0_REG_BASE_ADDR + 0x02))).bit.MODEN       ///< This bit enables the SPIA operations.
#define SPI0CTL_SFTRST          (*((volatile SPINCTL_REG *)(SPIA_0_REG_BASE_ADDR + 0x02))).bit.SFTRST      ///< This bit issues software reset to SPIA.

/// SPIA Ch.0 Transmit Data Register
#define SPI0TXD                 (*((volatile SPINTXD_REG *)(SPIA_0_REG_BASE_ADDR + 0x04))).reg
#define SPI0TXD_TXD             (*((volatile SPINTXD_REG *)(SPIA_0_REG_BASE_ADDR + 0x04))).bit.TXD         ///< Data can be written to the transmit data buffer through these bits.

/// SPIA Ch.0 Receive Data Register
#define SPI0RXD                 (*((volatile SPINRXD_REG *)(SPIA_0_REG_BASE_ADDR + 0x06))).reg
#define SPI0RXD_RXD             (*((volatile SPINRXD_REG *)(SPIA_0_REG_BASE_ADDR + 0x06))).bit.RXD         ///< The receive data buffer can be read through these bits.

/// SPIA Ch.0 Interrupt Flag Register
#define SPI0INTF                (*((volatile SPININTF_REG *)(SPIA_0_REG_BASE_ADDR + 0x08))).reg
#define SPI0INTF_TBEIF          (*((volatile SPININTF_REG *)(SPIA_0_REG_BASE_ADDR + 0x08))).bit.TBEIF       ///< This bit indicate Transmit buffer empty interrupt cause occurrence status.
#define SPI0INTF_RBFIF          (*((volatile SPININTF_REG *)(SPIA_0_REG_BASE_ADDR + 0x08))).bit.RBFIF       ///< This bit indicate Receive buffer full interrupt cause occurrence status.
#define SPI0INTF_TENDIF         (*((volatile SPININTF_REG *)(SPIA_0_REG_BASE_ADDR + 0x08))).bit.TENDIF      ///< This bit indicate End-of-transmission interrupt cause occurrence status.
#define SPI0INTF_OEIF           (*((volatile SPININTF_REG *)(SPIA_0_REG_BASE_ADDR + 0x08))).bit.OEIF        ///< This bit indicate Overrun error interrupt cause occurrence status.
#define SPI0INTF_BSY            (*((volatile SPININTF_REG *)(SPIA_0_REG_BASE_ADDR + 0x08))).bit.BSY         ///< This bit indicates the SPIA operating status.

/// SPIA Ch.0 Interrupt Enable Register
#define SPI0INTE                (*((volatile SPININTE_REG *)(SPIA_0_REG_BASE_ADDR + 0x0A))).reg
#define SPI0INTE_TBEIE          (*((volatile SPININTE_REG *)(SPIA_0_REG_BASE_ADDR + 0x0A))).bit.TBEIE       ///< This bit enable Transmit buffer empty interrupt.
#define SPI0INTE_RBFIE          (*((volatile SPININTE_REG *)(SPIA_0_REG_BASE_ADDR + 0x0A))).bit.RBFIE       ///< This bit enable Receive buffer full interrupt.
#define SPI0INTE_TENDIE         (*((volatile SPININTE_REG *)(SPIA_0_REG_BASE_ADDR + 0x0A))).bit.TENDIE      ///< This bit enable End-of-transmission interrupt.
#define SPI0INTE_OEIE           (*((volatile SPININTE_REG *)(SPIA_0_REG_BASE_ADDR + 0x0A))).bit.OEIE        ///< This bit enable Overrun error interrupt.

///

/// SPIA Ch.1 Mode Register
#define SPI1MOD                 (*((volatile SPINMOD_REG *)(SPIA_1_REG_BASE_ADDR + 0x00))).reg
#define SPI1MOD_MST             (*((volatile SPINMOD_REG *)(SPIA_1_REG_BASE_ADDR + 0x00))).bit.MST         ///< This bit sets the SPIA operating mode (master mode or slave mode).
#define SPI1MOD_CPOL            (*((volatile SPINMOD_REG *)(SPIA_1_REG_BASE_ADDR + 0x00))).bit.CPOL        ///< This bit set the SPI clock phase and polarity.
#define SPI1MOD_CPHA            (*((volatile SPINMOD_REG *)(SPIA_1_REG_BASE_ADDR + 0x00))).bit.CPHA        ///< This bit set the SPI clock phase and polarity.
#define SPI1MOD_LSBFST          (*((volatile SPINMOD_REG *)(SPIA_1_REG_BASE_ADDR + 0x00))).bit.LSBFST      ///< This bit configures the data format (input/output permutation).
#define SPI1MOD_NOCLKDIV        (*((volatile SPINMOD_REG *)(SPIA_1_REG_BASE_ADDR + 0x00))).bit.NOCLKDIV    ///< This bit selects SPICLKn in master mode. This setting is ineffective in slave mode.
#define SPI1MOD_PUEN            (*((volatile SPINMOD_REG *)(SPIA_1_REG_BASE_ADDR + 0x00))).bit.PUEN        ///< This bit enables pull-up/down of the input pins.

/// These bits set the bit length of transfer data.
#define SPI1MOD_CHLN            (*((volatile SPINMOD_REG *)(SPIA_1_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// SPIA Ch.1 Control Register
#define SPI1CTL                 (*((volatile SPINCTL_REG *)(SPIA_1_REG_BASE_ADDR + 0x02))).reg
#define SPI1CTL_MODEN           (*((volatile SPINCTL_REG *)(SPIA_1_REG_BASE_ADDR + 0x02))).bit.MODEN       ///< This bit enables the SPIA operations.
#define SPI1CTL_SFTRST          (*((volatile SPINCTL_REG *)(SPIA_1_REG_BASE_ADDR + 0x02))).bit.SFTRST      ///< This bit issues software reset to SPIA.

/// SPIA Ch.1 Transmit Data Register
#define SPI1TXD                 (*((volatile SPINTXD_REG *)(SPIA_1_REG_BASE_ADDR + 0x04))).reg
#define SPI1TXD_TXD             (*((volatile SPINTXD_REG *)(SPIA_1_REG_BASE_ADDR + 0x04))).bit.TXD         ///< SPIA Ch.1 Transmit Data Register

/// SPIA Ch.1 Receive Data Register
#define SPI1RXD                 (*((volatile SPINRXD_REG *)(SPIA_1_REG_BASE_ADDR + 0x06))).reg
#define SPI1RXD_RXD             (*((volatile SPINRXD_REG *)(SPIA_1_REG_BASE_ADDR + 0x06))).bit.RXD         ///< SPIA Ch.1 Receive Data Register

/// SPIA Ch.1 Interrupt Flag Register
#define SPI1INTF                (*((volatile SPININTF_REG *)(SPIA_1_REG_BASE_ADDR + 0x08))).reg
#define SPI1INTF_TBEIF          (*((volatile SPININTF_REG *)(SPIA_1_REG_BASE_ADDR + 0x08))).bit.TBEIF       ///< This bit indicate Transmit buffer empty interrupt cause occurrence status.
#define SPI1INTF_RBFIF          (*((volatile SPININTF_REG *)(SPIA_1_REG_BASE_ADDR + 0x08))).bit.RBFIF       ///< This bit indicate Receive buffer full interrupt cause occurrence status.
#define SPI1INTF_TENDIF         (*((volatile SPININTF_REG *)(SPIA_1_REG_BASE_ADDR + 0x08))).bit.TENDIF      ///< This bit indicate End-of-transmission interrupt cause occurrence status.
#define SPI1INTF_OEIF           (*((volatile SPININTF_REG *)(SPIA_1_REG_BASE_ADDR + 0x08))).bit.OEIF        ///< This bit indicate Overrun error interrupt cause occurrence status.
#define SPI1INTF_BSY            (*((volatile SPININTF_REG *)(SPIA_1_REG_BASE_ADDR + 0x08))).bit.BSY         ///< This bit indicates the SPIA operating status.

/// SPIA Ch.1 Interrupt Enable Register
#define SPI1INTE                (*((volatile SPININTE_REG *)(SPIA_1_REG_BASE_ADDR + 0x0A))).reg
#define SPI1INTE_TBEIE          (*((volatile SPININTE_REG *)(SPIA_1_REG_BASE_ADDR + 0x0A))).bit.TBEIE       ///< This bit enable Transmit buffer empty interrupt.
#define SPI1INTE_RBFIE          (*((volatile SPININTE_REG *)(SPIA_1_REG_BASE_ADDR + 0x0A))).bit.RBFIE       ///< This bit enable Receive buffer full interrupt.
#define SPI1INTE_TENDIE         (*((volatile SPININTE_REG *)(SPIA_1_REG_BASE_ADDR + 0x0A))).bit.TENDIE      ///< This bit enable End-of-transmission interrupt.
#define SPI1INTE_OEIE           (*((volatile SPININTE_REG *)(SPIA_1_REG_BASE_ADDR + 0x0A))).bit.OEIE        ///< This bit enable Overrun error interrupt.

/// ----- I2C -----

/// I2C Ch.0 Clock Control Register
#define I2C0CLK                 (*((volatile I2CNCLK_REG *)(I2C_0_REG_BASE_ADDR + 0x00))).reg
#define I2C0CLK_CLKSRC          (*((volatile I2CNCLK_REG *)(I2C_0_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of the I2C.
#define I2C0CLK_CLKDIV          (*((volatile I2CNCLK_REG *)(I2C_0_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the I2C operating clock.

/// This bit sets whether the I2C operating clock is supplied in DEBUG mode or not.
#define I2C0CLK_DBRUN           (*((volatile I2CNCLK_REG *)(I2C_0_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// I2C Ch.0 Mode Register
#define I2C0MOD                 (*((volatile I2CNMOD_REG *)(I2C_0_REG_BASE_ADDR + 0x02))).reg
#define I2C0MOD_GCEN            (*((volatile I2CNMOD_REG *)(I2C_0_REG_BASE_ADDR + 0x02))).bit.GCEN        ///< This bit sets whether to respond to master general calls in slave mode or not.
#define I2C0MOD_OADR10          (*((volatile I2CNMOD_REG *)(I2C_0_REG_BASE_ADDR + 0x02))).bit.OADR10      ///< This bit sets the number of own address bits for slave mode.

/// I2C Ch.0 Baud-Rate Register
#define I2C0BR                  (*((volatile I2CNBR_REG *)(I2C_0_REG_BASE_ADDR + 0x04))).reg
#define I2C0BR_BRT              (*((volatile I2CNBR_REG *)(I2C_0_REG_BASE_ADDR + 0x04))).bit.BRT         ///< These bits set the I2C Ch.0 transfer rate for master mode.

/// I2C Ch.0 Own Address Register
#define I2C0OADR                (*((volatile I2CNOADR_REG *)(I2C_0_REG_BASE_ADDR + 0x08))).reg
#define I2C0OADR_OADR           (*((volatile I2CNOADR_REG *)(I2C_0_REG_BASE_ADDR + 0x08))).bit.OADR        ///< These bits set the own address for slave mode.

/// I2C Ch.0 Control Register
#define I2C0CTL                 (*((volatile I2CNCTL_REG *)(I2C_0_REG_BASE_ADDR + 0x0A))).reg
#define I2C0CTL_MODEN           (*((volatile I2CNCTL_REG *)(I2C_0_REG_BASE_ADDR + 0x0A))).bit.MODEN       ///< This bit enables the I2C operations.
#define I2C0CTL_SFTRST          (*((volatile I2CNCTL_REG *)(I2C_0_REG_BASE_ADDR + 0x0A))).bit.SFTRST      ///< This bit issues software reset to the I2C.
#define I2C0CTL_TXSTART         (*((volatile I2CNCTL_REG *)(I2C_0_REG_BASE_ADDR + 0x0A))).bit.TXSTART     ///< This bit issues a START condition in master mode.
#define I2C0CTL_TXSTOP          (*((volatile I2CNCTL_REG *)(I2C_0_REG_BASE_ADDR + 0x0A))).bit.TXSTOP      ///< This bit issues a STOP condition in master mode.
#define I2C0CTL_TXNACK          (*((volatile I2CNCTL_REG *)(I2C_0_REG_BASE_ADDR + 0x0A))).bit.TXNACK      ///< This bit issues a request for sending a NACK at the next responding.
#define I2C0CTL_MST             (*((volatile I2CNCTL_REG *)(I2C_0_REG_BASE_ADDR + 0x0A))).bit.MST         ///< This bit selects the I2C Ch.0 operating mode.

/// I2C Ch.0 Transmit Data Register
#define I2C0TXD                 (*((volatile I2CNTXD_REG *)(I2C_0_REG_BASE_ADDR + 0x0C))).reg
#define I2C0TXD_TXD             (*((volatile I2CNTXD_REG *)(I2C_0_REG_BASE_ADDR + 0x0C))).bit.TXD         ///< Data can be written to the transmit data buffer through these bits.

/// I2C Ch.0 Receive Data Register
#define I2C0RXD                 (*((volatile I2CNRXD_REG *)(I2C_0_REG_BASE_ADDR + 0x0E))).reg
#define I2C0RXD_RXD             (*((volatile I2CNRXD_REG *)(I2C_0_REG_BASE_ADDR + 0x0E))).bit.RXD         ///< The receive data buffer can be read through these bits.

/// I2C Ch.0 Status and Interrupt Flag Register
#define I2C0INTF                (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).reg
#define I2C0INTF_TBEIF          (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).bit.TBEIF       ///< This bit indicate Transmit buffer empty interrupt cause occurrence status.
#define I2C0INTF_RBFIF          (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).bit.RBFIF       ///< This bit indicate Receive buffer full interrupt cause occurrence status.
#define I2C0INTF_ERRIF          (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).bit.ERRIF       ///< This bit indicate Error detection interrupt cause occurrence status.
#define I2C0INTF_STARTIF        (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).bit.STARTIF     ///< This bit indicate START condition interrupt cause occurrence status.
#define I2C0INTF_STOPIF         (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).bit.STOPIF      ///< This bit indicate STOP condition interrupt cause occurrence status.
#define I2C0INTF_NACKIF         (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).bit.NACKIF      ///< This bit indicate NACK reception interrupt cause occurrence status.
#define I2C0INTF_GCIF           (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).bit.GCIF        ///< This bit indicate General call address reception interrupt cause occurrence status.
#define I2C0INTF_BYTEENDIF      (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).bit.BYTEENDIF   ///< This bit indicate End of transfer interrupt cause occurrence status.
#define I2C0INTF_TR             (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).bit.TR          ///< This bit indicates whether the I2C is set in transmission mode or not.
#define I2C0INTF_BSY            (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).bit.BSY         ///< This bit indicates that the I2C bus is placed into busy status.
#define I2C0INTF_SCLLOW         (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).bit.SCLLOW      ///< This bit indicates that SCL is set to low level.
#define I2C0INTF_SDALOW         (*((volatile I2CNINTF_REG *)(I2C_0_REG_BASE_ADDR + 0x10))).bit.SDALOW      ///< This bit indicates that SDA is set to low level.

/// I2C Ch.0 Interrupt Enable Register
#define I2C0INTE                (*((volatile I2CNINTE_REG *)(I2C_0_REG_BASE_ADDR + 0x12))).reg
#define I2C0INTE_TBEIE          (*((volatile I2CNINTE_REG *)(I2C_0_REG_BASE_ADDR + 0x12))).bit.TBEIE       ///< This bit enable Transmit buffer empty interrupt.
#define I2C0INTE_RBFIE          (*((volatile I2CNINTE_REG *)(I2C_0_REG_BASE_ADDR + 0x12))).bit.RBFIE       ///< This bit enable Receive buffer full interrupt.
#define I2C0INTE_ERRIE          (*((volatile I2CNINTE_REG *)(I2C_0_REG_BASE_ADDR + 0x12))).bit.ERRIE       ///< This bit enable Error detection interrupt.
#define I2C0INTE_STARTIE        (*((volatile I2CNINTE_REG *)(I2C_0_REG_BASE_ADDR + 0x12))).bit.STARTIE     ///< This bit enable START condition interrupt.
#define I2C0INTE_STOPIE         (*((volatile I2CNINTE_REG *)(I2C_0_REG_BASE_ADDR + 0x12))).bit.STOPIE      ///< This bit enable STOP condition interrupt.
#define I2C0INTE_NACKIE         (*((volatile I2CNINTE_REG *)(I2C_0_REG_BASE_ADDR + 0x12))).bit.NACKIE      ///< This bit enable NACK reception interrupt.
#define I2C0INTE_GCIE           (*((volatile I2CNINTE_REG *)(I2C_0_REG_BASE_ADDR + 0x12))).bit.GCIE        ///< This bit enable General call address reception interrupt.
#define I2C0INTE_BYTEENDIE      (*((volatile I2CNINTE_REG *)(I2C_0_REG_BASE_ADDR + 0x12))).bit.BYTEENDIE   ///< This bit enable End of transfer interrupt.

/// ----- T16B ------

/// T16B Ch.0 Clock Control Register
#define T16B0CLK                (*((volatile T16BNCLK_REG *)(T16B_0_REG_BASE_ADDR + 0x00))).reg
#define T16B0CLK_CLKSRC         (*((volatile T16BNCLK_REG *)(T16B_0_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of T16B Ch.0.
#define T16B0CLK_CLKDIV         (*((volatile T16BNCLK_REG *)(T16B_0_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the T16B Ch.0 operating clock (counter clock).

/// This bit sets whether the T16B Ch.0 operating clock is supplied in DEBUG mode or not.
#define T16B0CLK_DBRUN          (*((volatile T16BNCLK_REG *)(T16B_0_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// T16B Ch.0 Counter Control Register.
#define T16B0CTL                (*((volatile T16BNCTL_REG *)(T16B_0_REG_BASE_ADDR + 0x02))).reg
#define T16B0CTL_MODEN          (*((volatile T16BNCTL_REG *)(T16B_0_REG_BASE_ADDR + 0x02))).bit.MODEN       ///< This bit enables the T16B Ch.0 operations.
#define T16B0CTL_PRESET         (*((volatile T16BNCTL_REG *)(T16B_0_REG_BASE_ADDR + 0x02))).bit.PRESET      ///< This bit resets the counter.
#define T16B0CTL_RUN            (*((volatile T16BNCTL_REG *)(T16B_0_REG_BASE_ADDR + 0x02))).bit.RUN         ///< This bit starts/stops counting.
#define T16B0CTL_ONEST          (*((volatile T16BNCTL_REG *)(T16B_0_REG_BASE_ADDR + 0x02))).bit.ONEST       ///< This bit selects the counter repeat/one-shot mode.
#define T16B0CTL_CNTMD          (*((volatile T16BNCTL_REG *)(T16B_0_REG_BASE_ADDR + 0x02))).bit.CNTMD       ///< These bits select the counter up/down mode.

/// This bit indicates whether data can be written to the T16BnMC register or not.
#define T16B0CTL_MAXBSY         (*((volatile T16BNCTL_REG *)(T16B_0_REG_BASE_ADDR + 0x02))).byte_reg[1]

/// T16B Ch.0 Max Counter Data Register
#define T16B0MC                 (*((volatile T16BNMC_REG *)(T16B_0_REG_BASE_ADDR + 0x04))).reg
#define T16B0MC_MC              (*((volatile T16BNMC_REG *)(T16B_0_REG_BASE_ADDR + 0x04))).bit.MC          ///< These bits are used to set the MAX value to preset to the counter.

/// T16B Ch.0 Timer Counter Data Register.
#define T16B0TC                 (*((volatile T16BNTC_REG *)(T16B_0_REG_BASE_ADDR + 0x06))).reg
#define T16B0TC_TC              (*((volatile T16BNTC_REG *)(T16B_0_REG_BASE_ADDR + 0x06))).bit.TC          ///< The current counter value can be read out through these bits.

/// T16B Ch.0 Counter Status Register
#define T16B0CS                 (*((volatile T16BNCS_REG *)(T16B_0_REG_BASE_ADDR + 0x08))).reg
#define T16B0CS_BSY             (*((volatile T16BNCS_REG *)(T16B_0_REG_BASE_ADDR + 0x08))).bit.BSY         ///< This bit indicates the counter operating status.
#define T16B0CS_UP_DOWN         (*((volatile T16BNCS_REG *)(T16B_0_REG_BASE_ADDR + 0x08))).bit.UP_DOWN     ///< This bit indicates the currently set count direction.
#define T16B0CS_CAPI0           (*((volatile T16BNCS_REG *)(T16B_0_REG_BASE_ADDR + 0x08))).bit.CAPI0       ///< This bit indicate the signal level currently input to the CAPx0 pin.
#define T16B0CS_CAPI1           (*((volatile T16BNCS_REG *)(T16B_0_REG_BASE_ADDR + 0x08))).bit.CAPI1       ///< This bit indicate the signal level currently input to the CAPx1 pin.
#define T16B0CS_CAPI2           (*((volatile T16BNCS_REG *)(T16B_0_REG_BASE_ADDR + 0x08))).bit.CAPI2       ///< This bit indicate the signal level currently input to the CAPx2 pin.
#define T16B0CS_CAPI3           (*((volatile T16BNCS_REG *)(T16B_0_REG_BASE_ADDR + 0x08))).bit.CAPI3       ///< This bit indicate the signal level currently input to the CAPx3 pin.
#define T16B0CS_CAPI4           (*((volatile T16BNCS_REG *)(T16B_0_REG_BASE_ADDR + 0x08))).bit.CAPI4       ///< This bit indicate the signal level currently input to the CAPx4 pin.
#define T16B0CS_CAPI5           (*((volatile T16BNCS_REG *)(T16B_0_REG_BASE_ADDR + 0x08))).bit.CAPI5       ///< This bit indicate the signal level currently input to the CAPx5 pin.

/// T16B Ch.0 Interrupt Flag Register.
#define T16B0INTF               (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).reg
#define T16B0INTF_CNTZEROIF     (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).bit.CNTZEROIF   ///< This bit indicate the Counter zero interrupt cause occurrence status.
#define T16B0INTF_CNTMAXIF      (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).bit.CNTMAXIF    ///< This bit indicate the Counter MAX interrupt cause occurrence status.
#define T16B0INTF_CMPCAP0IF     (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).bit.CMPCAP0IF   ///< This bit indicate the Compare/capture 0 interrupt cause occurrence status.
#define T16B0INTF_CAPOW0IF      (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).bit.CAPOW0IF    ///< This bit indicate the Capture 0 overwrite interrupt cause occurrence status.
#define T16B0INTF_CMPCAP1IF     (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).bit.CMPCAP1IF   ///< This bit indicate the Compare/capture 1 interrupt cause occurrence status.
#define T16B0INTF_CAPOW1IF      (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).bit.CAPOW1IF    ///< This bit indicate the Capture 1 overwrite interrupt cause occurrence status.
#define T16B0INTF_CMPCAP2IF     (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).bit.CMPCAP2IF   ///< This bit indicate the Compare/capture 2 interrupt cause occurrence status.
#define T16B0INTF_CAPOW2IF      (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).bit.CAPOW2IF    ///< This bit indicate the Capture 2 overwrite interrupt cause occurrence status.
#define T16B0INTF_CMPCAP3IF     (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).bit.CMPCAP3IF   ///< This bit indicate the Compare/capture 3 interrupt cause occurrence status.
#define T16B0INTF_CAPOW3IF      (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).bit.CAPOW3IF    ///< This bit indicate the Capture 3 overwrite interrupt cause occurrence status.
#define T16B0INTF_CMPCAP4IF     (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).bit.CMPCAP4IF   ///< This bit indicate the Compare/capture 4 interrupt cause occurrence status.
#define T16B0INTF_CAPOW4IF      (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).bit.CAPOW4IF    ///< This bit indicate the Capture 4 overwrite interrupt cause occurrence status.
#define T16B0INTF_CMPCAP5IF     (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).bit.CMPCAP5IF   ///< This bit indicate the Compare/capture 5 interrupt cause occurrence status.
#define T16B0INTF_CAPOW5IF      (*((volatile T16BNINTF_REG *)(T16B_0_REG_BASE_ADDR + 0x0A))).bit.CAPOW5IF    ///< This bit indicate the Capture 5 overwrite interrupt cause occurrence status.

/// T16B Ch.0 Interrupt Enable Register.
#define T16B0INTE               (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).reg
#define T16B0INTE_CNTZEROIE     (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).bit.CNTZEROIE   ///< This bit enable Counter zero interrupt.
#define T16B0INTE_CNTMAXIE      (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).bit.CNTMAXIE    ///< This bit enable Counter MAX interrupt.
#define T16B0INTE_CMPCAP0IE     (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).bit.CMPCAP0IE   ///< This bit enable Compare/capture 0 interrupt.
#define T16B0INTE_CAPOW0IE      (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).bit.CAPOW0IE    ///< This bit enable Capture 0 overwrite interrupt.
#define T16B0INTE_CMPCAP1IE     (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).bit.CMPCAP1IE   ///< This bit enable Compare/capture 1 interrupt interrupts.
#define T16B0INTE_CAPOW1IE      (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).bit.CAPOW1IE    ///< This bit enable Capture 1 overwrite interrupt.
#define T16B0INTE_CMPCAP2IE     (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).bit.CMPCAP2IE   ///< This bit enable Compare/capture 2 interrupt interrupts.
#define T16B0INTE_CAPOW2IE      (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).bit.CAPOW2IE    ///< This bit enable Capture 2 overwrite interrupt.
#define T16B0INTE_CMPCAP3IE     (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).bit.CMPCAP3IE   ///< This bit enable Compare/capture 3 interrupt interrupts.
#define T16B0INTE_CAPOW3IE      (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).bit.CAPOW3IE    ///< This bit enable Capture 3 overwrite interrupt.
#define T16B0INTE_CMPCAP4IE     (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).bit.CMPCAP4IE   ///< This bit enable Compare/capture 4 interrupt interrupts.
#define T16B0INTE_CAPOW4IE      (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).bit.CAPOW4IE    ///< This bit enable Capture 4 overwrite interrupt.
#define T16B0INTE_CMPCAP5IE     (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).bit.CMPCAP5IE   ///< This bit enable Compare/capture 5 interrupt interrupts.
#define T16B0INTE_CAPOW5IE      (*((volatile T16BNINTE_REG *)(T16B_0_REG_BASE_ADDR + 0x0C))).bit.CAPOW5IE    ///< This bit enable Capture 5 overwrite interrupt.

/// T16B Ch.0 Comparator/Capture 0 Control Register.
#define T16B0CCCTL0             (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x10))).reg
#define T16B0CCCTL0_CCMD        (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x10))).bit.CCMD        ///< This bit selects the operating mode of the comparator/capture circuit m.
#define T16B0CCCTL0_TOUTINV     (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x10))).bit.TOUTINV     ///< This bit selects the TOUT00 signal polarity.
#define T16B0CCCTL0_TOUTMD      (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x10))).bit.TOUTMD      ///< These bits configure how the TOUT00 signal waveform is changed.
#define T16B0CCCTL0_TOUTO       (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x10))).bit.TOUTO       ///< This bit sets the TOUT00 signal output level when software control mode (T16B0CCCTL0.TOUTMD[2:0] = 0x0) is selected for the TOUT00 output.
#define T16B0CCCTL0_TOUTMT      (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x10))).bit.TOUTMT      ///< This bit selects whether the comparator MATCH signal of another system is used for generating the TOUT00 signal or not.
#define T16B0CCCTL0_CAPTRG      (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x10))).bit.CAPTRG      ///< These bits select the trigger edge(s) of the trigger signal.
#define T16B0CCCTL0_CAPIS       (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x10))).bit.CAPIS       ///< These bits select the trigger signal for capturing.
#define T16B0CCCTL0_CBUFMD      (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x10))).bit.CBUFMD      ///< These bits select the timing to load the comparison value written.
#define T16B0CCCTL0_SCS         (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x10))).bit.SCS         ///< This bit selects either synchronous capture mode or asynchronous capture mode.

/// T16B Ch.0 Compare/Capture 0 Data Register.
#define T16B0CCR0               (*((volatile T16BNCCRM_REG *)(T16B_0_REG_BASE_ADDR + 0x12))).reg
#define T16B0CCR0_CC            (*((volatile T16BNCCRM_REG *)(T16B_0_REG_BASE_ADDR + 0x12))).bit.CC          ///< T16B Ch.0 Compare/Capture 0 Data Register

/// T16B Ch.0 Comparator/Capture 1 Control Registerr.
#define T16B0CCCTL1             (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x18))).reg
#define T16B0CCCTL1_CCMD        (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x18))).bit.CCMD        ///< This bit selects the operating mode of the comparator/capture circuit m.
#define T16B0CCCTL1_TOUTINV     (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x18))).bit.TOUTINV     ///< This bit selects the TOUT01 signal polarity.
#define T16B0CCCTL1_TOUTMD      (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x18))).bit.TOUTMD      ///< These bits configure how the TOUT01 signal waveform is changed.
#define T16B0CCCTL1_TOUTO       (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x18))).bit.TOUTO       ///< This bit sets the TOUT01 signal output level
#define T16B0CCCTL1_TOUTMT      (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x18))).bit.TOUTMT      ///< This bit selects whether the comparator equal signal.
#define T16B0CCCTL1_CAPTRG      (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x18))).bit.CAPTRG      ///< These bits select the trigger edge(s) of the trigger signal.
#define T16B0CCCTL1_CAPIS       (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x18))).bit.CAPIS       ///< These bits select the trigger signal for capturing.
#define T16B0CCCTL1_CBUFMD      (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x18))).bit.CBUFMD      ///< These bits select the timing to load the comparison value written.
#define T16B0CCCTL1_SCS         (*((volatile T16BNCCCTLM_REG *)(T16B_0_REG_BASE_ADDR + 0x18))).bit.SCS         ///< This bit selects either synchronous capture mode or asynchronous capture mode.

/// T16B Ch.0 Compare/Capture 1 Data Register.
#define T16B0CCR1               (*((volatile T16BNCCRM_REG *)(T16B_0_REG_BASE_ADDR + 0x1A))).reg
#define T16B0CCR1_CC            (*((volatile T16BNCCRM_REG *)(T16B_0_REG_BASE_ADDR + 0x1A))).bit.CC          ///< T16B Ch.0 Compare/Capture 1 Data Register

///

/// T16B Ch.1 Clock Control Register
#define T16B1CLK                (*((volatile T16BNCLK_REG *)(T16B_1_REG_BASE_ADDR + 0x00))).reg
#define T16B1CLK_CLKSRC         (*((volatile T16BNCLK_REG *)(T16B_1_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of T16B Ch.1.
#define T16B1CLK_CLKDIV         (*((volatile T16BNCLK_REG *)(T16B_1_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the T16B Ch.1 operating clock (counter clock).

/// This bit sets whether the T16B Ch.1 operating clock is supplied in DEBUG mode or not.
#define T16B1CLK_DBRUN          (*((volatile T16BNCLK_REG *)(T16B_1_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// T16B Ch.1 Counter Control Register.
#define T16B1CTL                (*((volatile T16BNCTL_REG *)(T16B_1_REG_BASE_ADDR + 0x02))).reg
#define T16B1CTL_MODEN          (*((volatile T16BNCTL_REG *)(T16B_1_REG_BASE_ADDR + 0x02))).bit.MODEN       ///< This bit enables the T16B Ch.1 operations.
#define T16B1CTL_PRESET         (*((volatile T16BNCTL_REG *)(T16B_1_REG_BASE_ADDR + 0x02))).bit.PRESET      ///< This bit resets the counter.
#define T16B1CTL_RUN            (*((volatile T16BNCTL_REG *)(T16B_1_REG_BASE_ADDR + 0x02))).bit.RUN         ///< This bit starts/stops counting.
#define T16B1CTL_ONEST          (*((volatile T16BNCTL_REG *)(T16B_1_REG_BASE_ADDR + 0x02))).bit.ONEST       ///< This bit selects the counter repeat/one-shot mode.
#define T16B1CTL_CNTMD          (*((volatile T16BNCTL_REG *)(T16B_1_REG_BASE_ADDR + 0x02))).bit.CNTMD       ///< These bits select the counter up/down mode.

/// This bit indicates whether data can be written to the T16B1MC register or not.
#define T16B1CTL_MAXBSY         (*((volatile T16BNCTL_REG *)(T16B_1_REG_BASE_ADDR + 0x02))).byte_reg[1]

/// T16B Ch.1 Max Counter Data Register
#define T16B1MC                 (*((volatile T16BNMC_REG *)(T16B_1_REG_BASE_ADDR + 0x04))).reg
#define T16B1MC_MC              (*((volatile T16BNMC_REG *)(T16B_1_REG_BASE_ADDR + 0x04))).bit.MC          ///< T16B Ch.1 Max Counter Data Register

/// T16B Ch.1 Timer Counter Data Register.
#define T16B1TC                 (*((volatile T16BNTC_REG *)(T16B_1_REG_BASE_ADDR + 0x06))).reg
#define T16B1TC_TC              (*((volatile T16BNTC_REG *)(T16B_1_REG_BASE_ADDR + 0x06))).bit.TC          ///< T16B Ch.1 Timer Counter Data Register.

/// T16B Ch.1 Counter Status Register
#define T16B1CS                 (*((volatile T16BNCS_REG *)(T16B_1_REG_BASE_ADDR + 0x08))).reg
#define T16B1CS_BSY             (*((volatile T16BNCS_REG *)(T16B_1_REG_BASE_ADDR + 0x08))).bit.BSY         ///< This bit indicates the counter operating status.
#define T16B1CS_UP_DOWN         (*((volatile T16BNCS_REG *)(T16B_1_REG_BASE_ADDR + 0x08))).bit.UP_DOWN     ///< This bit indicates the currently set count direction.
#define T16B1CS_CAPI0           (*((volatile T16BNCS_REG *)(T16B_1_REG_BASE_ADDR + 0x08))).bit.CAPI0       ///< This bit indicate the signal level currently input to the CAPx0 pin.
#define T16B1CS_CAPI1           (*((volatile T16BNCS_REG *)(T16B_1_REG_BASE_ADDR + 0x08))).bit.CAPI1       ///< This bit indicate the signal level currently input to the CAPx1 pin.
#define T16B1CS_CAPI2           (*((volatile T16BNCS_REG *)(T16B_1_REG_BASE_ADDR + 0x08))).bit.CAPI2       ///< This bit indicate the signal level currently input to the CAPx2 pin.
#define T16B1CS_CAPI3           (*((volatile T16BNCS_REG *)(T16B_1_REG_BASE_ADDR + 0x08))).bit.CAPI3       ///< This bit indicate the signal level currently input to the CAPx3 pin.
#define T16B1CS_CAPI4           (*((volatile T16BNCS_REG *)(T16B_1_REG_BASE_ADDR + 0x08))).bit.CAPI4       ///< This bit indicate the signal level currently input to the CAPx4 pin.
#define T16B1CS_CAPI5           (*((volatile T16BNCS_REG *)(T16B_1_REG_BASE_ADDR + 0x08))).bit.CAPI5       ///< This bit indicate the signal level currently input to the CAPx5 pin.

/// T16B Ch.1 Interrupt Flag Register.
#define T16B1INTF               (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).reg
#define T16B1INTF_CNTZEROIF     (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).bit.CNTZEROIF   ///< Counter zero interrupt
#define T16B1INTF_CNTMAXIF      (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).bit.CNTMAXIF    ///< Counter MAX interrupt
#define T16B1INTF_CMPCAP0IF     (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).bit.CMPCAP0IF   ///< Compare/capture 0 interrupt
#define T16B1INTF_CAPOW0IF      (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).bit.CAPOW0IF    ///< Capture 0 overwrite interrupt
#define T16B1INTF_CMPCAP1IF     (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).bit.CMPCAP1IF   ///< Compare/capture 1 interrupt
#define T16B1INTF_CAPOW1IF      (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).bit.CAPOW1IF    ///< Capture 1 overwrite interrupt
#define T16B1INTF_CMPCAP2IF     (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).bit.CMPCAP2IF   ///< This bit indicate the Compare/capture 2 interrupt cause occurrence status.
#define T16B1INTF_CAPOW2IF      (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).bit.CAPOW2IF    ///< This bit indicate the Capture 2 overwrite interrupt cause occurrence status.
#define T16B1INTF_CMPCAP3IF     (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).bit.CMPCAP3IF   ///< This bit indicate the Compare/capture 3 interrupt cause occurrence status.
#define T16B1INTF_CAPOW3IF      (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).bit.CAPOW3IF    ///< This bit indicate the Capture 3 overwrite interrupt cause occurrence status.
#define T16B1INTF_CMPCAP4IF     (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).bit.CMPCAP4IF   ///< This bit indicate the Compare/capture 4 interrupt cause occurrence status.
#define T16B1INTF_CAPOW4IF      (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).bit.CAPOW4IF    ///< This bit indicate the Capture 4 overwrite interrupt cause occurrence status.
#define T16B1INTF_CMPCAP5IF     (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).bit.CMPCAP5IF   ///< This bit indicate the Compare/capture 5 interrupt cause occurrence status.
#define T16B1INTF_CAPOW5IF      (*((volatile T16BNINTF_REG *)(T16B_1_REG_BASE_ADDR + 0x0A))).bit.CAPOW5IF    ///< This bit indicate the Capture 5 overwrite interrupt cause occurrence status.

/// T16B Ch.1 Interrupt Enable Register.
#define T16B1INTE               (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).reg
#define T16B1INTE_CNTZEROIE     (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).bit.CNTZEROIE   ///< Counter zero interrupt
#define T16B1INTE_CNTMAXIE      (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).bit.CNTMAXIE    ///< Counter MAX interrupt
#define T16B1INTE_CMPCAP0IE     (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).bit.CMPCAP0IE   ///< Compare/capture 0 interrupt
#define T16B1INTE_CAPOW0IE      (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).bit.CAPOW0IE    ///< Capture 0 overwrite interrupt
#define T16B1INTE_CMPCAP1IE     (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).bit.CMPCAP1IE   ///< Compare/capture 1 interrupt
#define T16B1INTE_CAPOW1IE      (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).bit.CAPOW1IE    ///< Capture 1 overwrite interrupt
#define T16B1INTE_CMPCAP2IE     (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).bit.CMPCAP2IE   ///< This bit enable Compare/capture 2 interrupt interrupts.
#define T16B1INTE_CAPOW2IE      (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).bit.CAPOW2IE    ///< This bit enable Capture 2 overwrite interrupt.
#define T16B1INTE_CMPCAP3IE     (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).bit.CMPCAP3IE   ///< This bit enable Compare/capture 3 interrupt interrupts.
#define T16B1INTE_CAPOW3IE      (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).bit.CAPOW3IE    ///< This bit enable Capture 3 overwrite interrupt.
#define T16B1INTE_CMPCAP4IE     (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).bit.CMPCAP4IE   ///< This bit enable Compare/capture 4 interrupt interrupts.
#define T16B1INTE_CAPOW4IE      (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).bit.CAPOW4IE    ///< This bit enable Capture 4 overwrite interrupt.
#define T16B1INTE_CMPCAP5IE     (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).bit.CMPCAP5IE   ///< This bit enable Compare/capture 5 interrupt interrupts.
#define T16B1INTE_CAPOW5IE      (*((volatile T16BNINTE_REG *)(T16B_1_REG_BASE_ADDR + 0x0C))).bit.CAPOW5IE    ///< This bit enable Capture 5 overwrite interrupt.

/// T16B Ch.1 Comparator/Capture 0 Control Register.
#define T16B1CCCTL0             (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x10))).reg
#define T16B1CCCTL0_CCMD        (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x10))).bit.CCMD        ///< This bit selects the operating mode of the comparator/capture circuit m.
#define T16B1CCCTL0_TOUTINV     (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x10))).bit.TOUTINV     ///< This bit selects the TOUT10 signal polarity.
#define T16B1CCCTL0_TOUTMD      (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x10))).bit.TOUTMD      ///< These bits configure how the TOUT10 signal waveform is changed.
#define T16B1CCCTL0_TOUTO       (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x10))).bit.TOUTO       ///< This bit sets the TOUT10 signal output level
#define T16B1CCCTL0_TOUTMT      (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x10))).bit.TOUTMT      ///< This bit selects whether the comparator equal signal.
#define T16B1CCCTL0_CAPTRG      (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x10))).bit.CAPTRG      ///< These bits select the trigger edge(s) of the trigger signal.
#define T16B1CCCTL0_CAPIS       (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x10))).bit.CAPIS       ///< These bits select the trigger signal for capturing.
#define T16B1CCCTL0_CBUFMD      (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x10))).bit.CBUFMD      ///< These bits select the timing to load the comparison value written.
#define T16B1CCCTL0_SCS         (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x10))).bit.SCS         ///< This bit selects either synchronous capture mode or asynchronous capture mode.

/// T16B Ch.1 Compare/Capture 0 Data Register.
#define T16B1CCR0               (*((volatile T16BNCCRM_REG *)(T16B_1_REG_BASE_ADDR + 0x12))).reg
#define T16B1CCR0_CC            (*((volatile T16BNCCRM_REG *)(T16B_1_REG_BASE_ADDR + 0x12))).bit.CC          ///< T16B Ch.1 Compare/Capture 0 Data Register.

/// T16B Ch.1 Comparator/Capture 1 Control Register.
#define T16B1CCCTL1             (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x18))).reg
#define T16B1CCCTL1_CCMD        (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x18))).bit.CCMD        ///< This bit selects the operating mode of the comparator/capture circuit m.
#define T16B1CCCTL1_TOUTINV     (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x18))).bit.TOUTINV     ///< This bit selects the TOUT11 signal polarity.
#define T16B1CCCTL1_TOUTMD      (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x18))).bit.TOUTMD      ///< These bits configure how the TOUT11 signal waveform is changed.
#define T16B1CCCTL1_TOUTO       (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x18))).bit.TOUTO       ///< This bit sets the TOUT11 signal output level
#define T16B1CCCTL1_TOUTMT      (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x18))).bit.TOUTMT      ///< This bit selects whether the comparator equal signal.
#define T16B1CCCTL1_CAPTRG      (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x18))).bit.CAPTRG      ///< These bits select the trigger edge(s) of the trigger signal.
#define T16B1CCCTL1_CAPIS       (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x18))).bit.CAPIS       ///< These bits select the trigger signal for capturing.
#define T16B1CCCTL1_CBUFMD      (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x18))).bit.CBUFMD      ///< These bits select the timing to load the comparison value written.
#define T16B1CCCTL1_SCS         (*((volatile T16BNCCCTLM_REG *)(T16B_1_REG_BASE_ADDR + 0x18))).bit.SCS         ///< This bit selects either synchronous capture mode or asynchronous capture mode.

/// T16B Ch.1 Compare/Capture 1 Data Register.
#define T16B1CCR1               (*((volatile T16BNCCRM_REG *)(T16B_1_REG_BASE_ADDR + 0x1A))).reg
#define T16B1CCR1_CC            (*((volatile T16BNCCRM_REG *)(T16B_1_REG_BASE_ADDR + 0x1A))).bit.CC          ///< T16B Ch.1 Compare/Capture 1 Data Register.

///

/// T16B Ch.2 Clock Control Register
#define T16B2CLK                (*((volatile T16BNCLK_REG *)(T16B_2_REG_BASE_ADDR + 0x00))).reg
#define T16B2CLK_CLKSRC         (*((volatile T16BNCLK_REG *)(T16B_2_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of T16B Ch.2.
#define T16B2CLK_CLKDIV         (*((volatile T16BNCLK_REG *)(T16B_2_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the T16B Ch.2 operating clock (counter clock).

/// This bit sets whether the T16B Ch.2 operating clock is supplied in DEBUG mode or not.
#define T16B2CLK_DBRUN          (*((volatile T16BNCLK_REG *)(T16B_2_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// T16B Ch.2 Counter Control Register.
#define T16B2CTL                (*((volatile T16BNCTL_REG *)(T16B_2_REG_BASE_ADDR + 0x02))).reg
#define T16B2CTL_MODEN          (*((volatile T16BNCTL_REG *)(T16B_2_REG_BASE_ADDR + 0x02))).bit.MODEN       ///< This bit enables the T16B Ch.2 operations.
#define T16B2CTL_PRESET         (*((volatile T16BNCTL_REG *)(T16B_2_REG_BASE_ADDR + 0x02))).bit.PRESET      ///< This bit resets the counter.
#define T16B2CTL_RUN            (*((volatile T16BNCTL_REG *)(T16B_2_REG_BASE_ADDR + 0x02))).bit.RUN         ///< This bit starts/stops counting.
#define T16B2CTL_ONEST          (*((volatile T16BNCTL_REG *)(T16B_2_REG_BASE_ADDR + 0x02))).bit.ONEST       ///< This bit selects the counter repeat/one-shot mode.
#define T16B2CTL_CNTMD          (*((volatile T16BNCTL_REG *)(T16B_2_REG_BASE_ADDR + 0x02))).bit.CNTMD       ///< These bits select the counter up/down mode.

/// This bit indicates whether data can be written to the T16B2MC register or not.
#define T16B2CTL_MAXBSY         (*((volatile T16BNCTL_REG *)(T16B_2_REG_BASE_ADDR + 0x02))).byte_reg[1]

/// T16B Ch.2 Max Counter Data Register
#define T16B2MC                 (*((volatile T16BNMC_REG *)(T16B_2_REG_BASE_ADDR + 0x04))).reg
#define T16B2MC_MC              (*((volatile T16BNMC_REG *)(T16B_2_REG_BASE_ADDR + 0x04))).bit.MC          ///< T16B Ch.2 Max Counter Data Register

/// T16B Ch.2 Timer Counter Data Register.
#define T16B2TC                 (*((volatile T16BNTC_REG *)(T16B_2_REG_BASE_ADDR + 0x06))).reg
#define T16B2TC_TC              (*((volatile T16BNTC_REG *)(T16B_2_REG_BASE_ADDR + 0x06))).bit.TC          ///< T16B Ch.2 Timer Counter Data Register.

/// T16B Ch.2 Counter Status Register
#define T16B2CS                 (*((volatile T16BNCS_REG *)(T16B_2_REG_BASE_ADDR + 0x08))).reg
#define T16B2CS_BSY             (*((volatile T16BNCS_REG *)(T16B_2_REG_BASE_ADDR + 0x08))).bit.BSY         ///< This bit indicates the counter operating status.
#define T16B2CS_UP_DOWN         (*((volatile T16BNCS_REG *)(T16B_2_REG_BASE_ADDR + 0x08))).bit.UP_DOWN     ///< This bit indicates the currently set count direction.
#define T16B2CS_CAPI0           (*((volatile T16BNCS_REG *)(T16B_2_REG_BASE_ADDR + 0x08))).bit.CAPI0       ///< This bit indicate the signal level currently input to the CAPx0 pin.
#define T16B2CS_CAPI1           (*((volatile T16BNCS_REG *)(T16B_2_REG_BASE_ADDR + 0x08))).bit.CAPI1       ///< This bit indicate the signal level currently input to the CAPx1 pin.
#define T16B2CS_CAPI2           (*((volatile T16BNCS_REG *)(T16B_2_REG_BASE_ADDR + 0x08))).bit.CAPI2       ///< This bit indicate the signal level currently input to the CAPx2 pin.
#define T16B2CS_CAPI3           (*((volatile T16BNCS_REG *)(T16B_2_REG_BASE_ADDR + 0x08))).bit.CAPI3       ///< This bit indicate the signal level currently input to the CAPx3 pin.
#define T16B2CS_CAPI4           (*((volatile T16BNCS_REG *)(T16B_2_REG_BASE_ADDR + 0x08))).bit.CAPI4       ///< This bit indicate the signal level currently input to the CAPx4 pin.
#define T16B2CS_CAPI5           (*((volatile T16BNCS_REG *)(T16B_2_REG_BASE_ADDR + 0x08))).bit.CAPI5       ///< This bit indicate the signal level currently input to the CAPx5 pin.

/// T16B Ch.2 Interrupt Flag Register.
#define T16B2INTF               (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).reg
#define T16B2INTF_CNTZEROIF     (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).bit.CNTZEROIF   ///< Counter zero interrupt
#define T16B2INTF_CNTMAXIF      (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).bit.CNTMAXIF    ///< Counter MAX interrupt
#define T16B2INTF_CMPCAP0IF     (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).bit.CMPCAP0IF   ///< Compare/capture 0 interrupt
#define T16B2INTF_CAPOW0IF      (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).bit.CAPOW0IF    ///< Capture 0 overwrite interrupt
#define T16B2INTF_CMPCAP1IF     (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).bit.CMPCAP1IF   ///< Compare/capture 1 interrupt
#define T16B2INTF_CAPOW1IF      (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).bit.CAPOW1IF    ///< Capture 1 overwrite interrupt
#define T16B2INTF_CMPCAP2IF     (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).bit.CMPCAP2IF   ///< This bit indicate the Compare/capture 2 interrupt cause occurrence status.
#define T16B2INTF_CAPOW2IF      (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).bit.CAPOW2IF    ///< This bit indicate the Capture 2 overwrite interrupt cause occurrence status.
#define T16B2INTF_CMPCAP3IF     (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).bit.CMPCAP3IF   ///< This bit indicate the Compare/capture 3 interrupt cause occurrence status.
#define T16B2INTF_CAPOW3IF      (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).bit.CAPOW3IF    ///< This bit indicate the Capture 3 overwrite interrupt cause occurrence status.
#define T16B2INTF_CMPCAP4IF     (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).bit.CMPCAP4IF   ///< This bit indicate the Compare/capture 4 interrupt cause occurrence status.
#define T16B2INTF_CAPOW4IF      (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).bit.CAPOW4IF    ///< This bit indicate the Capture 4 overwrite interrupt cause occurrence status.
#define T16B2INTF_CMPCAP5IF     (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).bit.CMPCAP5IF   ///< This bit indicate the Compare/capture 5 interrupt cause occurrence status.
#define T16B2INTF_CAPOW5IF      (*((volatile T16BNINTF_REG *)(T16B_2_REG_BASE_ADDR + 0x0A))).bit.CAPOW5IF    ///< This bit indicate the Capture 5 overwrite interrupt cause occurrence status.

/// T16B Ch.2 Interrupt Enable Register.
#define T16B2INTE               (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).reg
#define T16B2INTE_CNTZEROIE     (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).bit.CNTZEROIE   ///< Counter zero interrupt
#define T16B2INTE_CNTMAXIE      (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).bit.CNTMAXIE    ///< Counter MAX interrupt
#define T16B2INTE_CMPCAP0IE     (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).bit.CMPCAP0IE   ///< Compare/capture 0 interrupt
#define T16B2INTE_CAPOW0IE      (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).bit.CAPOW0IE    ///< Capture 0 overwrite interrupt
#define T16B2INTE_CMPCAP1IE     (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).bit.CMPCAP1IE   ///< Compare/capture 1 interrupt
#define T16B2INTE_CAPOW1IE      (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).bit.CAPOW1IE    ///< Capture 1 overwrite interrupt
#define T16B2INTE_CMPCAP2IE     (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).bit.CMPCAP2IE   ///< This bit enable Compare/capture 2 interrupt interrupts.
#define T16B2INTE_CAPOW2IE      (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).bit.CAPOW2IE    ///< This bit enable Capture 2 overwrite interrupt.
#define T16B2INTE_CMPCAP3IE     (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).bit.CMPCAP3IE   ///< This bit enable Compare/capture 3 interrupt interrupts.
#define T16B2INTE_CAPOW3IE      (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).bit.CAPOW3IE    ///< This bit enable Capture 3 overwrite interrupt.
#define T16B2INTE_CMPCAP4IE     (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).bit.CMPCAP4IE   ///< This bit enable Compare/capture 4 interrupt interrupts.
#define T16B2INTE_CAPOW4IE      (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).bit.CAPOW4IE    ///< This bit enable Capture 4 overwrite interrupt.
#define T16B2INTE_CMPCAP5IE     (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).bit.CMPCAP5IE   ///< This bit enable Compare/capture 5 interrupt interrupts.
#define T16B2INTE_CAPOW5IE      (*((volatile T16BNINTE_REG *)(T16B_2_REG_BASE_ADDR + 0x0C))).bit.CAPOW5IE    ///< This bit enable Capture 5 overwrite interrupt.

/// T16B Ch.2 Comparator/Capture 0 Control Register.
#define T16B2CCCTL0             (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x10))).reg
#define T16B2CCCTL0_CCMD        (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x10))).bit.CCMD        ///< This bit selects the operating mode of the comparator/capture circuit m.
#define T16B2CCCTL0_TOUTINV     (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x10))).bit.TOUTINV     ///< This bit selects the TOUT20 signal polarity.
#define T16B2CCCTL0_TOUTMD      (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x10))).bit.TOUTMD      ///< These bits configure how the TOUT10 signal waveform is changed.
#define T16B2CCCTL0_TOUTO       (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x10))).bit.TOUTO       ///< This bit sets the TOUT20 signal output level
#define T16B2CCCTL0_TOUTMT      (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x10))).bit.TOUTMT      ///< This bit selects whether the comparator equal signal.
#define T16B2CCCTL0_CAPTRG      (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x10))).bit.CAPTRG      ///< These bits select the trigger edge(s) of the trigger signal.
#define T16B2CCCTL0_CAPIS       (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x10))).bit.CAPIS       ///< These bits select the trigger signal for capturing.
#define T16B2CCCTL0_CBUFMD      (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x10))).bit.CBUFMD      ///< These bits select the timing to load the comparison value written.
#define T16B2CCCTL0_SCS         (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x10))).bit.SCS         ///< This bit selects either synchronous capture mode or asynchronous capture mode.

/// T16B Ch.2 Compare/Capture 0 Data Register.
#define T16B2CCR0               (*((volatile T16BNCCRM_REG *)(T16B_2_REG_BASE_ADDR + 0x12))).reg
#define T16B2CCR0_CC            (*((volatile T16BNCCRM_REG *)(T16B_2_REG_BASE_ADDR + 0x12))).bit.CC          ///< T16B Ch.2 Compare/Capture 0 Data Register.

/// T16B Ch.2 Comparator/Capture 1 Control Register.
#define T16B2CCCTL1             (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x18))).reg
#define T16B2CCCTL1_CCMD        (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x18))).bit.CCMD        ///< This bit selects the operating mode of the comparator/capture circuit m.
#define T16B2CCCTL1_TOUTINV     (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x18))).bit.TOUTINV     ///< This bit selects the TOUT21 signal polarity.
#define T16B2CCCTL1_TOUTMD      (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x18))).bit.TOUTMD      ///< These bits configure how the TOUT11 signal waveform is changed.
#define T16B2CCCTL1_TOUTO       (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x18))).bit.TOUTO       ///< This bit sets the TOUT21 signal output level
#define T16B2CCCTL1_TOUTMT      (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x18))).bit.TOUTMT      ///< This bit selects whether the comparator equal signal.
#define T16B2CCCTL1_CAPTRG      (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x18))).bit.CAPTRG      ///< These bits select the trigger edge(s) of the trigger signal.
#define T16B2CCCTL1_CAPIS       (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x18))).bit.CAPIS       ///< These bits select the trigger signal for capturing.
#define T16B2CCCTL1_CBUFMD      (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x18))).bit.CBUFMD      ///< These bits select the timing to load the comparison value written.
#define T16B2CCCTL1_SCS         (*((volatile T16BNCCCTLM_REG *)(T16B_2_REG_BASE_ADDR + 0x18))).bit.SCS         ///< This bit selects either synchronous capture mode or asynchronous capture mode.

/// T16B Ch.2 Compare/Capture 1 Data Register.
#define T16B2CCR1               (*((volatile T16BNCCRM_REG *)(T16B_2_REG_BASE_ADDR + 0x1A))).reg
#define T16B2CCR1_CC            (*((volatile T16BNCCRM_REG *)(T16B_2_REG_BASE_ADDR + 0x1A))).bit.CC          ///< T16B Ch.2 Compare/Capture 1 Data Register.

/// ----- SNDA ------

/// SNDA Clock Control Register
#define SNDCLK                  (*((volatile SNDCLK_REG *)(SNDA_REG_BASE_ADDR + 0x00))).reg
#define SNDCLK_CLKSRC           (*((volatile SNDCLK_REG *)(SNDA_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of SNDA.
#define SNDCLK_CLKDIV           (*((volatile SNDCLK_REG *)(SNDA_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the SNDA operating clock.

/// This bit sets whether the SNDA operating clock is supplied in DEBUG mode or not.
#define SNDCLK_DBRUN            (*((volatile SNDCLK_REG *)(SNDA_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// SNDA Select Register
#define SNDSEL                  (*((volatile SNDSEL_REG *)(SNDA_REG_BASE_ADDR + 0x02))).reg
#define SNDSEL_MOSEL            (*((volatile SNDSEL_REG *)(SNDA_REG_BASE_ADDR + 0x02))).bit.MOSEL       ///< These bits select a sound output mode.
#define SNDSEL_SINV             (*((volatile SNDSEL_REG *)(SNDA_REG_BASE_ADDR + 0x02))).bit.SINV        ///< This bit selects an output pin drive mode.

/// These bits select a tempo or a one-shot buzzer output duration.
#define SNDSEL_STIM             (*((volatile SNDSEL_REG *)(SNDA_REG_BASE_ADDR + 0x02))).byte_reg[1]

/// SNDA Control Register
#define SNDCTL                  (*((volatile SNDCTL_REG *)(SNDA_REG_BASE_ADDR + 0x04))).reg

/// This bit enables the SNDA operations.
#define SNDCTL_MODEN            (*((volatile SNDCTL_REG *)(SNDA_REG_BASE_ADDR + 0x04))).byte_reg[0]

/// This bit stops sound output.
#define SNDCTL_SSTP             (*((volatile SNDCTL_REG *)(SNDA_REG_BASE_ADDR + 0x04))).byte_reg[1]

/// SNDA Data Register
#define SNDDAT                  (*((volatile SNDDAT_REG *)(SNDA_REG_BASE_ADDR + 0x06))).reg
#define SNDDAT_SLEN             (*((volatile SNDDAT_REG *)(SNDA_REG_BASE_ADDR + 0x06))).bit.SLEN        ///< These bits select a duration or a buzzer signal duty ratio.
#define SNDDAT_MDRS             (*((volatile SNDDAT_REG *)(SNDA_REG_BASE_ADDR + 0x06))).bit.MDRS        ///< This bit selects the output type in melody mode from a note or a rest.
#define SNDDAT_MDTI             (*((volatile SNDDAT_REG *)(SNDA_REG_BASE_ADDR + 0x06))).bit.MDTI        ///< This bit specifies a tie or slur (continuous play with the previous note) in melody mode.

/// These bits select a scale or a buzzer signal frequency.
#define SNDDAT_SFRQ             (*((volatile SNDDAT_REG *)(SNDA_REG_BASE_ADDR + 0x06))).byte_reg[0]

/// SNDA Interrupt Flag Register
#define SNDINTF                 (*((volatile SNDINTF_REG *)(SNDA_REG_BASE_ADDR + 0x08))).reg
#define SNDINTF_EDIF            (*((volatile SNDINTF_REG *)(SNDA_REG_BASE_ADDR + 0x08))).bit.EDIF        ///< Sound buffer empty interrupt status.
#define SNDINTF_EMIF            (*((volatile SNDINTF_REG *)(SNDA_REG_BASE_ADDR + 0x08))).bit.EMIF        ///< Sound output completion interrupt status.

/// This bit indicates the sound output status.
#define SNDINTF_SBSY            (*((volatile SNDINTF_REG *)(SNDA_REG_BASE_ADDR + 0x08))).byte_reg[1]

/// SNDA Interrupt Enable Register
#define SNDINTE                 (*((volatile SNDINTE_REG *)(SNDA_REG_BASE_ADDR + 0x0A))).reg
#define SNDINTE_EDIE            (*((volatile SNDINTE_REG *)(SNDA_REG_BASE_ADDR + 0x0A))).bit.EDIE        ///< Sound output completion interrupt.
#define SNDINTE_EMIE            (*((volatile SNDINTE_REG *)(SNDA_REG_BASE_ADDR + 0x0A))).bit.EMIE        ///< Sound buffer empty interrupt.

/// ----- REMC3 ------

/// REMC3 Clock Control Register.
#define REMCLK                  (*((volatile REMCLK_REG *)(REMC3_REG_BASE_ADDR + 0x00))).reg
#define REMCLK_CLKSRC           (*((volatile REMCLK_REG *)(REMC3_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of the REMC3.
#define REMCLK_CLKDIV           (*((volatile REMCLK_REG *)(REMC3_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the REMC3 operating clock.

/// This bit sets whether the remc operating clock is supplied in DEBUG mode or not.
#define REMCLK_DBRUN            (*((volatile REMCLK_REG *)(REMC3_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// remc Data Bit Counter Control Register.
#define REMDBCTL                (*((volatile REMDBCTL_REG *)(REMC3_REG_BASE_ADDR + 0x02))).reg
#define REMDBCTL_MODEN          (*((volatile REMDBCTL_REG *)(REMC3_REG_BASE_ADDR + 0x02))).bit.MODEN       ///< This bit enables the REMC3 operations.
#define REMDBCTL_REMCRST        (*((volatile REMDBCTL_REG *)(REMC3_REG_BASE_ADDR + 0x02))).bit.REMCRST     ///< This bit issues software reset to the REMC3.
#define REMDBCTL_TRMD           (*((volatile REMDBCTL_REG *)(REMC3_REG_BASE_ADDR + 0x02))).bit.TRMD        ///< This bit selects the operation mode of the 16-bit counter for data signal generation.
#define REMDBCTL_BUFEN          (*((volatile REMDBCTL_REG *)(REMC3_REG_BASE_ADDR + 0x02))).bit.BUFEN       ///< This bit enables or disables the compare buffers.
#define REMDBCTL_REMOINV        (*((volatile REMDBCTL_REG *)(REMC3_REG_BASE_ADDR + 0x02))).bit.REMOINV     ///< This bit inverts the REMO output signal.
#define REMDBCTL_PRUN           (*((volatile REMDBCTL_REG *)(REMC3_REG_BASE_ADDR + 0x02))).bit.PRUN        ///< This bit starts/stops counting by the internal counters.
#define REMDBCTL_PRESET         (*((volatile REMDBCTL_REG *)(REMC3_REG_BASE_ADDR + 0x02))).bit.PRESET      ///< This bit resets the internal counters.

/// REMC3 Data Bit Counter Register.
#define REMDBCNT                (*((volatile REMDBCNT_REG *)(REMC3_REG_BASE_ADDR + 0x04))).reg
#define REMDBCNT_DBCNT          (*((volatile REMDBCNT_REG *)(REMC3_REG_BASE_ADDR + 0x04))).bit.DBCNT       ///< REMC3 Data Bit Counter Register.

/// REMC3 Data Bit Active Pulse Length Register.
#define REMAPLEN                (*((volatile REMAPLEN_REG *)(REMC3_REG_BASE_ADDR + 0x06))).reg
#define REMAPLEN_APLEN          (*((volatile REMAPLEN_REG *)(REMC3_REG_BASE_ADDR + 0x06))).bit.APLEN       ///< REMC3 Data Bit Active Pulse Length Register.

/// REMC3 Data Bit Length Register.
#define REMDBLEN                (*((volatile REMDBLEN_REG *)(REMC3_REG_BASE_ADDR + 0x08))).reg
#define REMDBLEN_DBLEN          (*((volatile REMDBLEN_REG *)(REMC3_REG_BASE_ADDR + 0x08))).bit.DBLEN       ///< REMC3 Data Bit Length Register.

/// REMC3 Status and Interrupt Flag Register.
#define REMINTF                 (*((volatile REMINTF_REG *)(REMC3_REG_BASE_ADDR + 0x0A))).reg
#define REMINTF_APIF            (*((volatile REMINTF_REG *)(REMC3_REG_BASE_ADDR + 0x0A))).bit.APIF        ///< This bit indicate the REMC3 Compare AP interrupt cause occurrence status.
#define REMINTF_DBIF            (*((volatile REMINTF_REG *)(REMC3_REG_BASE_ADDR + 0x0A))).bit.DBIF        ///< This bit indicate the REMC3 Compare DB interrupt cause occurrence status.
#define REMINTF_APLENBSY        (*((volatile REMINTF_REG *)(REMC3_REG_BASE_ADDR + 0x0A))).bit.APLENBSY    ///< This bit indicates whether a compare match occurs by the REMAPLEN buffer or not.
#define REMINTF_DBLENBSY        (*((volatile REMINTF_REG *)(REMC3_REG_BASE_ADDR + 0x0A))).bit.DBLENBSY    ///< This bit indicates whether a compare match occurs by the REMDBLEN buffer or not.
#define REMINTF_DBCNTRUN        (*((volatile REMINTF_REG *)(REMC3_REG_BASE_ADDR + 0x0A))).bit.DBCNTRUN    ///< This bit indicates whether the 16-bit counter for data signal generation is running or not.

/// REMC3 Interrupt Enable Register.
#define REMINTE                 (*((volatile REMINTE_REG *)(REMC3_REG_BASE_ADDR + 0x0C))).reg
#define REMINTE_APIE            (*((volatile REMINTE_REG *)(REMC3_REG_BASE_ADDR + 0x0C))).bit.APIE        ///< This bit enable REMC3 Compare AP interrupt.
#define REMINTE_DBIE            (*((volatile REMINTE_REG *)(REMC3_REG_BASE_ADDR + 0x0C))).bit.DBIE        ///< This bit enable REMC3 Compare DB interrupt.

/// REMC3 Carrier Waveform Register.
#define REMCARR                 (*((volatile REMCARR_REG *)(REMC3_REG_BASE_ADDR + 0x10))).reg

/// These bits set the carrier signal cycle.
#define REMCARR_CRPER           (*((volatile REMCARR_REG *)(REMC3_REG_BASE_ADDR + 0x10))).byte_reg[0]

/// These bits set the high level period of the carrier signal.
#define REMCARR_CRDTY           (*((volatile REMCARR_REG *)(REMC3_REG_BASE_ADDR + 0x10))).byte_reg[1]

/// REMC3 Carrier Modulation Control Register.
#define REMCCTL                 (*((volatile REMCCTL_REG *)(REMC3_REG_BASE_ADDR + 0x12))).reg
#define REMCCTL_CARREN          (*((volatile REMCCTL_REG *)(REMC3_REG_BASE_ADDR + 0x12))).bit.CARREN      ///< REMC3 Carrier Modulation Control Register.
#define REMCCTL_OUTINVEN        (*((volatile REMCCTL_REG *)(REMC3_REG_BASE_ADDR + 0x12))).bit.OUTINVEN    ///< This bit inverts the REMO output polarity.

/// ----- LCD8A -----

/// LCD8A Clock Control Register
#define LCD8CLK                 (*((volatile LCD8CLK_REG *)(LCD8A_REG_BASE_ADDR + 0x00))).reg
#define LCD8CLK_CLKSRC          (*((volatile LCD8CLK_REG *)(LCD8A_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of the LCD8A.
#define LCD8CLK_CLKDIV          (*((volatile LCD8CLK_REG *)(LCD8A_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the LCD8A operating clock.

/// This bit sets whether the LCD8A operating clock is supplied in DEBUG mode or not.
#define LCD8CLK_DBRUN           (*((volatile LCD8CLK_REG *)(LCD8A_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// LCD8A Control Register
#define LCD8CTL                 (*((volatile LCD8CTL_REG *)(LCD8A_REG_BASE_ADDR + 0x02))).reg
#define LCD8CTL_MODEN           (*((volatile LCD8CTL_REG *)(LCD8A_REG_BASE_ADDR + 0x02))).bit.MODEN       ///< This bit enables the LCD8A operations.
#define LCD8CTL_LCDDIS          (*((volatile LCD8CTL_REG *)(LCD8A_REG_BASE_ADDR + 0x02))).bit.LCDDIS      ///< This bit enables the SEG/COM-pin discharge operations.

/// LCD8A Timing Control Register 1
#define LCD8TIM1                (*((volatile LCD8TIM1_REG *)(LCD8A_REG_BASE_ADDR + 0x04))).reg
#define LCD8TIM1_LDUTY          (*((volatile LCD8TIM1_REG *)(LCD8A_REG_BASE_ADDR + 0x04))).bit.LDUTY       ///< These bits set the drive duty.
#define LCD8TIM1_FRMCNT         (*((volatile LCD8TIM1_REG *)(LCD8A_REG_BASE_ADDR + 0x04))).bit.FRMCNT      ///< These bits set the frame frequency.

/// LCD8A Timing Control Register 2
#define LCD8TIM2                (*((volatile LCD8TIM2_REG *)(LCD8A_REG_BASE_ADDR + 0x06))).reg
#define LCD8TIM2_NLINE          (*((volatile LCD8TIM2_REG *)(LCD8A_REG_BASE_ADDR + 0x06))).bit.NLINE       ///< These bits enable the n-line inverse AC drive function and set the number of inverse lines.

/// LCD8A Power Control Register
#define LCD8PWR                 (*((volatile LCD8PWR_REG *)(LCD8A_REG_BASE_ADDR + 0x08))).reg
#define LCD8PWR_EXVCSEL         (*((volatile LCD8PWR_REG *)(LCD8A_REG_BASE_ADDR + 0x08))).bit.EXVCSEL     ///< This bit selects the LCD drive power supply mode.

/// LCD8A Display Control Register
#define LCD8DSP                 (*((volatile LCD8DSP_REG *)(LCD8A_REG_BASE_ADDR + 0x0A))).reg
#define LCD8DSP_DSPC            (*((volatile LCD8DSP_REG *)(LCD8A_REG_BASE_ADDR + 0x0A))).bit.DSPC        ///< These bits control the LCD display on/off and select a display mode
#define LCD8DSP_DSPAR           (*((volatile LCD8DSP_REG *)(LCD8A_REG_BASE_ADDR + 0x0A))).bit.DSPAR       ///< This bit switches the display area in the display data RAM.
#define LCD8DSP_DSPREV          (*((volatile LCD8DSP_REG *)(LCD8A_REG_BASE_ADDR + 0x0A))).bit.DSPREV      ///< This bit controls black/white inversion on the LCD display.
#define LCD8DSP_COMREV          (*((volatile LCD8DSP_REG *)(LCD8A_REG_BASE_ADDR + 0x0A))).bit.COMREV      ///< This bit selects the common pin assignment direction.
#define LCD8DSP_SEGREV          (*((volatile LCD8DSP_REG *)(LCD8A_REG_BASE_ADDR + 0x0A))).bit.SEGREV      ///< This bit selects the segment pin assignment direction.

/// LCD8A COM Pin Control Register 0
#define LCD8COMC0               (*((volatile LCD8COMC0_REG *)(LCD8A_REG_BASE_ADDR + 0x0C))).reg
#define LCD8COMC0_COM0DEN       (*((volatile LCD8COMC0_REG *)(LCD8A_REG_BASE_ADDR + 0x0C))).bit.COM0DEN     ///< These bits configure the partial drive of the COM0 pins.
#define LCD8COMC0_COM1DEN       (*((volatile LCD8COMC0_REG *)(LCD8A_REG_BASE_ADDR + 0x0C))).bit.COM1DEN     ///< These bits configure the partial drive of the COM1 pins.
#define LCD8COMC0_COM2DEN       (*((volatile LCD8COMC0_REG *)(LCD8A_REG_BASE_ADDR + 0x0C))).bit.COM2DEN     ///< These bits configure the partial drive of the COM2 pins.
#define LCD8COMC0_COM3DEN       (*((volatile LCD8COMC0_REG *)(LCD8A_REG_BASE_ADDR + 0x0C))).bit.COM3DEN     ///< These bits configure the partial drive of the COM3 pins.
#define LCD8COMC0_COM4DEN       (*((volatile LCD8COMC0_REG *)(LCD8A_REG_BASE_ADDR + 0x0C))).bit.COM4DEN     ///< These bits configure the partial drive of the COM4 pins.
#define LCD8COMC0_COM5DEN       (*((volatile LCD8COMC0_REG *)(LCD8A_REG_BASE_ADDR + 0x0C))).bit.COM5DEN     ///< These bits configure the partial drive of the COM5 pins.
#define LCD8COMC0_COM6DEN       (*((volatile LCD8COMC0_REG *)(LCD8A_REG_BASE_ADDR + 0x0C))).bit.COM6DEN     ///< These bits configure the partial drive of the COM6 pins.
#define LCD8COMC0_COM7DEN       (*((volatile LCD8COMC0_REG *)(LCD8A_REG_BASE_ADDR + 0x0C))).bit.COM7DEN     ///< These bits configure the partial drive of the COM7 pins.

/// LCD8A Interrupt Flag Register
#define LCD8INTF                (*((volatile LCD8INTF_REG *)(LCD8A_REG_BASE_ADDR + 0x10))).reg
#define LCD8INTF_FRMIF          (*((volatile LCD8INTF_REG *)(LCD8A_REG_BASE_ADDR + 0x10))).bit.FRMIF       ///< This bit indicates the frame interrupt cause occurrence status.

/// LCD8A Interrupt Enable Register
#define LCD8INTE                (*((volatile LCD8INTE_REG *)(LCD8A_REG_BASE_ADDR + 0x12))).reg
#define LCD8INTE_FRMIE          (*((volatile LCD8INTE_REG *)(LCD8A_REG_BASE_ADDR + 0x12))).bit.FRMIE       ///< This bit enables the frame interrupt.

/// ----- RFC ------

/// RFC Ch.0 Clock Control Register
#define RFC0CLK                 (*((volatile RFCNCLK_REG *)(RFC_0_REG_BASE_ADDR + 0x00))).reg
#define RFC0CLK_CLKSRC          (*((volatile RFCNCLK_REG *)(RFC_0_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of the RFC.
#define RFC0CLK_CLKDIV          (*((volatile RFCNCLK_REG *)(RFC_0_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the RFC operating clock.

/// This bit sets whether the RFC operating clock is supplied in DEBUG mode or not.
#define RFC0CLK_DBRUN           (*((volatile RFCNCLK_REG *)(RFC_0_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// RFC Ch.0 Control Register
#define RFC0CTL                 (*((volatile RFCNCTL_REG *)(RFC_0_REG_BASE_ADDR + 0x02))).reg
#define RFC0CTL_MODEN           (*((volatile RFCNCTL_REG *)(RFC_0_REG_BASE_ADDR + 0x02))).bit.MODEN       ///< This bit enables the RFC operations.
#define RFC0CTL_SMODE           (*((volatile RFCNCTL_REG *)(RFC_0_REG_BASE_ADDR + 0x02))).bit.SMODE       ///< These bits configure the oscillation mode.
#define RFC0CTL_EVTEN           (*((volatile RFCNCTL_REG *)(RFC_0_REG_BASE_ADDR + 0x02))).bit.EVTEN       ///< This bit enables external clock input mode (event counter mode).
#define RFC0CTL_CONEN           (*((volatile RFCNCTL_REG *)(RFC_0_REG_BASE_ADDR + 0x02))).bit.CONEN       ///< This bit disables the automatic CR oscillation stop function to enable continuous oscillation function.

/// This bit sets the RFCLKOn pin to output the divided-by-two oscillation clock.
#define RFC0CTL_RFCLKMD         (*((volatile RFCNCTL_REG *)(RFC_0_REG_BASE_ADDR + 0x02))).byte_reg[1]

/// RFC Ch.0 Oscillation Trigger Register
#define RFC0TRG                 (*((volatile RFCNTRG_REG *)(RFC_0_REG_BASE_ADDR + 0x04))).reg
#define RFC0TRG_SREF            (*((volatile RFCNTRG_REG *)(RFC_0_REG_BASE_ADDR + 0x04))).bit.SREF        ///< This bit controls CR oscillation for the reference resistor. This bit also indicates the CR oscillation status.
#define RFC0TRG_SSENA           (*((volatile RFCNTRG_REG *)(RFC_0_REG_BASE_ADDR + 0x04))).bit.SSENA       ///< This bit controls CR oscillation for sensor A. This bit also indicates the CR oscillation status.
#define RFC0TRG_SSENB           (*((volatile RFCNTRG_REG *)(RFC_0_REG_BASE_ADDR + 0x04))).bit.SSENB       ///< This bit controls CR oscillation for sensor B. This bit also indicates the CR oscillation status.

/// RFC Ch.0 Measurement Counter Low Register
#define RFC0MCL                 (*((volatile RFCNMCL_REG *)(RFC_0_REG_BASE_ADDR + 0x06))).reg
#define RFC0MCL_MC              (*((volatile RFCNMCL_REG *)(RFC_0_REG_BASE_ADDR + 0x06))).bit.MC          ///< Measurement counter data can be read and written through these bits.

/// RFC Ch.0 Measurement Counter High Register
#define RFC0MCH                 (*((volatile RFCNMCH_REG *)(RFC_0_REG_BASE_ADDR + 0x08))).reg
#define RFC0MCH_MC              (*((volatile RFCNMCH_REG *)(RFC_0_REG_BASE_ADDR + 0x08))).bit.MC          ///< Measurement counter data can be read and written through these bits.

/// Measurement counter data can be read and written through these bits.
#define RFC0MC                  (*((volatile RFCNMC_DWORD_REG *)(RFC_0_REG_BASE_ADDR + 0x06))).reg

/// RFC Ch.0 Time Base Counter Low Register
#define RFC0TCL                 (*((volatile RFCNTCL_REG *)(RFC_0_REG_BASE_ADDR + 0x0A))).reg
#define RFC0TCL_TC              (*((volatile RFCNTCL_REG *)(RFC_0_REG_BASE_ADDR + 0x0A))).bit.TC          ///< Time base counter data can be read and written through these bits.

/// RFC Ch.0 Time Base Counter High Register
#define RFC0TCH                 (*((volatile RFCNTCH_REG *)(RFC_0_REG_BASE_ADDR + 0x0C))).reg
#define RFC0TCH_TC              (*((volatile RFCNTCH_REG *)(RFC_0_REG_BASE_ADDR + 0x0C))).bit.TC          ///< Time base counter data can be read and written through these bits.

/// Time base counter data can be read and written through these bits.
#define RFC0TC                  (*((volatile RFCNTC_DWORD_REG *)(RFC_0_REG_BASE_ADDR + 0x0A))).reg

/// RFC Ch.0 Interrupt Flag Register
#define RFC0INTF                (*((volatile RFCNINTF_REG *)(RFC_0_REG_BASE_ADDR + 0x0E))).reg
#define RFC0INTF_EREFIF         (*((volatile RFCNINTF_REG *)(RFC_0_REG_BASE_ADDR + 0x0E))).bit.EREFIF      ///< This bit indicate Reference oscillation completion interrupt cause occurrence status.
#define RFC0INTF_ESENAIF        (*((volatile RFCNINTF_REG *)(RFC_0_REG_BASE_ADDR + 0x0E))).bit.ESENAIF     ///< This bit indicate Sensor B oscillation completion interrupt cause occurrence status.
#define RFC0INTF_ESENBIF        (*((volatile RFCNINTF_REG *)(RFC_0_REG_BASE_ADDR + 0x0E))).bit.ESENBIF     ///< This bit indicate Sensor B oscillation completion interrupt cause occurrence status.
#define RFC0INTF_OVMCIF         (*((volatile RFCNINTF_REG *)(RFC_0_REG_BASE_ADDR + 0x0E))).bit.OVMCIF      ///< This bit indicate Measurement counter overflow error interrupt cause occurrence status.
#define RFC0INTF_OVTCIF         (*((volatile RFCNINTF_REG *)(RFC_0_REG_BASE_ADDR + 0x0E))).bit.OVTCIF      ///< This bit indicate Time base counter overflow error interrupt cause occurrence status.

/// RFC Ch.0 Interrupt Enable Register
#define RFC0INTE                (*((volatile RFCNINTE_REG *)(RFC_0_REG_BASE_ADDR + 0x10))).reg
#define RFC0INTE_EREFIE         (*((volatile RFCNINTE_REG *)(RFC_0_REG_BASE_ADDR + 0x10))).bit.EREFIE      ///< This bit enable Reference oscillation completion interrupt.
#define RFC0INTE_ESENAIE        (*((volatile RFCNINTE_REG *)(RFC_0_REG_BASE_ADDR + 0x10))).bit.ESENAIE     ///< This bit enable Sensor A oscillation completion interrupt.
#define RFC0INTE_ESENBIE        (*((volatile RFCNINTE_REG *)(RFC_0_REG_BASE_ADDR + 0x10))).bit.ESENBIE     ///< This bit enable Sensor B oscillation completion interrupt.
#define RFC0INTE_OVMCIE         (*((volatile RFCNINTE_REG *)(RFC_0_REG_BASE_ADDR + 0x10))).bit.OVMCIE      ///< This bit enable Measurement counter overflow error interrupt.
#define RFC0INTE_OVTCIE         (*((volatile RFCNINTE_REG *)(RFC_0_REG_BASE_ADDR + 0x10))).bit.OVTCIE      ///< This bit enable Time base counter overflow error interrupt.

/// RFC Ch.1 Interrupt Enable Register

/// RFC Ch.1 Clock Control Register
#define RFC1CLK                 (*((volatile RFCNCLK_REG *)(RFC_1_REG_BASE_ADDR + 0x00))).reg
#define RFC1CLK_CLKSRC          (*((volatile RFCNCLK_REG *)(RFC_1_REG_BASE_ADDR + 0x00))).bit.CLKSRC      ///< These bits select the clock source of the RFC.
#define RFC1CLK_CLKDIV          (*((volatile RFCNCLK_REG *)(RFC_1_REG_BASE_ADDR + 0x00))).bit.CLKDIV      ///< These bits select the division ratio of the RFC operating clock.

/// This bit sets whether the RFC operating clock is supplied in DEBUG mode or not.
#define RFC1CLK_DBRUN           (*((volatile RFCNCLK_REG *)(RFC_1_REG_BASE_ADDR + 0x00))).byte_reg[1]

/// RFC Ch.1 Control Register
#define RFC1CTL                 (*((volatile RFCNCTL_REG *)(RFC_1_REG_BASE_ADDR + 0x02))).reg
#define RFC1CTL_MODEN           (*((volatile RFCNCTL_REG *)(RFC_1_REG_BASE_ADDR + 0x02))).bit.MODEN       ///< This bit enables the RFC operations.
#define RFC1CTL_SMODE           (*((volatile RFCNCTL_REG *)(RFC_1_REG_BASE_ADDR + 0x02))).bit.SMODE       ///< These bits configure the oscillation mode.
#define RFC1CTL_EVTEN           (*((volatile RFCNCTL_REG *)(RFC_1_REG_BASE_ADDR + 0x02))).bit.EVTEN       ///< This bit enables external clock input mode (event counter mode).
#define RFC1CTL_CONEN           (*((volatile RFCNCTL_REG *)(RFC_1_REG_BASE_ADDR + 0x02))).bit.CONEN       ///< This bit disables the automatic CR oscillation stop function to enable continuous oscillation function.

/// This bit sets the RFCLKOn pin to output the divided-by-two oscillation clock.
#define RFC1CTL_RFCLKMD         (*((volatile RFCNCTL_REG *)(RFC_1_REG_BASE_ADDR + 0x02))).byte_reg[1]

/// RFC Ch.1 Oscillation Trigger Register
#define RFC1TRG                 (*((volatile RFCNTRG_REG *)(RFC_1_REG_BASE_ADDR + 0x04))).reg
#define RFC1TRG_SREF            (*((volatile RFCNTRG_REG *)(RFC_1_REG_BASE_ADDR + 0x04))).bit.SREF        ///< This bit controls CR oscillation for the reference resistor.
#define RFC1TRG_SSENA           (*((volatile RFCNTRG_REG *)(RFC_1_REG_BASE_ADDR + 0x04))).bit.SSENA       ///< This bit controls CR oscillation for sensor A.
#define RFC1TRG_SSENB           (*((volatile RFCNTRG_REG *)(RFC_1_REG_BASE_ADDR + 0x04))).bit.SSENB       ///< This bit controls CR oscillation for sensor B.

/// RFC Ch.1 Measurement Counter Low Register
#define RFC1MCL                 (*((volatile RFCNMCL_REG *)(RFC_1_REG_BASE_ADDR + 0x06))).reg
#define RFC1MCL_MC              (*((volatile RFCNMCL_REG *)(RFC_1_REG_BASE_ADDR + 0x06))).bit.MC          ///< Measurement counter data can be read and written through these bits.

/// RFC Ch.1 Measurement Counter High Register
#define RFC1MCH                 (*((volatile RFCNMCH_REG *)(RFC_1_REG_BASE_ADDR + 0x08))).reg
#define RFC1MCH_MC              (*((volatile RFCNMCH_REG *)(RFC_1_REG_BASE_ADDR + 0x08))).bit.MC          ///< Measurement counter data can be read and written through these bits.

/// Measurement counter data can be read and written through these bits.
#define RFC1MC                  (*((volatile RFCNMC_DWORD_REG *)(RFC_1_REG_BASE_ADDR + 0x06))).reg

/// RFC Ch.1 Time Base Counter Low Register
#define RFC1TCL                 (*((volatile RFCNTCL_REG *)(RFC_1_REG_BASE_ADDR + 0x0A))).reg
#define RFC1TCL_TC              (*((volatile RFCNTCL_REG *)(RFC_1_REG_BASE_ADDR + 0x0A))).bit.TC          ///< Time base counter data can be read and written through these bits.

/// RFC Ch.1 Time Base Counter High Register
#define RFC1TCH                 (*((volatile RFCNTCH_REG *)(RFC_1_REG_BASE_ADDR + 0x0C))).reg
#define RFC1TCH_TC              (*((volatile RFCNTCH_REG *)(RFC_1_REG_BASE_ADDR + 0x0C))).bit.TC          ///< Time base counter data can be read and written through these bits.

/// Time base counter data can be read and written through these bits.
#define RFC1TC                  (*((volatile RFCNTC_DWORD_REG *)(RFC_1_REG_BASE_ADDR + 0x0A))).reg

/// RFC Ch.1 Interrupt Flag Register
#define RFC1INTF                (*((volatile RFCNINTF_REG *)(RFC_1_REG_BASE_ADDR + 0x0E))).reg
#define RFC1INTF_EREFIF         (*((volatile RFCNINTF_REG *)(RFC_1_REG_BASE_ADDR + 0x0E))).bit.EREFIF      ///< This bit indicate Reference oscillation completion interrupt cause occurrence status.
#define RFC1INTF_ESENAIF        (*((volatile RFCNINTF_REG *)(RFC_1_REG_BASE_ADDR + 0x0E))).bit.ESENAIF     ///< This bit indicate Sensor B oscillation completion interrupt cause occurrence status.
#define RFC1INTF_ESENBIF        (*((volatile RFCNINTF_REG *)(RFC_1_REG_BASE_ADDR + 0x0E))).bit.ESENBIF     ///< This bit indicate Sensor B oscillation completion interrupt cause occurrence status.
#define RFC1INTF_OVMCIF         (*((volatile RFCNINTF_REG *)(RFC_1_REG_BASE_ADDR + 0x0E))).bit.OVMCIF      ///< This bit indicate Measurement counter overflow error interrupt cause occurrence status.
#define RFC1INTF_OVTCIF         (*((volatile RFCNINTF_REG *)(RFC_1_REG_BASE_ADDR + 0x0E))).bit.OVTCIF      ///< This bit indicate Time base counter overflow error interrupt cause occurrence status.

/// RFC Ch.1 Interrupt Enable Register
#define RFC1INTE                (*((volatile RFCNINTE_REG *)(RFC_1_REG_BASE_ADDR + 0x10))).reg
#define RFC1INTE_EREFIE         (*((volatile RFCNINTE_REG *)(RFC_1_REG_BASE_ADDR + 0x10))).bit.EREFIE      ///< This bit enable Reference oscillation completion interrupt.
#define RFC1INTE_ESENAIE        (*((volatile RFCNINTE_REG *)(RFC_1_REG_BASE_ADDR + 0x10))).bit.ESENAIE     ///< This bit enable Sensor A oscillation completion interrupt.
#define RFC1INTE_ESENBIE        (*((volatile RFCNINTE_REG *)(RFC_1_REG_BASE_ADDR + 0x10))).bit.ESENBIE     ///< This bit enable Sensor B oscillation completion interrupt.
#define RFC1INTE_OVMCIE         (*((volatile RFCNINTE_REG *)(RFC_1_REG_BASE_ADDR + 0x10))).bit.OVMCIE      ///< This bit enable Measurement counter overflow error interrupt.
#define RFC1INTE_OVTCIE         (*((volatile RFCNINTE_REG *)(RFC_1_REG_BASE_ADDR + 0x10))).bit.OVTCIE      ///< This bit enable Time base counter overflow error interrupt.

/// ----- ADC12A ------

/// ADC12A Ch.0 Control Register
#define ADC12_0CTL              (*((volatile ADC12_NCTL_REG *)(ADC12A_0_REG_BASE_ADDR + 0x00))).reg
#define ADC12_0CTL_MODEN        (*((volatile ADC12_NCTL_REG *)(ADC12A_0_REG_BASE_ADDR + 0x00))).bit.MODEN       ///< This bit enables the ADC12A operations.
#define ADC12_0CTL_ADST         (*((volatile ADC12_NCTL_REG *)(ADC12A_0_REG_BASE_ADDR + 0x00))).bit.ADST        ///< This bit starts A/D conversion or enables to accept triggers.
#define ADC12_0CTL_BSYSTAT      (*((volatile ADC12_NCTL_REG *)(ADC12A_0_REG_BASE_ADDR + 0x00))).bit.BSYSTAT     ///< This bit indicates whether the ADC12A is executing A/D conversion or not.
#define ADC12_0CTL_ADSTAT       (*((volatile ADC12_NCTL_REG *)(ADC12A_0_REG_BASE_ADDR + 0x00))).bit.ADSTAT      ///< These bits indicate the analog input pin number m being A/D converted.

/// ADC12A Ch.0 Trigger/Analog Input Select Register
#define ADC12_0TRG              (*((volatile ADC12_NTRG_REG *)(ADC12A_0_REG_BASE_ADDR + 0x02))).reg
#define ADC12_0TRG_SMPCLK       (*((volatile ADC12_NTRG_REG *)(ADC12A_0_REG_BASE_ADDR + 0x02))).bit.SMPCLK      ///< These bits set the analog input signal sampling time.
#define ADC12_0TRG_CNVTRG       (*((volatile ADC12_NTRG_REG *)(ADC12A_0_REG_BASE_ADDR + 0x02))).bit.CNVTRG      ///< These bits select a trigger source to start A/D conversion.
#define ADC12_0TRG_CNVMD        (*((volatile ADC12_NTRG_REG *)(ADC12A_0_REG_BASE_ADDR + 0x02))).bit.CNVMD       ///< This bit sets the A/D conversion mode.
#define ADC12_0TRG_STMD         (*((volatile ADC12_NTRG_REG *)(ADC12A_0_REG_BASE_ADDR + 0x02))).bit.STMD        ///< This bit selects the data alignment when the conversion results are loaded into the A/D conversion result registers.
#define ADC12_0TRG_STAAIN       (*((volatile ADC12_NTRG_REG *)(ADC12A_0_REG_BASE_ADDR + 0x02))).bit.STAAIN      ///< These bits set the analog input pin to be A/D converted first.
#define ADC12_0TRG_ENDAIN       (*((volatile ADC12_NTRG_REG *)(ADC12A_0_REG_BASE_ADDR + 0x02))).bit.ENDAIN      ///< These bits set the analog input pin to be A/D converted last.

/// ADC12A Ch.0 Configuration Register
#define ADC12_0CFG              (*((volatile ADC12_NCFG_REG *)(ADC12A_0_REG_BASE_ADDR + 0x04))).reg
#define ADC12_0CFG_VRANGE       (*((volatile ADC12_NCFG_REG *)(ADC12A_0_REG_BASE_ADDR + 0x04))).bit.VRANGE      ///< These bits set the A/D converter operating voltage range.

/// ADC12A Ch.0 Interrupt Flag Register
#define ADC12_0INTF             (*((volatile ADC12_NINTF_REG *)(ADC12A_0_REG_BASE_ADDR + 0x06))).reg
#define ADC12_0INTF_AD0CIF      (*((volatile ADC12_NINTF_REG *)(ADC12A_0_REG_BASE_ADDR + 0x06))).bit.AD0CIF      ///< This bit indicate Analog input signal 0 A/D conversion completion interrupt cause occurrence status.
#define ADC12_0INTF_AD1CIF      (*((volatile ADC12_NINTF_REG *)(ADC12A_0_REG_BASE_ADDR + 0x06))).bit.AD1CIF      ///< This bit indicate Analog input signal 1 A/D conversion completion interrupt cause occurrence status.
#define ADC12_0INTF_AD5CIF      (*((volatile ADC12_NINTF_REG *)(ADC12A_0_REG_BASE_ADDR + 0x06))).bit.AD5CIF      ///< This bit indicate Analog input signal 5 A/D conversion completion interrupt cause occurrence status.
#define ADC12_0INTF_AD0OVIF     (*((volatile ADC12_NINTF_REG *)(ADC12A_0_REG_BASE_ADDR + 0x06))).bit.AD0OVIF     ///< This bit indicate Analog input signal 0 A/D conversion result overwrite error interrupt cause occurrence status.
#define ADC12_0INTF_AD1OVIF     (*((volatile ADC12_NINTF_REG *)(ADC12A_0_REG_BASE_ADDR + 0x06))).bit.AD1OVIF     ///< This bit indicate Analog input signal 1 A/D conversion result overwrite error interrupt cause occurrence status.
#define ADC12_0INTF_AD5OVIF     (*((volatile ADC12_NINTF_REG *)(ADC12A_0_REG_BASE_ADDR + 0x06))).bit.AD5OVIF     ///< This bit indicate Analog input signal 5 A/D conversion result overwrite error interrupt cause occurrence status.

/// ADC12A Ch.0 Interrupt Enable Register
#define ADC12_0INTE             (*((volatile ADC12_NINTE_REG *)(ADC12A_0_REG_BASE_ADDR + 0x08))).reg
#define ADC12_0INTE_AD0CIE      (*((volatile ADC12_NINTE_REG *)(ADC12A_0_REG_BASE_ADDR + 0x08))).bit.AD0CIE      ///< This bit enable Analog input signal 0 A/D conversion completion interrupt.
#define ADC12_0INTE_AD1CIE      (*((volatile ADC12_NINTE_REG *)(ADC12A_0_REG_BASE_ADDR + 0x08))).bit.AD1CIE      ///< This bit enable Analog input signal 1 A/D conversion completion interrupt.
#define ADC12_0INTE_AD5CIE      (*((volatile ADC12_NINTE_REG *)(ADC12A_0_REG_BASE_ADDR + 0x08))).bit.AD5CIE      ///< This bit enable Analog input signal 5 A/D conversion completion interrupt.
#define ADC12_0INTE_AD0OVIE     (*((volatile ADC12_NINTE_REG *)(ADC12A_0_REG_BASE_ADDR + 0x08))).bit.AD0OVIE     ///< This bit enable Analog input signal 0 A/D conversion result overwrite error interrupt.
#define ADC12_0INTE_AD1OVIE     (*((volatile ADC12_NINTE_REG *)(ADC12A_0_REG_BASE_ADDR + 0x08))).bit.AD1OVIE     ///< This bit enable Analog input signal 1 A/D conversion result overwrite error interrupt.
#define ADC12_0INTE_AD5OVIE     (*((volatile ADC12_NINTE_REG *)(ADC12A_0_REG_BASE_ADDR + 0x08))).bit.AD5OVIE     ///< This bit enable Analog input signal 5 A/D conversion result overwrite error interrupt.

/// ADC12A Ch.0 Result Register 0
#define ADC12_0AD0D             (*((volatile ADC12_0ADND_REG *)(ADC12A_0_REG_BASE_ADDR + 0x0A))).reg
#define ADC12_0AD0D_AD0D        (*((volatile ADC12_0ADND_REG *)(ADC12A_0_REG_BASE_ADDR + 0x0A))).bit.AD0D        ///< These bits are the A/D conversion results of the analog input signal 0.

/// ADC12A Ch.0 Result Register 1
#define ADC12_0AD1D             (*((volatile ADC12_NAD1D_REG *)(ADC12A_0_REG_BASE_ADDR + 0x0C))).reg
#define ADC12_0AD1D_AD1D        (*((volatile ADC12_NAD1D_REG *)(ADC12A_0_REG_BASE_ADDR + 0x0C))).bit.AD1D        ///< These bits are the A/D conversion results of the analog input signal 1.

/// ADC12A Ch.0 Result Register 5
#define ADC12_0AD5D             (*((volatile ADC12_NAD5D_REG *)(ADC12A_0_REG_BASE_ADDR + 0x14))).reg
#define ADC12_0AD5D_AD5D        (*((volatile ADC12_NAD5D_REG *)(ADC12A_0_REG_BASE_ADDR + 0x14))).bit.AD5D        ///< These bits are the A/D conversion results of the analog input signal 5.

/// ----- TSRVR ------

/// TSRVR Ch.0 Temperature Sensor Control Register
#define TSRVR0TCTL              (*((volatile TSRVRNTCTL_REG *)(TSRVR_0_REG_BASE_ADDR + 0x00))).reg
#define TSRVR0TCTL_TEMPEN       (*((volatile TSRVRNTCTL_REG *)(TSRVR_0_REG_BASE_ADDR + 0x00))).bit.TEMPEN      ///< This bit enables the temperature sensor operation.

/// TSRVR Ch.0 Reference Voltage Generator Control Register
#define TSRVR0VCTL              (*((volatile TSRVRNVCTL_REG *)(TSRVR_0_REG_BASE_ADDR + 0x02))).reg
#define TSRVR0VCTL_VREFAMD      (*((volatile TSRVRNVCTL_REG *)(TSRVR_0_REG_BASE_ADDR + 0x02))).bit.VREFAMD     ///< These bits set the reference voltage generator output voltage.

#ifdef __cplusplus
}
#endif

#endif // C17M30_REG_H__
