/************************************************************************//**
 *
 * @file	upmux_m30_m31_m32_m33_reg.h
 *
 * @brief	Definition of the Universal Port MultiplexerUPMUX) Register.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 01 Sep. 2016    1.00
 *				- First revision.
 *
 ******************************************************************************/

#ifndef UPMUX_REG_H__
#define UPMUX_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

/// P00-01 Universal Port Multiplexer Setting Register
typedef union P0UPMUX0_REG_TAG {
    unsigned short  reg;
    struct P0UPMUX0_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P00PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P00PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P00PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P01PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P01PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P01PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P0UPMUX0_REG;

/// P02-03 Universal Port Multiplexer Setting Register
typedef union P0UPMUX1_REG_TAG {
    unsigned short  reg;
    struct P0UPMUX1_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P02PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P02PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P02PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P03PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P03PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P03PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P0UPMUX1_REG;

/// P04-05 Universal Port Multiplexer Setting Register
typedef union P0UPMUX2_REG_TAG {
    unsigned short  reg;
    struct P0UPMUX2_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P04PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P04PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P04PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P05PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P05PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P05PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P0UPMUX2_REG;

/// P06-07 Universal Port Multiplexer Setting Register
typedef union P0UPMUX3_REG_TAG {
    unsigned short  reg;
    struct P0UPMUX3_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P06PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P06PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P06PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P07PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P07PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P07PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P0UPMUX3_REG;

/// P10-11 Universal Port Multiplexer Setting Register
typedef union P1UPMUX0_REG_TAG {
    unsigned short  reg;
    struct P1UPMUX0_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P10PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P10PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P10PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P11PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P11PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P11PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P1UPMUX0_REG;

/// P12-13 Universal Port Multiplexer Setting Register
typedef union P1UPMUX1_REG_TAG {
    unsigned short  reg;
    struct P1UPMUX1_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P12PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P12PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P12PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P13PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P13PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P13PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P1UPMUX1_REG;

/// P14-15 Universal Port Multiplexer Setting Register
typedef union P1UPMUX2_REG_TAG {
    unsigned short  reg;
    struct P1UPMUX2_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P14PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P14PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P14PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P15PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P15PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P15PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P1UPMUX2_REG;

/// P16-17 Universal Port Multiplexer Setting Register
typedef union P1UPMUX3_REG_TAG {
    unsigned short  reg;
    struct P1UPMUX3_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P16PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P16PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P16PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P17PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P17PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P17PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P1UPMUX3_REG;

/// P20-21 Universal Port Multiplexer Setting Register
typedef union P2UPMUX0_REG_TAG {
    unsigned short  reg;
    struct P2UPMUX0_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P20PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P20PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P20PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P21PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P21PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P21PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P2UPMUX0_REG;

/// P22-23 Universal Port Multiplexer Setting Register
typedef union P2UPMUX1_REG_TAG {
    unsigned short  reg;
    struct P2UPMUX1_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P22PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P22PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P22PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P23PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P23PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P23PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P2UPMUX1_REG;

/// P24-25 Universal Port Multiplexer Setting Register
typedef union P2UPMUX2_REG_TAG {
    unsigned short  reg;
    struct P2UPMUX2_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P24PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P24PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P24PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P25PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P25PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P25PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P2UPMUX2_REG;

/// P26-27 Universal Port Multiplexer Setting Register
typedef union P2UPMUX3_REG_TAG {
    unsigned short  reg;
    struct P2UPMUX3_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P26PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P26PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P26PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P27PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P27PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P27PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P2UPMUX3_REG;

/// P30-31 Universal Port Multiplexer Setting Register
typedef union P3UPMUX0_REG_TAG {
    unsigned short  reg;
    struct P3UPMUX0_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P30PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P30PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P30PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P31PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P31PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P31PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P3UPMUX0_REG;

/// P32-33 Universal Port Multiplexer Setting Register
typedef union P3UPMUX1_REG_TAG {
    unsigned short  reg;
    struct P3UPMUX1_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P32PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P32PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P32PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P33PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P33PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P33PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P3UPMUX1_REG;

/// P34-35 Universal Port Multiplexer Setting Register
typedef union P3UPMUX2_REG_TAG {
    unsigned short  reg;
    struct P3UPMUX2_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P34PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P34PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P34PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P35PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P35PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P35PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P3UPMUX2_REG;

/// P36-37 Universal Port Multiplexer Setting Register
typedef union P3UPMUX3_REG_TAG {
    unsigned short  reg;
    struct P3UPMUX3_REG_BIT_TAG {
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P36PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P36PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P36PPFNC    : 3;
        /**
         * These bits specify a peripheral circuit.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P37PERISEL  : 3;
        /**
         * These bits specify a peripheral circuit channel number.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P37PERICH   : 2;
        /**
         * These bits specify the peripheral I/O function to be assigned to the port.
         * .PxyPERISEL[2:0]
         * .PxzPERISEL[2:0]
         *  These bits specify a peripheral circuit.
         * .PxyPERICH[1:0]
         * .PxzPERICH[1:0]
         *  These bits specify a peripheral circuit channel number.
         * .PxyPPFNC[2:0]
         * .PxzPPFNC[2:0]
         *  These bits specify the peripheral I/O function to be assigned to the port.
         * +---------------+----------------------------------------------------------------------------------------+
         * |               |                                     PxyPERISEL[2:0]                                    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |   0x0    |   0x1    |   0x2    |   0x3    |   0x4     |   0x5    |   0x6    |   0x7    |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |  None *  |   I2C    |   SPIA   |  UART3   |  T16B     | Reserved | Reserved | Reserved |
         * | PxyPPFNC[2:0] +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |                                     PxyPERICH[1:0]                                     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   0x0    |  0x0,0x1 |  0x0,0x1 |0x0,0x1,0x2|    -     |    -     |    -     |
         * |               +----------+----------+----------+----------+-----------+----------+----------+----------+
         * |               |    -     |   Ch.0   |  Ch.0,1  |  Ch.0,1  | Ch.0,1,2  |    -     |    -     |    -     |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x0      |  None *  |  None *  |  None *  |  None *  |  None *   |  None *  |  None *  |  None *  |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * |      0x1      |          |   SCLn   |   SDIn   |  USINn   | TOUTn0/   |          |          |          |
         * |               |          |          |          |          |  CAPn0    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x2      |          |   SDAn   |   SDOn   |  USOUTn  | TOUTn1/   |          |          |          |
         * |               |          |          |          |          |  CAPn1    |          |          |          |
         * +---------------+          +----------+----------+----------+-----------+          +          +          +
         * |      0x3      | Reserved |          | SPICLKn  |          |           | Reserved | Reserved | Reserved |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x4      |          |          | #SPISSn  |          |           |          |          |          |
         * +---------------+          +          +----------+          +           +          +          +          +
         * |      0x5      |          | Reserved |          | Reserved | Reserved  |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x6      |          |          | Reserved |          |           |          |          |          |
         * +---------------+          +          +          +          +           +          +          +          +
         * |      0x7      |          |          |          |          |           |          |          |          |
         * +---------------+----------+----------+----------+----------+-----------+----------+----------+----------+
         * "None" means no assignment. Selecting this will put the Pxy pin into Hi-Z status when peripheral I/O function 1 is
         * selected and enabled in the I/O port.
         */
        unsigned short      P37PPFNC    : 3;
    } bit;
    unsigned char   byte_reg[2];
} P3UPMUX3_REG;

#ifdef __cplusplus
}
#endif

#endif // UPMUX_REG_H__
